@@ -122,35 +122,49 @@ enum BetFinanceDataColumns
  * \return
  **/
 static AmortissementStruct *bet_finance_get_echeance_at_date (LoanStruct *s_loan,
-															  GDate *date,
+															  const GDate *date,
 															  gboolean maj_s_loan_capital_du)
 {
 	AmortissementStruct *s_amortissement = NULL;
 
-	devel_debug (gsb_format_gdate (date));
+	//devel_debug (gsb_format_gdate (date));
 	s_amortissement = bet_data_finance_structure_amortissement_init ();
 	if (g_date_compare (date, s_loan->first_date) == 0
 		&& s_loan->first_is_different)
 	{
 			s_amortissement->echeance = s_loan->first_capital;
-			s_amortissement->echeance += s_loan->fees + s_loan->first_interests;
+			s_amortissement->echeance += s_loan->amount_fees + s_loan->first_interests;
 			s_amortissement->interets = s_loan->first_interests;
-			s_amortissement->frais = s_loan->fees;
+			s_amortissement->frais = s_loan->amount_fees;
 			s_amortissement->principal = s_loan->first_capital;
 	}
+	else if (s_loan->type_taux == 2)
+	{
+		gdouble taux_periodique;
+
+		taux_periodique = bet_data_finance_get_taux_periodique (s_loan->annual_rate, s_loan->type_taux);
+		s_amortissement->echeance = s_loan->fixed_due_amount;
+		s_amortissement->interets = bet_data_finance_get_interets (s_loan->capital_du, taux_periodique);
+		s_amortissement->frais = bet_data_finance_get_fees_for_type_taux_2 (s_loan->capital_du,
+																			s_loan->percentage_fees);
+		s_amortissement->principal = bet_data_finance_get_principal (s_amortissement->echeance,
+																	 s_amortissement->interets,
+																	 s_amortissement->frais);
+	}
 	else
 	{
 		gdouble taux_periodique;
 //~ printf ("s_loan->capital_du avant = %f\n", s_loan->capital_du);
 		taux_periodique = bet_data_finance_get_taux_periodique (s_loan->annual_rate, s_loan->type_taux);
 		s_amortissement->echeance = bet_data_finance_get_echeance (s_loan->capital, taux_periodique, s_loan->duree);
-		s_amortissement->echeance += s_loan->fees;
+		s_amortissement->echeance += s_loan->amount_fees;
 		s_amortissement->interets = bet_data_finance_get_interets (s_loan->capital_du, taux_periodique);
-		s_amortissement->frais = s_loan->fees;
+		s_amortissement->frais = s_loan->amount_fees;
 		s_amortissement->principal = bet_data_finance_get_principal (s_amortissement->echeance,
 																	 s_amortissement->interets,
 																	 s_amortissement->frais);
 	}
+
 	s_amortissement->capital_du = s_loan->capital_du - s_amortissement->principal;
 //~ printf ("capital_du = %f principal = %f interêts = %f frais = %f\n",
 		//~ s_amortissement->capital_du, s_amortissement->principal, s_amortissement->interets, s_amortissement->frais);
@@ -182,7 +196,6 @@ static void bet_finance_fill_data_ligne (GtkTreeModel *model,
     gchar *str_echeance;
     gchar *str_totale;
     gchar *str_total_cost;
-    gchar *str_format;
 	gchar *tmp_str;
     gchar buffer[256];
     gint nbre_char;
@@ -195,12 +208,8 @@ static void bet_finance_fill_data_ligne (GtkTreeModel *model,
 													   s_echeance->devise,
 													   TRUE);
 
-	tmp_str = utils_str_itoa (BET_TAUX_DIGITS);
-    str_format = g_strconcat ("%.", tmp_str, "f", NULL);
-	g_free (tmp_str);
-    nbre_char = g_sprintf (buffer, str_format, s_echeance->taux);
+    nbre_char = g_sprintf (buffer, "%.*f", BET_TAUX_DIGITS, s_echeance->taux);
     str_taux =  g_strndup (buffer, nbre_char + 1);
-    g_free (str_format);
 
     str_frais = utils_real_get_string_with_currency (gsb_real_double_to_real (s_echeance->frais),
 													 s_echeance->devise,
@@ -662,7 +671,9 @@ static gboolean bet_finance_ui_capital_entry_key_press_event (GtkWidget *widget,
 															  GtkWidget *page)
 {
     gchar *str_capital;
+	GrisbiWinEtat *w_etat;
 
+	w_etat = grisbi_win_get_w_etat ();
     switch (ev->keyval)
     {
         case GDK_KEY_1:
@@ -678,8 +689,8 @@ static gboolean bet_finance_ui_capital_entry_key_press_event (GtkWidget *widget,
             break;
 
         case GDK_KEY_Escape :
-            str_capital = utils_real_get_string_with_currency (gsb_real_double_to_real (etat.bet_capital),
-															   etat.bet_currency,
+            str_capital = utils_real_get_string_with_currency (gsb_real_double_to_real (w_etat->bet_capital),
+															   w_etat->bet_currency,
 															   FALSE);
             gtk_entry_set_text (GTK_ENTRY (widget), str_capital);
             gtk_editable_set_position (GTK_EDITABLE (widget), -1);
@@ -688,20 +699,20 @@ static gboolean bet_finance_ui_capital_entry_key_press_event (GtkWidget *widget,
             break;
 
         case GDK_KEY_ISO_Left_Tab:
-            etat.bet_capital = bet_finance_get_number_from_string (page, "capital");
+            w_etat->bet_capital = bet_finance_get_number_from_string (page, "capital");
             bet_finance_ui_calculer_clicked (NULL, page);
             return TRUE;
             break;
 
         case GDK_KEY_Tab :
-            etat.bet_capital = bet_finance_get_number_from_string (page, "capital");
+            w_etat->bet_capital = bet_finance_get_number_from_string (page, "capital");
             bet_finance_ui_calculer_clicked (NULL, page);
             return TRUE;
             break;
 
         case GDK_KEY_KP_Enter :
         case GDK_KEY_Return :
-            etat.bet_capital = bet_finance_get_number_from_string (page, "capital");
+            w_etat->bet_capital = bet_finance_get_number_from_string (page, "capital");
             bet_finance_ui_calculer_clicked (NULL, page);
             return TRUE;
             break;
@@ -741,7 +752,7 @@ static void bet_finance_ui_switch_amortization_initial_date (GtkWidget *widget,
 	else
 		tmp_button = g_object_get_data (G_OBJECT (tree_view), "amortization_initial_date_button");
 
-    if (a_conf->display_toolbar != GSB_BUTTON_ICON)
+    if (a_conf->display_toolbar != GTK_TOOLBAR_ICONS)
     {
 		if (amortization_initial_date)
 			gtk_tool_button_set_label (GTK_TOOL_BUTTON (tmp_button), _("At today"));
@@ -770,6 +781,8 @@ static void bet_finance_ui_export_tab (GtkWidget *menu_item,
 									   GtkTreeView *tree_view)
 {
     GtkWidget *dialog;
+	GtkWidget *button_cancel;
+	GtkWidget *button_save;
     gint resultat;
     gchar *filename;
     gchar *tmp_last_directory;
@@ -777,16 +790,25 @@ static void bet_finance_ui_export_tab (GtkWidget *menu_item,
     dialog = gtk_file_chooser_dialog_new (_("Export the array"),
 										  GTK_WINDOW (grisbi_app_get_active_window (NULL)),
 										  GTK_FILE_CHOOSER_ACTION_SAVE,
-										  "gtk-cancel", GTK_RESPONSE_CANCEL,
-										  "gtk-save", GTK_RESPONSE_OK,
+										  NULL, NULL,
 										  NULL);
 
+	button_cancel = gtk_button_new_with_label (_("Cancel"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_cancel, GTK_RESPONSE_CANCEL);
+	gtk_widget_set_can_default (button_cancel, TRUE);
+
+	button_save = gtk_button_new_with_label (_("Save"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_save, GTK_RESPONSE_OK);
+	gtk_widget_set_can_default (button_save, TRUE);
+
     gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog),  _("credit.csv"));
     gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), gsb_file_get_last_path ());
     gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog), TRUE);
     gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ON_PARENT);
 
-    resultat = gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_show_all (dialog);
+
+	resultat = gtk_dialog_run (GTK_DIALOG (dialog));
 
     switch (resultat)
     {
@@ -906,11 +928,7 @@ static void bet_finance_ui_data_list_context_menu (GtkWidget *tree_view,
     /* Finish all. */
     gtk_widget_show_all (menu);
 
-#if GTK_CHECK_VERSION (3,22,0)
 	gtk_menu_popup_at_pointer (GTK_MENU (menu), NULL);
-#else
-	gtk_menu_popup (GTK_MENU(menu), NULL, NULL, NULL, NULL, 3, gtk_get_current_event_time ());
-#endif
 }
 
 /**
@@ -1251,7 +1269,9 @@ static GtkWidget *bet_finance_ui_create_duration_widget (GtkWidget *parent)
 									 N_("Between 1 and 15 years"),
     								 N_("Between 15 and 30 years"),
     								 NULL};
+	GrisbiWinEtat *w_etat;
 
+	w_etat = grisbi_win_get_w_etat ();
     combobox = gsb_combo_box_new_with_index (text_duration,
 											 G_CALLBACK (bet_finance_ui_duration_button_changed),
 											 parent);
@@ -1259,7 +1279,7 @@ static GtkWidget *bet_finance_ui_create_duration_widget (GtkWidget *parent)
     g_signal_handlers_block_by_func (G_OBJECT (combobox),
 									 G_CALLBACK (bet_finance_ui_duration_button_changed),
 									 parent);
-    gsb_combo_box_set_index (combobox, etat.bet_index_duree);
+    gsb_combo_box_set_index (combobox, w_etat->bet_index_duree);
     g_signal_handlers_unblock_by_func (G_OBJECT (combobox),
 									   G_CALLBACK (bet_finance_ui_duration_button_changed),
 									   parent);
@@ -1278,7 +1298,10 @@ static GtkWidget *bet_finance_ui_create_duration_widget (GtkWidget *parent)
 static void bet_finance_ui_spin_button_fees_changed (GtkSpinButton *spinbutton,
 													 GtkWidget *page)
 {
-    etat.bet_frais = gtk_spin_button_get_value (GTK_SPIN_BUTTON (spinbutton));
+	GrisbiWinEtat *w_etat;
+
+	w_etat = grisbi_win_get_w_etat ();
+    w_etat->bet_frais = gtk_spin_button_get_value (GTK_SPIN_BUTTON (spinbutton));
     bet_finance_ui_calculer_clicked (NULL, page);
 }
 
@@ -1293,7 +1316,10 @@ static void bet_finance_ui_spin_button_fees_changed (GtkSpinButton *spinbutton,
 static void bet_finance_ui_spin_button_taux_changed (GtkSpinButton *spinbutton,
 													 GtkWidget *page)
 {
-    etat.bet_taux_annuel = gtk_spin_button_get_value (GTK_SPIN_BUTTON (spinbutton));
+	GrisbiWinEtat *w_etat;
+
+	w_etat = grisbi_win_get_w_etat ();
+    w_etat->bet_taux_annuel = gtk_spin_button_get_value (GTK_SPIN_BUTTON (spinbutton));
     bet_finance_ui_calculer_clicked (NULL, page);
 }
 
@@ -1310,8 +1336,11 @@ static void bet_finance_ui_type_taux_changed (GtkWidget *togglebutton,
 											  GdkEventButton *event,
 											  GtkWidget *widget)
 {
+	GrisbiWinEtat *w_etat;
+
+	w_etat = grisbi_win_get_w_etat ();
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (togglebutton), TRUE);
-    etat.bet_type_taux = !etat.bet_type_taux;
+    w_etat->bet_type_taux = !w_etat->bet_type_taux;
     bet_finance_ui_calculer_clicked (NULL, widget);
 }
 
@@ -1330,6 +1359,9 @@ static void bet_finance_ui_create_saisie_widget (GtkWidget *page,
     GtkWidget *spin_button = NULL;
     GtkWidget *button_1, *button_2;
     gchar *tmp_str;
+	GrisbiWinEtat *w_etat;
+
+	w_etat = grisbi_win_get_w_etat ();
 
     /* taux */
     label = gtk_label_new (_("Annual interest: "));
@@ -1339,7 +1371,7 @@ static void bet_finance_ui_create_saisie_widget (GtkWidget *page,
 
     spin_button = gtk_spin_button_new_with_range (0.0, 100,
                         bet_data_finance_get_bet_taux_step (BET_TAUX_DIGITS));
-    gtk_spin_button_set_value (GTK_SPIN_BUTTON (spin_button), etat.bet_taux_annuel);
+    gtk_spin_button_set_value (GTK_SPIN_BUTTON (spin_button), w_etat->bet_taux_annuel);
     g_object_set_data (G_OBJECT (page), "taux", spin_button);
 	gtk_grid_attach (GTK_GRID (grid), spin_button, 1, 1, 1 ,1);
     g_signal_connect (spin_button,
@@ -1361,7 +1393,7 @@ static void bet_finance_ui_create_saisie_widget (GtkWidget *page,
     spin_button = gtk_spin_button_new_with_range (0.0,
 												  100,
 												  bet_data_finance_get_bet_taux_step (BET_TAUX_DIGITS));
-    gtk_spin_button_set_value (GTK_SPIN_BUTTON (spin_button), etat.bet_frais);
+    gtk_spin_button_set_value (GTK_SPIN_BUTTON (spin_button), w_etat->bet_frais);
     g_object_set_data (G_OBJECT (page), "frais", spin_button);
 	gtk_grid_attach (GTK_GRID (grid), spin_button, 4, 1, 1 ,1);
     g_signal_connect (spin_button,
@@ -1390,7 +1422,7 @@ static void bet_finance_ui_create_saisie_widget (GtkWidget *page,
 															_("Proportional rate"));
     g_object_set_data (G_OBJECT (page), "type_taux", button_2);
 
-    if (etat.bet_type_taux)
+    if (w_etat->bet_type_taux)
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button_2), TRUE);
     else
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button_1), TRUE);
@@ -1418,7 +1450,10 @@ static void bet_finance_ui_create_saisie_widget (GtkWidget *page,
 static void bet_finance_ui_currency_changed (GtkComboBox *combo_box,
 											 GtkWidget *page)
 {
-    etat.bet_currency = gsb_currency_get_currency_from_combobox (GTK_WIDGET (combo_box));
+	GrisbiWinEtat *w_etat;
+
+	w_etat = grisbi_win_get_w_etat ();
+    w_etat->bet_currency = gsb_currency_get_currency_from_combobox (GTK_WIDGET (combo_box));
     bet_finance_ui_calculer_clicked (NULL, page);
 }
 
@@ -1439,7 +1474,9 @@ static GtkWidget *bet_finance_ui_create_simulator_page (void)
     GtkWidget *label;
     GtkWidget *tree_view;
     gchar *str_capital;
+	GrisbiWinEtat *w_etat;
 
+	w_etat = grisbi_win_get_w_etat ();
     page = gtk_box_new (GTK_ORIENTATION_VERTICAL, MARGIN_BOX);
 
     /* frame pour la barre d'outils */
@@ -1464,8 +1501,8 @@ static GtkWidget *bet_finance_ui_create_simulator_page (void)
     gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
 	gtk_grid_attach (GTK_GRID (grid), label, 0, 0, 1 ,1);
 
-    str_capital = utils_real_get_string_with_currency (gsb_real_double_to_real (etat.bet_capital),
-													   etat.bet_currency,
+    str_capital = utils_real_get_string_with_currency (gsb_real_double_to_real (w_etat->bet_capital),
+													   w_etat->bet_currency,
 													   FALSE);
 
     widget = gtk_entry_new ();
@@ -1485,7 +1522,7 @@ static GtkWidget *bet_finance_ui_create_simulator_page (void)
 
     /* Set the devises */
     widget = gsb_currency_make_combobox (FALSE);
-    gsb_currency_set_combobox_history (widget, etat.bet_currency);
+    gsb_currency_set_combobox_history (widget, w_etat->bet_currency);
     g_object_set_data (G_OBJECT (page), "devise", widget);
 	gtk_grid_attach (GTK_GRID (grid), widget, 2, 0, 1 ,1);
     g_signal_connect (G_OBJECT ( widget),
@@ -2154,7 +2191,7 @@ void bet_finance_ui_update_all_finance_toolbars (gint toolbar_style)
  **/
 GsbReal bet_finance_get_loan_amount_at_date (gint scheduled_number,
 											 gint transfer_account,
-											 GDate *date,
+											 const GDate *date,
 											 gboolean maj_s_loan_capital_du)
 {
 	gint transaction_mother = 0;
@@ -2210,31 +2247,34 @@ AmortissementStruct *bet_finance_get_echeance_first (LoanStruct *s_loan,
 {
 	gdouble taux_periodique;
 	AmortissementStruct *s_amortissement = NULL;
+	gchar *tmp_str;
 
-	devel_debug (gsb_format_gdate (first_date));
+	tmp_str = gsb_format_gdate (first_date);
+	devel_debug (tmp_str);
+	g_free(tmp_str);
 	taux_periodique = bet_data_finance_get_taux_periodique (s_loan->annual_rate, s_loan->type_taux);
 	s_amortissement = bet_data_finance_structure_amortissement_init ();
 	if (s_loan->first_is_different)
 	{
 		s_amortissement->echeance = s_loan->first_capital;
-		s_amortissement->echeance += s_loan->fees + s_loan->first_interests;
+		s_amortissement->echeance += s_loan->amount_fees + s_loan->first_interests;
 		s_amortissement->interets = s_loan->first_interests;
-		s_amortissement->frais = s_loan->fees;
+		s_amortissement->frais = s_loan->amount_fees;
 		s_amortissement->principal = s_loan->first_capital;
 		s_loan->other_echeance_amount = bet_data_finance_get_echeance (s_loan->capital,
 																	   taux_periodique,
 																	   s_loan->duree);
-		s_loan->other_echeance_amount += s_loan->fees;
+		s_loan->other_echeance_amount += s_loan->amount_fees;
 	}
 	else
 	{
 		s_amortissement->echeance = bet_data_finance_get_echeance (s_loan->capital,
 																   taux_periodique,
 																   s_loan->duree);
-		s_amortissement->echeance += s_loan->fees;
+		s_amortissement->echeance += s_loan->amount_fees;
 		s_amortissement->interets = bet_data_finance_get_interets (s_loan->capital_du,
 																   taux_periodique);
-		s_amortissement->frais = s_loan->fees;
+		s_amortissement->frais = s_loan->amount_fees;
 		s_amortissement->principal = bet_data_finance_get_principal (s_amortissement->echeance,
 																	 s_amortissement->interets,
 																	 s_amortissement->frais);
@@ -2268,7 +2308,9 @@ gdouble bet_finance_get_number_from_string (GtkWidget *parent,
     {
         const gchar *entry;
         gchar *tmp_str;
+		GrisbiWinEtat *w_etat;
 
+		w_etat = grisbi_win_get_w_etat ();
         entry = gtk_entry_get_text (GTK_ENTRY (widget));
 
         if (entry && strlen (entry) > 0)
@@ -2276,7 +2318,7 @@ gdouble bet_finance_get_number_from_string (GtkWidget *parent,
             number = utils_str_strtod (entry, NULL);
 
             tmp_str = utils_real_get_string_with_currency (gsb_real_double_to_real (number),
-														   etat.bet_currency,
+														   w_etat->bet_currency,
 														   FALSE);
             gtk_entry_set_text (GTK_ENTRY (widget), tmp_str);
             g_free (tmp_str);
@@ -2305,27 +2347,26 @@ void bet_finance_update_amortization_tab_with_data (gint account_number,
     GtkTreeIter iter;
     GtkTreePath *path;
     GtkTreePath *sel_path;
-	gchar *str_capital_du = NULL;
-    gchar *tmp_str;
-    gint index = 0;
-    gint nbre_echeances;
-    gint type_taux;
-    gdouble taux;
-    gdouble taux_periodique;
     GDate *date;
     GDate *last_paid_date = NULL;
 	GDate *last_installment_paid = NULL;
+	gchar *str_capital_du = NULL;
+	gchar *str_date = NULL;
+    gchar *tmp_str;
+	gchar *tmp_str2;
+    gint index = 0;
 	gint index_last_installment_paid = 0;
+    gint nbre_echeances;
+	gint origin;
+    gint type_taux;
+    gdouble taux;
+    gdouble taux_periodique;
     gboolean amortization_initial_date;
 	gboolean first_echeance = FALSE;
-	gint origin;
     AmortissementStruct *s_amortissement;
 
     devel_debug (NULL);
 
-    s_amortissement = bet_data_finance_structure_amortissement_init ();
-    s_amortissement->origin = SPP_ORIGIN_FINANCE;
-
     /* récupère le tableau d'amortissement */
     tree_view = g_object_get_data (G_OBJECT (parent), "bet_finance_tree_view");
 	origin = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (tree_view), "origin"));
@@ -2338,23 +2379,37 @@ void bet_finance_update_amortization_tab_with_data (gint account_number,
     store = gtk_tree_view_get_model (GTK_TREE_VIEW (tree_view));
     gtk_tree_store_clear (GTK_TREE_STORE (store));
 
-    s_amortissement->devise = gsb_data_account_get_currency (account_number);
-
     /* récupère les paramètres du crédit */
     nbre_echeances = s_loan->duree;
 
 	date = gsb_date_copy (s_loan->first_date);
 	if (!date || !g_date_valid (date))
+	{
 		return;
+	}
 
-	s_amortissement->str_date = gsb_format_gdate (date);
-	if (strlen (s_amortissement->str_date) == 0)
+	str_date = gsb_format_gdate (date);
+	if (strlen (str_date) == 0)
+	{
+		g_free(str_date);
 		return;
+	}
+
+	/* A ce stade on peut commencer à remplir la structure s_amortissement */
+	s_amortissement = bet_data_finance_structure_amortissement_init ();
+	s_amortissement->origin = SPP_ORIGIN_FINANCE;
+
+	/* set currency */
+	s_amortissement->devise = gsb_data_account_get_currency (account_number);
+
+	/* set date s_amortissement->str_date */
+	s_amortissement->str_date = str_date;
 
 	if (amortization_initial_date == FALSE)
 	{
 		last_paid_date = bet_data_finance_get_date_last_installment_paid (date);
-	/* set first line si necessaire */
+
+		/* set first line si necessaire */
 		if (s_loan->invers_cols_cap_ech)
 		{
 			str_capital_du = utils_real_get_string_with_currency (gsb_real_double_to_real (s_loan->capital),
@@ -2379,6 +2434,7 @@ void bet_finance_update_amortization_tab_with_data (gint account_number,
 	{
 		last_paid_date = gsb_date_copy (date);
 		last_installment_paid = bet_data_finance_get_date_last_installment_paid (date);
+
 		/* set first line si necessaire */
 		if (s_loan->invers_cols_cap_ech)
 		{
@@ -2401,9 +2457,11 @@ void bet_finance_update_amortization_tab_with_data (gint account_number,
 		}
 	}
 
-    /* met à jour le titre du tableau */
+	/* met à jour le titre du tableau */
     label = g_object_get_data (G_OBJECT (parent), "bet_finance_amortization_title");
-    tmp_str = g_strconcat (_("Amortization Table"), _(" at "), gsb_format_gdate (last_paid_date), NULL);
+	tmp_str2 = gsb_format_gdate (last_paid_date);
+    tmp_str = g_strconcat (_("Amortization Table"), _(" at "), tmp_str2, NULL);
+	g_free(tmp_str2);
     gtk_label_set_label (GTK_LABEL (label), tmp_str);
     g_free (tmp_str);
 
@@ -2426,72 +2484,115 @@ void bet_finance_update_amortization_tab_with_data (gint account_number,
 
     /* set duration */
     label = g_object_get_data (G_OBJECT (parent), "bet_finance_duree");
-    tmp_str = g_strconcat (utils_str_itoa (s_loan->duree), _(" months "), NULL);
+	tmp_str2 = utils_str_itoa (s_loan->duree);
+    tmp_str = g_strconcat (tmp_str2, _(" months "), NULL);
+	g_free(tmp_str2);
     gtk_label_set_label (GTK_LABEL (label), tmp_str);
     g_free (tmp_str);
 
     /* set frais */
-    s_amortissement->frais = s_loan->fees;
-    s_amortissement->str_frais = utils_real_get_string_with_currency (
-                        gsb_real_double_to_real (s_amortissement->frais),
-                        s_amortissement->devise, TRUE);
+	if (s_loan->type_taux < 2)
+	{
+		s_amortissement->frais = s_loan->amount_fees;
+		s_amortissement->str_frais = utils_real_get_string_with_currency (gsb_real_double_to_real
+																		  (s_amortissement->frais),
+																		  s_amortissement->devise,
+																		  TRUE);
+	}
 
 	/* set first echeance */
 	s_amortissement->num_echeance = 1;
 	if (s_loan->first_is_different)
 	{
-		s_amortissement->echeance = s_loan->first_capital;
-		s_amortissement->interets = s_loan->first_interests;
-		s_amortissement->echeance += s_amortissement->frais + s_amortissement->interets;
-		s_amortissement->str_echeance = utils_real_get_string_with_currency (gsb_real_double_to_real (s_amortissement->echeance),
-																			 s_amortissement->devise, TRUE);
-		s_amortissement->principal = bet_data_finance_get_principal (s_amortissement->echeance,
-																	 s_amortissement->interets,
-																	 s_amortissement->frais);
-
-		if (s_loan->invers_cols_cap_ech)
+		if (s_loan->type_taux == 2)
 		{
-			s_amortissement->capital_du -= s_amortissement->principal;
-			if (g_date_compare (date, last_paid_date) >= 0)
-				bet_finance_fill_amortization_ligne (store, s_amortissement);
+			s_amortissement->echeance = s_loan->first_capital;
+			s_amortissement->interets = s_loan->first_interests;
+			s_amortissement->frais = s_loan->first_fees;
+			s_amortissement->str_frais = utils_real_get_string_with_currency (gsb_real_double_to_real
+																			  (s_amortissement->frais),
+																			  s_amortissement->devise,
+																			  TRUE);
+			s_amortissement->echeance += s_amortissement->frais + s_amortissement->interets;
+			s_amortissement->str_echeance = utils_real_get_string_with_currency (gsb_real_double_to_real
+																				 (s_amortissement->echeance),
+																				 s_amortissement->devise,
+																				 TRUE);
+			s_amortissement->principal = s_loan->first_capital;
 		}
 		else
 		{
-			if (g_date_compare (date, last_paid_date) >= 0)
-				bet_finance_fill_amortization_ligne (store, s_amortissement);
-			s_amortissement->capital_du -= s_amortissement->principal;
+			s_amortissement->echeance = s_loan->first_capital;
+			s_amortissement->interets = s_loan->first_interests;
+			s_amortissement->echeance += s_amortissement->frais + s_amortissement->interets;
+			s_amortissement->str_echeance = utils_real_get_string_with_currency (gsb_real_double_to_real (s_amortissement->echeance),
+																				 s_amortissement->devise, TRUE);
+			s_amortissement->principal = bet_data_finance_get_principal (s_amortissement->echeance,
+																		 s_amortissement->interets,
+																		 s_amortissement->frais);
 		}
 
-		/* On recalcule la nouvelle échéance du crédit avec nouveau capital dû et nbre d'échéances -1 */
-		s_amortissement->echeance = bet_data_finance_get_echeance (s_amortissement->capital_du,
-																   taux_periodique, nbre_echeances-1);
-		s_amortissement->echeance += s_amortissement->frais;
-		s_amortissement->str_echeance = utils_real_get_string_with_currency (gsb_real_double_to_real (s_amortissement->echeance),
-																			 s_amortissement->devise, TRUE);
+			if (s_loan->invers_cols_cap_ech)
+			{
+				s_amortissement->capital_du -= s_amortissement->principal;
+				if (g_date_compare (date, last_paid_date) >= 0)
+					bet_finance_fill_amortization_ligne (store, s_amortissement);
+			}
+			else
+			{
+				if (g_date_compare (date, last_paid_date) >= 0)
+					bet_finance_fill_amortization_ligne (store, s_amortissement);
+				s_amortissement->capital_du -= s_amortissement->principal;
+			}
 	}
 	else
 	{
-		s_amortissement->echeance = bet_data_finance_get_echeance (s_amortissement->capital_du,
-																   taux_periodique, nbre_echeances);
-		s_amortissement->echeance += s_amortissement->frais;
-		s_amortissement->str_echeance = utils_real_get_string_with_currency (gsb_real_double_to_real (s_amortissement->echeance),
-																			 s_amortissement->devise, TRUE);
-		s_amortissement->interets = bet_data_finance_get_interets (s_amortissement->capital_du,
-																   taux_periodique);
-		s_amortissement->principal = bet_data_finance_get_principal (s_amortissement->echeance,
-																	 s_amortissement->interets,
-																	 s_amortissement->frais);
-		if (s_loan->invers_cols_cap_ech)
+		if (s_loan->type_taux == 2)
 		{
-			s_amortissement->capital_du -= s_amortissement->principal;
+			s_amortissement->echeance = s_loan->fixed_due_amount;
+			s_amortissement->str_echeance = utils_real_get_string_with_currency (gsb_real_double_to_real
+																				 (s_amortissement->echeance),
+																				 s_amortissement->devise, TRUE);
+			s_amortissement->frais = bet_data_finance_get_fees_for_type_taux_2 (s_amortissement->capital_du,
+																				s_loan->percentage_fees);
+			s_amortissement->str_frais = utils_real_get_string_with_currency (gsb_real_double_to_real
+																			  (s_amortissement->frais),
+																			  s_amortissement->devise,
+																			  TRUE);
+			s_amortissement->interets = bet_data_finance_get_interets (s_amortissement->capital_du,
+																	   taux_periodique);
+			s_amortissement->principal = bet_data_finance_get_principal (s_amortissement->echeance,
+																		 s_amortissement->interets,
+																		 s_amortissement->frais);
+
 			if (g_date_compare (date, last_paid_date) >= 0)
 				bet_finance_fill_amortization_ligne (store, s_amortissement);
+			s_amortissement->capital_du -= s_amortissement->principal;
 		}
 		else
 		{
-			if (g_date_compare (date, last_paid_date) >= 0)
-				bet_finance_fill_amortization_ligne (store, s_amortissement);
-			s_amortissement->capital_du -= s_amortissement->principal;
+			s_amortissement->echeance = bet_data_finance_get_echeance (s_amortissement->capital_du,
+																	   taux_periodique, nbre_echeances);
+			s_amortissement->echeance += s_amortissement->frais;
+			s_amortissement->str_echeance = utils_real_get_string_with_currency (gsb_real_double_to_real (s_amortissement->echeance),
+																				 s_amortissement->devise, TRUE);
+			s_amortissement->interets = bet_data_finance_get_interets (s_amortissement->capital_du,
+																	   taux_periodique);
+			s_amortissement->principal = bet_data_finance_get_principal (s_amortissement->echeance,
+																		 s_amortissement->interets,
+																		 s_amortissement->frais);
+			if (s_loan->invers_cols_cap_ech)
+			{
+				s_amortissement->capital_du -= s_amortissement->principal;
+				if (g_date_compare (date, last_paid_date) >= 0)
+					bet_finance_fill_amortization_ligne (store, s_amortissement);
+			}
+			else
+			{
+				if (g_date_compare (date, last_paid_date) >= 0)
+					bet_finance_fill_amortization_ligne (store, s_amortissement);
+				s_amortissement->capital_du -= s_amortissement->principal;
+			}
 		}
 	}
 
@@ -2500,39 +2601,81 @@ void bet_finance_update_amortization_tab_with_data (gint account_number,
 
     /* set the other echeances */
 	for (index = 2; index <= nbre_echeances; index++)
-    {
+	{
 		s_amortissement->num_echeance = index;
-        s_amortissement->interets = bet_data_finance_get_interets (s_amortissement->capital_du,
+		s_amortissement->interets = bet_data_finance_get_interets (s_amortissement->capital_du,
 																   taux_periodique);
-
-        if (index == nbre_echeances)
-        {
-            s_amortissement->echeance = bet_data_finance_get_last_echeance (
-                        s_amortissement->capital_du,
-                        s_amortissement->interets,
-                        s_amortissement->frais);
-            g_free (s_amortissement->str_echeance);
-            s_amortissement->str_echeance = utils_real_get_string_with_currency (
-                        gsb_real_double_to_real (s_amortissement->echeance),
-                        s_amortissement-> devise, TRUE);
-            s_amortissement->principal = s_amortissement->capital_du;
-        }
-        else
-            s_amortissement->principal = bet_data_finance_get_principal (s_amortissement->echeance,
-																		 s_amortissement->interets,
-																		 s_amortissement->frais);
-
-		if (s_loan->invers_cols_cap_ech)
+		if (s_loan->type_taux == 2)
 		{
-			s_amortissement->capital_du -= s_amortissement->principal;
+			s_amortissement->echeance = s_loan->fixed_due_amount;
+			s_amortissement->str_echeance = utils_real_get_string_with_currency (gsb_real_double_to_real
+																				 (s_amortissement->echeance),
+																				 s_amortissement->devise,
+																				 TRUE);
+			s_amortissement->frais = bet_data_finance_get_fees_for_type_taux_2 (s_amortissement->capital_du,
+																				s_loan->percentage_fees);
+			s_amortissement->str_frais = utils_real_get_string_with_currency (gsb_real_double_to_real
+																			  (s_amortissement->frais),
+																			  s_amortissement->devise,
+																			  TRUE);
+			if (index == nbre_echeances)
+			{
+				s_amortissement->echeance = bet_data_finance_get_last_echeance (
+							s_amortissement->capital_du,
+							s_amortissement->interets,
+							s_amortissement->frais);
+				g_free (s_amortissement->str_echeance);
+				s_amortissement->str_echeance = utils_real_get_string_with_currency (
+							gsb_real_double_to_real (s_amortissement->echeance),
+							s_amortissement-> devise, TRUE);
+				s_amortissement->principal = s_amortissement->capital_du;
+			}
+			else
+			{
+				s_amortissement->principal = bet_data_finance_get_principal (s_amortissement->echeance,
+																			 s_amortissement->interets,
+																			 s_amortissement->frais);
+			}
+
 			if (g_date_compare (date, last_paid_date) >= 0)
 				bet_finance_fill_amortization_ligne (store, s_amortissement);
+			s_amortissement->capital_du -= s_amortissement->principal;
 		}
 		else
 		{
-			if (g_date_compare (date, last_paid_date) >= 0)
-				bet_finance_fill_amortization_ligne (store, s_amortissement);
-			s_amortissement->capital_du -= s_amortissement->principal;
+			s_amortissement->num_echeance = index;
+			s_amortissement->interets = bet_data_finance_get_interets (s_amortissement->capital_du,
+																	   taux_periodique);
+
+			if (index == nbre_echeances)
+			{
+				s_amortissement->echeance = bet_data_finance_get_last_echeance (
+							s_amortissement->capital_du,
+							s_amortissement->interets,
+							s_amortissement->frais);
+				g_free (s_amortissement->str_echeance);
+				s_amortissement->str_echeance = utils_real_get_string_with_currency (
+							gsb_real_double_to_real (s_amortissement->echeance),
+							s_amortissement-> devise, TRUE);
+				s_amortissement->principal = s_amortissement->capital_du;
+			}
+			else
+				s_amortissement->principal = bet_data_finance_get_principal (s_amortissement->echeance,
+																			 s_amortissement->interets,
+																			 s_amortissement->frais);
+
+			if (s_loan->invers_cols_cap_ech)
+			{
+				s_amortissement->capital_du -= s_amortissement->principal;
+				if (g_date_compare (date, last_paid_date) >= 0)
+					bet_finance_fill_amortization_ligne (store, s_amortissement);
+			}
+			else
+			{
+				if (g_date_compare (date, last_paid_date) >= 0)
+					bet_finance_fill_amortization_ligne (store, s_amortissement);
+				s_amortissement->capital_du -= s_amortissement->principal;
+			}
 		}
 		if (amortization_initial_date && !first_echeance)
 		{
@@ -2549,7 +2692,7 @@ void bet_finance_update_amortization_tab_with_data (gint account_number,
 //~ if (index < 11)
 	//~ printf ("num_echeance = %d capital_du = %f, principal = %f interets = %f\n",
 			//~ s_amortissement->num_echeance, s_amortissement->capital_du, s_amortissement->principal, s_amortissement->interets);
-    }
+	}
 
     bet_finance_struct_amortization_free (s_amortissement);
     g_date_free (date);
