@@ -82,7 +82,7 @@ struct _BetFormOrganization
  * for now, this list if filled at the opening of grisbi and never erased */
 static GSList *bet_schedul_element_list = NULL;
 
-/** contains a list of struct_element according to the current form */
+/** contains a list of FormElement according to the current form */
 static GSList *bet_form_list_widgets = NULL;
 
 static GtkWidget *bet_futur_dialog = NULL;
@@ -475,7 +475,7 @@ static gboolean bet_form_clean (gint account_number)
 
     while (tmp_list)
     {
-        struct_element *element;
+        FormElement *element;
 
         element = tmp_list->data;
 
@@ -511,7 +511,7 @@ static gboolean bet_form_clean (gint account_number)
 
     while (tmp_list)
     {
-        struct_element *element;
+        FormElement *element;
 
         element = tmp_list->data;
 
@@ -826,16 +826,18 @@ static gboolean bet_form_create_current_form (GtkWidget *dialog,
     gint element_number;
     gint row = 2;
     gint column = 0;
-    struct_element *element;
     GSList *tmp_list;
+    FormElement *element;
+	GrisbiWinEtat *w_etat;
 
+	w_etat = grisbi_win_get_w_etat ();
     account_number = gsb_gui_navigation_get_current_account ();
 
     element_number = TRANSACTION_FORM_DATE;
     widget = gsb_calendar_entry_new (FALSE);
     gtk_widget_show (widget);
     gtk_grid_attach (GTK_GRID (table), widget, column, row, 1, 1);
-    element = g_malloc0 (sizeof (struct_element));
+    element = g_malloc0 (sizeof (FormElement));
     element->element_number = element_number;
     element->element_widget = widget;
     bet_form_list_widgets = g_slist_append (bet_form_list_widgets, element);
@@ -845,13 +847,13 @@ static gboolean bet_form_create_current_form (GtkWidget *dialog,
 	tmp_list = gsb_data_payee_get_name_and_report_list ();
 	widget = gtk_combofix_new_with_properties (tmp_list,
 											   TRUE,							/* on ne peut pas créer d'item */
-											   etat.combofix_case_sensitive,
+											   w_etat->combofix_case_sensitive,
 											   FALSE,
 											   METATREE_PAYEE);
 	gsb_data_payee_free_name_and_report_list (tmp_list);
     gtk_widget_show (widget);
     gtk_grid_attach (GTK_GRID (table), widget, column, row, 1, 1);
-    element = g_malloc0 (sizeof (struct_element));
+    element = g_malloc0 (sizeof (FormElement));
     element->element_number = element_number;
     element->element_widget = widget;
     bet_form_list_widgets = g_slist_append (bet_form_list_widgets, element);
@@ -867,7 +869,7 @@ static gboolean bet_form_create_current_form (GtkWidget *dialog,
 					  NULL);
     gtk_widget_show (widget);
     gtk_grid_attach (GTK_GRID (table), widget, column, row, 1, 1);
-    element = g_malloc0 (sizeof (struct_element));
+    element = g_malloc0 (sizeof (FormElement));
     element->element_number = element_number;
     element->element_widget = widget;
     bet_form_list_widgets = g_slist_append (bet_form_list_widgets, element);
@@ -883,7 +885,7 @@ static gboolean bet_form_create_current_form (GtkWidget *dialog,
 		              NULL);
     gtk_widget_show (widget);
     gtk_grid_attach (GTK_GRID (table), widget, column, row, 1, 1);
-    element = g_malloc0 (sizeof (struct_element));
+    element = g_malloc0 (sizeof (FormElement));
     element->element_number = element_number;
     element->element_widget = widget;
     bet_form_list_widgets = g_slist_append (bet_form_list_widgets, element);
@@ -896,7 +898,7 @@ static gboolean bet_form_create_current_form (GtkWidget *dialog,
 					  _("Choose the financial year"));
     gtk_widget_show (widget);
     gtk_grid_attach (GTK_GRID (table), widget, column, row, 1, 1);
-    element = g_malloc0 (sizeof (struct_element));
+    element = g_malloc0 (sizeof (FormElement));
     element->element_number = element_number;
     element->element_widget = widget;
     bet_form_list_widgets = g_slist_append (bet_form_list_widgets, element);
@@ -906,13 +908,13 @@ static gboolean bet_form_create_current_form (GtkWidget *dialog,
 	tmp_list = gsb_data_category_get_name_list (TRUE, TRUE, TRUE, TRUE);
 	widget = gtk_combofix_new_with_properties (tmp_list,
 											   TRUE,							/* on ne peut pas créer d'item */
-											   etat.combofix_case_sensitive,
-											   etat.combofix_mixed_sort,
+											   w_etat->combofix_case_sensitive,
+											   w_etat->combofix_mixed_sort,
 											   METATREE_CATEGORY);
 	gsb_data_categorie_free_name_list (tmp_list);
     gtk_widget_show (widget);
     gtk_grid_attach (GTK_GRID (table), widget, column, row, 1, 1);
-    element = g_malloc0 (sizeof (struct_element));
+    element = g_malloc0 (sizeof (FormElement));
     element->element_number = element_number;
     element->element_widget = widget;
     bet_form_list_widgets = g_slist_append (bet_form_list_widgets, element);
@@ -928,7 +930,7 @@ static gboolean bet_form_create_current_form (GtkWidget *dialog,
     gtk_widget_show (widget);
     gtk_grid_attach (GTK_GRID (table), widget, column, row, 1, 1);
 
-    element = g_malloc0 (sizeof (struct_element));
+    element = g_malloc0 (sizeof (FormElement));
     element->element_number = element_number;
     element->element_widget = widget;
     bet_form_list_widgets = g_slist_append (bet_form_list_widgets, element);
@@ -939,13 +941,13 @@ static gboolean bet_form_create_current_form (GtkWidget *dialog,
 	tmp_list = gsb_data_budget_get_name_list (TRUE, TRUE);
 	widget = gtk_combofix_new_with_properties (tmp_list,
 											   TRUE,							/* on ne peut pas créer d'item */
-											   etat.combofix_case_sensitive,
-											   etat.combofix_mixed_sort,
+											   w_etat->combofix_case_sensitive,
+											   w_etat->combofix_mixed_sort,
 											   METATREE_BUDGET);
 	gsb_data_categorie_free_name_list (tmp_list);
     gtk_widget_show (widget);
     gtk_grid_attach (GTK_GRID (table), widget, column, row, 1, 1);
-    element = g_malloc0 (sizeof (struct_element));
+    element = g_malloc0 (sizeof (FormElement));
     element->element_number = element_number;
     element->element_widget = widget;
     bet_form_list_widgets = g_slist_append (bet_form_list_widgets, element);
@@ -956,7 +958,7 @@ static gboolean bet_form_create_current_form (GtkWidget *dialog,
 	widget = gtk_entry_new();
     gtk_widget_show (widget);
     gtk_grid_attach (GTK_GRID (table), widget, column, row, 4, 1);
-    element = g_malloc0 (sizeof (struct_element));
+    element = g_malloc0 (sizeof (FormElement));
     element->element_number = element_number;
     element->element_widget = widget;
     bet_form_list_widgets = g_slist_append (bet_form_list_widgets, element);
@@ -965,7 +967,7 @@ static gboolean bet_form_create_current_form (GtkWidget *dialog,
 
     while (tmp_list)
     {
-        struct_element *element_list;
+        FormElement *element_list;
 
         element_list = tmp_list->data;
 
@@ -1060,7 +1062,7 @@ static gboolean bet_form_create_scheduler_part (GtkWidget *dialog,
 										  N_("Quarterly"), N_("Yearly"), N_("Custom"), NULL };
 	    const gchar *text_frequency_user [] = { N_("Days"), N_("Weeks"), N_("Months"), N_("Years"), NULL };
         gint element_number;
-        struct_element *element;
+        FormElement *element;
 
         /* on tient compte que le premier widget utile est le troisième du formulaire */
 	    element_number = column + 2;
@@ -1141,7 +1143,7 @@ static gboolean bet_form_create_scheduler_part (GtkWidget *dialog,
             gtk_widget_set_tooltip_text (GTK_WIDGET (widget), tooltip_text);
 
         /* save the element */
-	    element = g_malloc0 (sizeof (struct_element));
+	    element = g_malloc0 (sizeof (FormElement));
 	    element->element_number = element_number;
 	    element->element_widget = widget;
 	    bet_schedul_element_list = g_slist_append (bet_schedul_element_list, element);
@@ -1449,22 +1451,22 @@ void bet_utils_get_payment_data (GtkWidget *widget,
 								 gpointer *value)
 {
     gint payment_number;
-    TransfertData *sd = (TransfertData *) value;
+    TransfertData *std = (TransfertData *) value;
 
     payment_number = gsb_payment_method_get_selected_number (widget);
     if (payment_number > 0)
     {
 		if (struct_type == 1)
-        	sd->main_payment_number = payment_number;
+        	std->main_payment_number = payment_number;
 		else
-			sd->card_payment_number = payment_number;
+			std->card_payment_number = payment_number;
     }
     else
     {
 		if (struct_type == 1)
-        	sd->main_payment_number = gsb_data_account_get_default_debit (sd->account_number);
+        	std->main_payment_number = gsb_data_account_get_default_debit (std->main_account_number);
 		else
-			sd->card_payment_number = gsb_data_account_get_default_credit (sd->replace_account);
+			std->card_payment_number = gsb_data_account_get_default_credit (std->card_account_number);
     }
 }
 
@@ -1482,6 +1484,8 @@ void bet_utils_get_payment_data (GtkWidget *widget,
 static GtkWidget *bet_future_create_dialog (gint account_number)
 {
     GtkWidget *dialog;
+	GtkWidget *button_cancel;
+	GtkWidget *button_OK;
     GtkWidget *vbox;
     GtkWidget *table;
 
@@ -1489,13 +1493,20 @@ static GtkWidget *bet_future_create_dialog (gint account_number)
     dialog = gtk_dialog_new_with_buttons (_("Enter a budget line"),
 										  GTK_WINDOW (grisbi_app_get_active_window (NULL)),
 										  GTK_DIALOG_MODAL,
-										  "gtk-cancel", GTK_RESPONSE_CANCEL,
-										  "gtk-ok", GTK_RESPONSE_OK,
+										  NULL, NULL,
 										  NULL);
 
+	button_cancel = gtk_button_new_with_label (_("Cancel"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_cancel, GTK_RESPONSE_CANCEL);
+	gtk_widget_set_can_default (button_cancel, TRUE);
+
+	button_OK = gtk_button_new_with_label (_("Validate"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_OK, GTK_RESPONSE_OK);
+	gtk_widget_set_can_default (button_OK, TRUE);
+    gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
+
     gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ON_PARENT);
     gtk_window_set_resizable (GTK_WINDOW (dialog), TRUE);
-    gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
 	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_box_pack_start (GTK_BOX (dialog_get_content_area (dialog)), vbox, TRUE, TRUE, 0);
@@ -1510,7 +1521,7 @@ static GtkWidget *bet_future_create_dialog (gint account_number)
     bet_form_create_scheduler_part (dialog, table);
     bet_form_create_current_form (dialog, table, account_number);
 
-	gtk_widget_show (vbox);
+	gtk_widget_show_all (dialog);
 
     return dialog;
 }
@@ -1533,9 +1544,22 @@ static gboolean bet_future_set_form_data_from_line (gint account_number,
     FuturData *scheduled;
 
     if (account_number == 0)
-        key = g_strconcat ("0:", utils_str_itoa (number), NULL);
+	{
+		gchar *tmp_str1;
+		tmp_str1 = utils_str_itoa (number);
+        key = g_strconcat ("0:", tmp_str1, NULL);
+		g_free(tmp_str1);
+	}
     else
-        key = g_strconcat (utils_str_itoa (account_number), ":", utils_str_itoa (number), NULL);
+	{
+		gchar *tmp_str1;
+		gchar *tmp_str2;
+		tmp_str1 = utils_str_itoa (account_number);
+		tmp_str2 = utils_str_itoa (number);
+        key = g_strconcat (tmp_str1, ":", tmp_str2, NULL);
+		g_free(tmp_str1);
+		g_free(tmp_str2);
+	}
 
     future_list = bet_data_future_get_list ();
 
@@ -1902,7 +1926,7 @@ dialog_return:
     {
         FuturData *scheduled;
 
-        scheduled = struct_initialise_bet_future ();
+        scheduled = bet_data_future_struct_init ();
 
         if (!scheduled)
         {
@@ -1917,6 +1941,7 @@ dialog_return:
                                  "not specified or the date is invalid."));
             dialogue_warning_hint (tmp_str, _("One field is not filled in"));
             g_free (tmp_str);
+			bet_data_future_struct_free(scheduled);
             goto dialog_return;
         }
         else
@@ -1965,7 +1990,7 @@ dialog_return:
     {
         FuturData *scheduled;
 
-        scheduled = struct_initialise_bet_future ();
+        scheduled = bet_data_future_struct_init ();
 
         if (!scheduled)
         {
@@ -1980,6 +2005,7 @@ dialog_return:
 								  "not specified or the date is invalid."));
             dialogue_warning_hint (tmp_str, _("One field is not filled in"));
             g_free (tmp_str);
+			bet_data_future_struct_free(scheduled);
             goto dialog_return;
         }
         else
@@ -2143,10 +2169,10 @@ dialog_return:
     if (result == GTK_RESPONSE_OK)
     {
         gchar *tmp_str;
-        TransfertData *transfert;
+        TransfertData *std;
 
-		transfert = widget_transfer_take_data (transfer_dialog, account_number, number);
-        if (!transfert)
+		std = widget_transfer_take_data (transfer_dialog, account_number, number);
+        if (!std)
         {
             tmp_str = g_strdup (_("Error: a date is not present or a field is in error."));
             dialogue_warning_hint (tmp_str, _("One field is not filled in"));
@@ -2155,7 +2181,7 @@ dialog_return:
         }
         else
         {
-            bet_data_transfert_modify_line (transfert);
+            bet_data_transfert_modify_line (std);
         }
 
         gsb_data_account_set_bet_maj (account_number, BET_MAJ_ESTIMATE);
@@ -2165,13 +2191,13 @@ dialog_return:
 	{
 		gchar *msg;
 		const gchar *tmp_str;
-		TransfertData *transfert;
+		TransfertData *std;
 
-		transfert = bet_data_transfert_get_struct_from_number (number);
-		if (transfert->type == 0)
-			tmp_str = gsb_data_account_get_name ( transfert->replace_account );
+		std = bet_data_transfert_get_struct_from_number (number);
+		if (std->type == 0)
+			tmp_str = gsb_data_account_get_name ( std->card_account_number );
 		else
-			tmp_str = gsb_data_partial_balance_get_name ( transfert->replace_account );
+			tmp_str = gsb_data_partial_balance_get_name ( std->card_account_number );
 
 		msg = g_strdup_printf (_("Warning: You are about to delete the deferred debit card: \"%s\"\n"
 								 "Are you sure?"),
