@@ -12,6 +12,8 @@ gboolean 	csv_import_parse_budget 		(struct ImportTransaction *ope,
 											 gchar *string);
 gboolean 	csv_import_parse_category 		(struct ImportTransaction *ope,
 											 gchar *string);
+gboolean 	csv_import_parse_cheque 		(struct ImportTransaction *ope,
+											 gchar *string);
 gboolean 	csv_import_parse_credit 		(struct ImportTransaction *ope,
 											 gchar *string);
 gboolean 	csv_import_parse_currency 		(struct ImportTransaction *ope,
@@ -20,12 +22,16 @@ gboolean 	csv_import_parse_date 			(struct ImportTransaction *ope,
 											 gchar *string);
 gboolean 	csv_import_parse_debit 			(struct ImportTransaction *ope,
 											 gchar *string);
+GSList *	csv_import_parse_line 			(gchar **contents,
+											 const gchar *separator);
 gboolean 	csv_import_parse_notes 			(struct ImportTransaction *ope,
 											 gchar *string);
 gboolean 	csv_import_parse_p_r 			(struct ImportTransaction *ope,
 											 gchar *string);
 gboolean 	csv_import_parse_payee 			(struct ImportTransaction *ope,
 											 gchar *string);
+gboolean 	csv_import_parse_payment_method	(struct ImportTransaction *ope,
+											 gchar *string);
 gboolean 	csv_import_parse_split 			(struct ImportTransaction *ope,
 											 gchar *string);
 gboolean 	csv_import_parse_sub_budget 	(struct ImportTransaction *ope,
@@ -34,14 +40,10 @@ gboolean 	csv_import_parse_sub_category 	(struct ImportTransaction *ope,
 											 gchar *string);
 gboolean 	csv_import_parse_value_date 	(struct ImportTransaction *ope,
 											 gchar *string);
-gboolean 	csv_import_parse_cheque 		(struct ImportTransaction *ope,
-											 gchar *string);
 gboolean 	csv_import_validate_amount 		(gchar *string);
 gboolean 	csv_import_validate_date 		(gchar *string);
 gboolean 	csv_import_validate_number 		(gchar *string);
 gboolean 	csv_import_validate_string 		(gchar *string);
-GSList *	csv_parse_line 					(gchar **contents,
-											 const gchar *separator);
 /* END_DECLARATION */
 
 #endif
