@@ -121,8 +121,9 @@ static GtkWidget *debug_print_backtrace ( void )
     {
 	g_print ("\t%s\n", backtrace_strings[i]);
 	gchar* old_text = text;
-	text = g_strconcat ( text, g_strconcat ( "\t", backtrace_strings[i], "\n", NULL ),
-			     NULL );
+	gchar *tmp_str = g_strconcat ( "\t", backtrace_strings[i], "\n", NULL );
+	text = g_strconcat ( text, tmp_str, NULL );
+	g_free(tmp_str);
 	g_free ( old_text );
     }
 
@@ -154,6 +155,7 @@ void debug_traitement_sigsegv ( gint signal_nb )
     GtkWidget *expander;
     GtkWidget *scrolled_window;
 #endif
+	GrisbiWinRun *w_run;
 
 	switch ( signal_nb )
 	{
@@ -184,8 +186,8 @@ void debug_traitement_sigsegv ( gint signal_nb )
     /*     soit on était en train de charger un fichier, c'est que celui-ci est corrompu */
     /* soit on était en train de sauver un fichier, et là on peut rien faire */
     /* sinon on essaie de sauver le fichier sous le nom entouré de # */
-
-    if (file_is_loading || run.file_is_saving || !gsb_file_get_modified ())
+	w_run = (GrisbiWinRun *) grisbi_win_get_w_run ();
+    if (file_is_loading || w_run->file_is_saving || !gsb_file_get_modified ())
     {
 		if (file_is_loading )
 		{
@@ -194,7 +196,7 @@ void debug_traitement_sigsegv ( gint signal_nb )
 			g_free ( old_errmsg );
 		}
 
-		if ( run.file_is_saving )
+		if ( w_run->file_is_saving )
 		{
 			old_errmsg = errmsg;
 			errmsg = g_strconcat ( errmsg, _("Error occurred saving file."), NULL );
@@ -227,10 +229,12 @@ void debug_traitement_sigsegv ( gint signal_nb )
 		grisbi_win_status_bar_clear();
 
 		old_errmsg = errmsg;
+		tmp_str = g_strdup_printf ( _("Grisbi made a backup file at '%s'."),
+								   nom_fichier_comptes );
 		errmsg = g_strconcat ( errmsg,
-							  g_strdup_printf ( _("Grisbi made a backup file at '%s'."),
-											   nom_fichier_comptes ),
+							  tmp_str,
 							  NULL );
+		g_free(tmp_str);
 		g_free ( old_errmsg );
 		g_free (nom_fichier_comptes);
     }
@@ -410,24 +414,38 @@ void debug_message_string ( const gchar *prefixe,
     if (level <= debugging_grisbi || force_debug_display || debug_mode)
     {
         gchar* tmp_str;
+		GLogLevelFlags log_level;
 
-        /* on affiche dans la console le message */
-        if (message)
-            tmp_str = g_strdup_printf(_("%s, %2f : %s - %s:%d:%s - %s\n"),
-                        debug_get_debug_time (), (clock() + 0.0)/ CLOCKS_PER_SEC, prefixe,
+        if (NULL == message)
+			message = "";
+
+		tmp_str = g_strdup_printf("%2f : %s - %s:%d:%s - %s",
+                        (clock() + 0.0)/ CLOCKS_PER_SEC, prefixe,
                         file, line, function, message);
-        else
-            tmp_str = g_strdup_printf(_("%s, %2f : %s - %s:%d:%s\n"),
-                        debug_get_debug_time (), (clock() + 0.0)/ CLOCKS_PER_SEC, prefixe,
-                        file, line, function);
 
         if ( debug_mode && debug_file)
         {
-            fwrite ( tmp_str, sizeof (gchar), strlen ( tmp_str ), debug_file );
+			gchar *tmp_str2;
+			tmp_str2 = g_strdup_printf("%s %s\n", debug_get_debug_time (), tmp_str);
+            fwrite ( tmp_str2, sizeof (gchar), strlen ( tmp_str2 ), debug_file );
+			g_free(tmp_str2);
             fflush ( debug_file );
         }
 
-        g_print ("%s", tmp_str);
+		/* on affiche dans la console le message */
+		switch (level)
+		{
+			case DEBUG_LEVEL_ALERT:
+				log_level = G_LOG_LEVEL_CRITICAL;
+				break;
+			case DEBUG_LEVEL_IMPORTANT:
+				log_level = G_LOG_LEVEL_WARNING;
+				break;
+			default:
+				log_level = G_LOG_LEVEL_MESSAGE;
+		}
+        g_log (NULL, log_level, "%s", tmp_str);
+
         g_free ( tmp_str );
     }
 }
@@ -579,7 +597,7 @@ gboolean debug_start_log ( void )
 
 		debug_mode = TRUE;
         /* début du mode de débogage */
-        tmp_str = g_strdup_printf(_("%s, %2f : Debug - %s:%d:%s\n\n"),
+        tmp_str = g_strdup_printf("%s, %2f : Debug - %s:%d:%s\n\n",
                         debug_get_debug_time ( ),
                         (clock() + 0.0)/ CLOCKS_PER_SEC,
                         __FILE__,
@@ -652,44 +670,6 @@ void debug_finish_log ( void )
 }
 
 
-/**
- *
- *
- *
- */
-void debug_print_log_string ( const gchar *prefixe,
-                        const gchar *file,
-                        gint line,
-                        const char *function,
-                        const gchar *msg )
-{
-    gchar *tmp_str;
-    gchar *message;
-
-    if ( debug_file == NULL )
-        return;
-
-    if ( msg && strlen ( msg ) )
-        message = g_strdup ( msg );
-    else
-        message = g_strdup ( "(null)" );
-
-    tmp_str = g_strdup_printf(_("%s, %2f : %s - %s:%d:%s - %s\n"),
-                        debug_get_debug_time ( ),
-                        (clock() + 0.0) / CLOCKS_PER_SEC,
-                        prefixe,
-                        file,
-                        line,
-                        function,
-                        message );
-
-    fwrite ( tmp_str, sizeof (gchar), strlen ( tmp_str ), debug_file );
-    fflush ( debug_file );
-
-    g_free ( tmp_str );
-    g_free ( message );
-}
-
 /**
  *
  *
