@@ -11,8 +11,6 @@
 gboolean	affichage_etat 							(gint report_number,
 													 struct EtatAffichage *affichage,
 													 gchar *filename);
-gint 		cherche_string_equivalente_dans_slist 	(gchar *string_list,
-													 gchar *string_cmp);
 void 		denote_struct_sous_jaccentes 			(gint origine);
 gboolean	rafraichissement_etat 					(gint report_number);
 GSList *	recupere_opes_etat 						(gint report_number);
