@@ -201,8 +201,10 @@ gchar*  csv_field_info_bank  = NULL; /*!< bank references (string) */
 static gchar *csv_real_get_string_from_us_option (GsbReal number)
 {
 	gchar *tmp_str;
+	GrisbiWinEtat *w_etat;
 
-	if (etat.export_force_US_numbers)
+	w_etat = grisbi_win_get_w_etat ();
+	if (w_etat->export_force_US_numbers)
 	{
 		tmp_str = utils_real_get_string_intl (number);
 	}
@@ -479,7 +481,9 @@ static gboolean gsb_csv_export_transaction (gint transaction_number,
 	gint financial_year_number;
 	gint payment_method;
 	gint reconcile_number;
+	GrisbiWinEtat *w_etat;
 
+	w_etat = grisbi_win_get_w_etat ();
     account_number = gsb_data_transaction_get_account_number (transaction_number);
 
     /* Si c'est une ventilation d'opération (càd une opération fille),
@@ -494,8 +498,8 @@ static gboolean gsb_csv_export_transaction (gint transaction_number,
 	date = gsb_data_transaction_get_date (transaction_number);
 	if (date)
 	{
-	    CSV_CLEAR_FIELD (csv_field_date);
-		if (etat.export_force_US_dates)
+		CSV_CLEAR_FIELD (csv_field_date);
+		if (w_etat->export_force_US_dates)
 		{
 			csv_field_date = gsb_format_gdate_safe (date);
 		}
@@ -512,7 +516,7 @@ static gboolean gsb_csv_export_transaction (gint transaction_number,
 	if (value_date)
 	{
 	    CSV_CLEAR_FIELD (csv_field_date_val);
-		if (etat.export_force_US_dates)
+		if (w_etat->export_force_US_dates)
 		{
 			csv_field_date_val = gsb_format_gdate_safe (date);
 		}
@@ -591,7 +595,7 @@ static gboolean gsb_csv_export_transaction (gint transaction_number,
 		gint sub_budgetary_number;
 
 	    CSV_CLEAR_FIELD (csv_field_imput);
-	    csv_field_imput = my_strdup (gsb_data_budget_get_name (budgetary_number, 0, ""));
+	    csv_field_imput = gsb_data_budget_get_name (budgetary_number, 0, "");
 
 		sub_budgetary_number = gsb_data_transaction_get_sub_budgetary_number (transaction_number);
 	    if (sub_budgetary_number != -1)
@@ -667,11 +671,14 @@ static gboolean gsb_csv_export_transaction (gint transaction_number,
 				contra_transaction_number = gsb_data_transaction_get_contra_transaction_number (pSplitTransaction);
 				if (contra_transaction_number > 0)
 				{
+					gint tmp_account_number;
+
 					/* c'est un virement */
 					CSV_CLEAR_FIELD (csv_field_categ);
 					csv_field_categ = my_strdup (_("Transfer"));
 
-					tmp_str = g_strconcat ("[", gsb_data_account_get_name (contra_transaction_number), "]", NULL);
+					tmp_account_number = gsb_data_transaction_get_account_number (contra_transaction_number);
+					tmp_str = g_strconcat ("[", gsb_data_account_get_name (tmp_account_number), "]", NULL);
 
 					/* TODO dOm : is it necessary to duplicate memory with my_strdup since it was already newly allocated memory ? */
 					CSV_CLEAR_FIELD (csv_field_sous_categ);
@@ -686,7 +693,7 @@ static gboolean gsb_csv_export_transaction (gint transaction_number,
 						gint sub_category_number;
 
 						CSV_CLEAR_FIELD (csv_field_categ);
-						csv_field_categ = my_strdup (gsb_data_category_get_name (category_number, 0, ""));
+						csv_field_categ = gsb_data_category_get_name (category_number, 0, "");
 
 						sub_category_number = gsb_data_transaction_get_sub_category_number (pSplitTransaction);
 						if (sub_category_number != -1)
@@ -738,7 +745,7 @@ static gboolean gsb_csv_export_transaction (gint transaction_number,
 					gint sub_budgetary_number;
 
 					CSV_CLEAR_FIELD (csv_field_imput);
-					csv_field_imput = my_strdup (gsb_data_budget_get_name (budgetary_number, 0, ""));
+					csv_field_imput = gsb_data_budget_get_name (budgetary_number, 0, "");
 
 					sub_budgetary_number = gsb_data_transaction_get_sub_budgetary_number (pSplitTransaction);
 					if (sub_budgetary_number != -1)
@@ -785,7 +792,7 @@ static gboolean gsb_csv_export_transaction (gint transaction_number,
 					gint sub_category_number;
 
 					CSV_CLEAR_FIELD (csv_field_categ);
-					csv_field_categ = my_strdup (gsb_data_category_get_name (category_number, 0, ""));
+					csv_field_categ = gsb_data_category_get_name (category_number, 0, "");
 
 					sub_category_number = gsb_data_transaction_get_sub_category_number (transaction_number);
 					if (sub_category_number != -1)
