@@ -29,15 +29,18 @@
 
 /*START_INCLUDE*/
 #include "gsb_account.h"
+#include "bet_data.h"
 #include "categories_onglet.h"
 #include "dialog.h"
 #include "grisbi_win.h"
-#include "gsb_account_property.h"
 #include "gsb_category.h"
 #include "gsb_data_account.h"
 #include "gsb_data_currency.h"
 #include "gsb_data_import_rule.h"
+#include "gsb_data_partial_balance.h"
 #include "gsb_data_payment.h"
+#include "gsb_data_reconcile.h"
+#include "gsb_data_report.h"
 #include "gsb_data_scheduled.h"
 #include "gsb_data_transaction.h"
 #include "gsb_file.h"
@@ -53,6 +56,7 @@
 #include "traitement_variables.h"
 #include "transaction_list.h"
 #include "utils_str.h"
+#include "widget_account_property.h"
 #include "erreur.h"
 /*END_INCLUDE*/
 
@@ -84,6 +88,7 @@ gboolean gsb_account_new ( KindAccount account_type,
 {
     gint account_number;
     GtkWidget *notebook_general;
+	GrisbiWinRun *w_run;
 
     /*     create the new account */
     account_number = gsb_data_account_new (account_type);
@@ -106,7 +111,6 @@ gboolean gsb_account_new ( KindAccount account_type,
         if (pixbuf)
 		{
             gsb_data_account_set_account_icon_pixbuf ( account_number, pixbuf );
-			g_object_unref (G_OBJECT (pixbuf));
 		}
     }
 
@@ -122,7 +126,8 @@ gboolean gsb_account_new ( KindAccount account_type,
     gsb_data_account_set_name (account_number, name);
 
     /* update the main page */
-    run.mise_a_jour_liste_comptes_accueil = TRUE;
+	w_run = (GrisbiWinRun *) grisbi_win_get_w_run ();
+    w_run->mise_a_jour_liste_comptes_accueil = TRUE;
 
     /* update the accounts lists */
 	grisbi_win_menu_move_to_acc_delete ();
@@ -148,7 +153,7 @@ gboolean gsb_account_new ( KindAccount account_type,
         gtk_notebook_set_current_page ( GTK_NOTEBOOK ( grisbi_win_get_account_page () ),
                         GSB_PROPERTIES_PAGE );
 
-        gsb_account_property_fill_page ();
+        widget_account_property_fill ();
     }
 
     gsb_file_set_modified ( TRUE );
@@ -171,6 +176,7 @@ gboolean gsb_account_delete ( void )
     gint page_number;
     GSList *list_tmp;
 	gchar* tmpstr;
+	GrisbiWinRun *w_run;
 
     deleted_account = gsb_gui_navigation_get_current_account ();
     devel_debug_int (deleted_account);
@@ -189,7 +195,7 @@ gboolean gsb_account_delete ( void )
     g_free ( tmpstr );
 
     /* if the last account, close the file */
-    if ( gsb_data_account_get_accounts_amount () == 1 )
+    if ( gsb_data_account_get_number_of_accounts () == 1 )
     {
         gsb_file_set_modified ( FALSE );
         (void)gsb_file_close ();
@@ -252,6 +258,15 @@ gboolean gsb_account_delete ( void )
         list_tmp = list_tmp -> next;
     }
 
+	/* delete reconciles */
+	gsb_data_reconcile_remove_from_account (deleted_account);
+
+	/* delete account in partial_balance */
+	gsb_partial_balance_remove_from_account (deleted_account);
+
+	/* delete elements of the bet module */
+	bet_data_remove_all_bet_data (deleted_account);
+
 	/* delete the rules if necessary */
 	list_tmp = gsb_data_import_rule_get_from_account (deleted_account);
 	if (list_tmp)
@@ -268,6 +283,9 @@ gboolean gsb_account_delete ( void )
 		g_slist_free (list_tmp);
 	}
 
+	/* delete account in reports */
+	gsb_data_report_remove_from_account (deleted_account);
+
     /* delete the account */
     gsb_data_account_delete ( deleted_account );
 
@@ -294,10 +312,11 @@ gboolean gsb_account_delete ( void )
     /* update the name of accounts in form */
     gsb_account_update_combo_list ( gsb_form_scheduler_get_element_widget (SCHEDULED_FORM_ACCOUNT), FALSE );
 
-    run.mise_a_jour_liste_echeances_manuelles_accueil = TRUE;
-    run.mise_a_jour_liste_comptes_accueil = TRUE;
-    run.mise_a_jour_soldes_minimaux = TRUE;
-    run.mise_a_jour_fin_comptes_passifs = TRUE;
+	w_run = (GrisbiWinRun *) grisbi_win_get_w_run ();
+    w_run->mise_a_jour_liste_echeances_manuelles_accueil = TRUE;
+    w_run->mise_a_jour_liste_comptes_accueil = TRUE;
+    w_run->mise_a_jour_soldes_minimaux = TRUE;
+    w_run->mise_a_jour_fin_comptes_passifs = TRUE;
 
     gsb_file_set_modified ( TRUE );
 
