@@ -2,7 +2,7 @@
 /*                                                                            */
 /*     Copyright (C)    2000-2007 Cédric Auger (cedric@grisbi.org)            */
 /*          2003-2008 Benjamin Drieu (bdrieu@april.org)                       */
-/*          https://www.grisbi.org/                                            */
+/*          https://www.grisbi.org/                                           */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -52,7 +52,7 @@
 /*END_INCLUDE*/
 
 
-enum archive_export_assistant_page
+enum ArchiveExportAssistantPage
 {
     ARCHIVE_EXPORT_ASSISTANT_INTRO= 0,
     ARCHIVE_EXPORT_ASSISTANT_CHOOSE,
@@ -61,7 +61,7 @@ enum archive_export_assistant_page
 };
 
 /** Columns for payment methods tree */
-enum archives_export_columns {
+enum ArchiveExportColumns {
     ARCHIVES_EXPORT_SELECT_COLUMN = 0,
     ARCHIVES_EXPORT_NAME_COLUMN,
     ARCHIVES_EXPORT_INIT_DATE,
@@ -355,7 +355,7 @@ static gboolean gsb_assistant_archive_switch ( GtkWidget *assistant,
 {
     gint archive_number;
     GtkTreeModel *model;
-    const gchar *export_name;
+    gchar *export_name;
     gboolean success = FALSE;
     gchar* tmpstr;
 	GrisbiAppConf *a_conf;
@@ -410,7 +410,9 @@ static gboolean gsb_assistant_archive_switch ( GtkWidget *assistant,
             /* on vérifie juste que l'extension existe */
             if ( ! g_strrstr ( export_name, ".gsb" ) )
             {
-               export_name = g_strconcat ( export_name, ".gsb", NULL );
+				tmpstr = g_strconcat ( export_name, ".gsb", NULL );
+				g_free(export_name);
+				export_name = tmpstr;
             }
 		    success = gsb_file_util_test_overwrite (export_name)
 			&&
@@ -421,7 +423,9 @@ static gboolean gsb_assistant_archive_switch ( GtkWidget *assistant,
 		    /* QIF format */
             if ( ! g_strrstr ( export_name, ".qif" ) )
             {
-               export_name = g_strconcat ( export_name, ".qif", NULL );
+				tmpstr = g_strconcat ( export_name, ".qif", NULL );
+				g_free(export_name);
+				export_name = tmpstr;
             }
 		    success = gsb_qif_export_archive ( export_name, archive_number);
 		    break;
@@ -430,11 +434,14 @@ static gboolean gsb_assistant_archive_switch ( GtkWidget *assistant,
 		    /* CSV format */
             if ( ! g_strrstr ( export_name, ".csv" ) )
             {
-               export_name = g_strconcat ( export_name, ".csv", NULL );
+				tmpstr = g_strconcat ( export_name, ".csv", NULL );
+				g_free(export_name);
+				export_name = tmpstr;
             }
 		    success = gsb_csv_export_archive ( export_name, archive_number);
 		    break;
 	    }
+		g_free(export_name);
 	    /* now success = TRUE or FALSE, show the good final page of assistant */
 	    if (success)
 		gtk_label_set_text ( GTK_LABEL (archive_export_label_success),
