@@ -70,17 +70,17 @@
  * \param button The reference GtkCheckButton
  * \param default_func the function to call to change the value in memory
  *
- * \return FALSE
- */
-static gboolean gsb_autofunc_checkbutton_changed (GtkWidget *button,
-												  gboolean default_func (gint,
-																		 gboolean))
+ * \return
+ **/
+static void gsb_autofunc_checkbutton_changed (GtkWidget *button,
+											  gboolean default_func (gint,
+																	 gboolean))
 {
     gint number_for_func;
 
     /* just to be sure... */
-    if (!default_func || !button)
-		return FALSE;
+	if (!default_func || !button)
+		return;
 
     number_for_func = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (button), "number_for_func"));
     default_func (number_for_func, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)));
@@ -88,7 +88,7 @@ static gboolean gsb_autofunc_checkbutton_changed (GtkWidget *button,
     /* Mark file as modified */
     gsb_file_set_modified (TRUE);
 
-    return FALSE;
+    return;
 }
 
 /**
@@ -97,25 +97,23 @@ static gboolean gsb_autofunc_checkbutton_changed (GtkWidget *button,
  * \param combobox The reference Combobox
  * \param default_func the function to call to change the value in memory
  *
- * \return FALSE
- */
-static gboolean gsb_autofunc_combobox_changed (GtkWidget *combobox,
-											   gboolean default_func (gint,
-																	  gint))
+ * \return
+ **/
+static void gsb_autofunc_combobox_changed (GtkWidget *combobox,
+											gboolean default_func (gint,
+																   gint))
 {
     gint number_for_func;
 
     /* just to be sure... */
-    if (!default_func || !combobox)
-		return FALSE;
+	if (!default_func || !combobox)
+		return;
 
     number_for_func = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (combobox), "number_for_func"));
     default_func (number_for_func, gsb_combo_box_get_index (combobox));
 
     /* Mark file as modified */
     gsb_file_set_modified (TRUE);
-
-	return FALSE;
 }
 
 /**
@@ -124,25 +122,23 @@ static gboolean gsb_autofunc_combobox_changed (GtkWidget *combobox,
  * \param combobox The reference Combobox
  * \param default_func the function to call to change the value in memory
  *
- * \return FALSE
- */
-static gboolean gsb_autofunc_currency_changed (GtkWidget *combobox,
-											   gboolean default_func (gint,
-																	  gint))
+ * \return
+ **/
+static void gsb_autofunc_currency_changed (GtkWidget *combobox,
+										   gboolean default_func (gint,
+																  gint))
 {
     gint number_for_func;
 
     /* just to be sure... */
-    if (!default_func || !combobox)
-		return FALSE;
+	if (!default_func || !combobox)
+		return;
 
     number_for_func = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (combobox), "number_for_func"));
     default_func (number_for_func, gsb_currency_get_currency_from_combobox (combobox));
 
     /* Mark file as modified */
     gsb_file_set_modified (TRUE);
-
-    return FALSE;
 }
 
 /**
@@ -152,18 +148,18 @@ static gboolean gsb_autofunc_currency_changed (GtkWidget *combobox,
  * \param entry The reference GtkEntry
  * \param default_func the function to call to change the date in memory
  *
- * \return FALSE
- */
-static gboolean gsb_autofunc_date_changed (GtkWidget *entry,
-										   gboolean default_func (gint,
-																  const GDate *))
+ * \return
+ **/
+static void gsb_autofunc_date_changed (GtkWidget *entry,
+									   gboolean default_func (gint,
+															  const GDate *))
 {
     gint number_for_func;
     GDate *date;
 
     /* just to be sure... */
-    if (!default_func || !entry)
-		return FALSE;
+	if (!default_func || !entry)
+		return;
 
     number_for_func = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (entry), "number_for_func"));
     date = gsb_calendar_entry_get_date (entry);
@@ -175,8 +171,6 @@ static gboolean gsb_autofunc_date_changed (GtkWidget *entry,
 
     /* Mark file as modified */
     gsb_file_set_modified (TRUE);
-
-    return FALSE;
 }
 
 /**
@@ -186,25 +180,23 @@ static gboolean gsb_autofunc_date_changed (GtkWidget *entry,
  * \param entry The reference GtkEntry
  * \param default_func the function to call to change the value in memory
  *
- * \return FALSE
- */
-static gboolean gsb_autofunc_entry_changed (GtkWidget *entry,
-											gboolean default_func (gint,
-																   const gchar *))
+ * \return
+ **/
+static void gsb_autofunc_entry_changed (GtkWidget *entry,
+										gboolean default_func (gint,
+															   const gchar *))
 {
     gint number_for_func;
 
     /* just to be sure... */
-    if (!default_func || !entry)
-		return FALSE;
+	if (!default_func || !entry)
+		return;
 
     number_for_func = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (entry), "number_for_func"));
     default_func (number_for_func, gtk_entry_get_text (GTK_ENTRY (entry)));
 
     /* Mark file as modified */
     gsb_file_set_modified (TRUE);
-
-    return FALSE;
 }
 
 /**
@@ -214,25 +206,23 @@ static gboolean gsb_autofunc_entry_changed (GtkWidget *entry,
  * \param entry The reference GtkEntry
  * \param default_func the function to call to change the value in memory
  *
- * \return FALSE
- */
-static gboolean gsb_autofunc_int_changed (GtkWidget *entry,
-										  gboolean default_func (gint,
-																 gint))
+ * \return
+ **/
+static void gsb_autofunc_int_changed (GtkWidget *entry,
+									  gboolean default_func (gint,
+															 gint))
 {
     gint number_for_func;
 
     /* just to be sure... */
-    if (!default_func || !entry)
-		return FALSE;
+	if (!default_func || !entry)
+		return;
 
     number_for_func = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (entry), "number_for_func"));
     default_func (number_for_func, utils_str_atoi (gtk_entry_get_text (GTK_ENTRY (entry))));
 
     /* Mark file as modified */
     gsb_file_set_modified (TRUE);
-
-    return FALSE;
 }
 
 /**
@@ -242,25 +232,23 @@ static gboolean gsb_autofunc_int_changed (GtkWidget *entry,
  * \param entry The reference GtkEntry
  * \param default_func the function to call to change the date in memory
  *
- * \return FALSE
- */
-static gboolean gsb_autofunc_real_changed (GtkWidget *entry,
-										   gboolean default_func (gint,
-																  GsbReal))
+ * \return
+ **/
+static void gsb_autofunc_real_changed (GtkWidget *entry,
+									   gboolean default_func (gint,
+															  GsbReal))
 {
     gint number_for_func;
 
     /* just to be sure... */
     if (!default_func || !entry)
-		return FALSE;
+		return;
 
     number_for_func = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (entry), "number_for_func"));
     default_func (number_for_func, utils_real_get_from_string (gtk_entry_get_text (GTK_ENTRY (entry))));
 
     /* Mark file as modified */
     gsb_file_set_modified (TRUE);
-
-	return FALSE;
 }
 
 /**
@@ -272,23 +260,21 @@ static gboolean gsb_autofunc_real_changed (GtkWidget *entry,
  *
  * \return FALSE
  */
-static gboolean gsb_autofunc_spin_changed (GtkWidget *spin_button,
-										   gboolean default_func (gint,
-																  gint))
+static void gsb_autofunc_spin_changed (GtkWidget *spin_button,
+									   gboolean default_func (gint,
+															  gint))
 {
     gint number_for_func;
 
     /* just to be sure... */
     if (!default_func || !spin_button)
-		return FALSE;
+		return;
 
     number_for_func = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (spin_button), "number_for_func"));
     default_func (number_for_func, gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin_button)));
 
     /* Mark file as modified */
     gsb_file_set_modified (TRUE);
-
-	return FALSE;
 }
 
 /**
@@ -297,16 +283,16 @@ static gboolean gsb_autofunc_spin_changed (GtkWidget *spin_button,
  * \param buffer The reference GtkTextBuffer
  * \param dummy Handler parameter.  Not used.
  */
-static gboolean gsb_autofunc_textview_changed (GtkTextBuffer *buffer,
-											   gboolean default_func (gint,
-																	  const gchar *))
+static void gsb_autofunc_textview_changed (GtkTextBuffer *buffer,
+										   gboolean default_func (gint,
+																  const gchar *))
 {
     GtkTextIter start, end;
     gint number_for_func;
 
     /* just to be sure... */
-    if (!default_func || !buffer)
-		return FALSE;
+	if (!default_func || !buffer)
+		return;
 
     number_for_func = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (buffer), "number_for_func"));
 
@@ -317,8 +303,6 @@ static gboolean gsb_autofunc_textview_changed (GtkTextBuffer *buffer,
 
     /* Mark file as modified */
     gsb_file_set_modified (TRUE);
-
-    return FALSE;
 }
 
 /******************************************************************************/
@@ -401,10 +385,9 @@ GtkWidget *gsb_autofunc_checkbutton_new (const gchar *label,
  * \param default_func The function to call to change the value in memory (function must be func (number, gboolean)) or NULL
  * \param number_for_func a gint which we be used to call default_func (will be saved as g_object_set_data with "number_for_func")
  *
- * \return a new GtkCheckButton
- * */
+ * \return
+ **/
 void gsb_autofunc_checkbutton_new_from_ui (GtkWidget *button,
-										   const gchar *label,
 										   gboolean value,
 										   GCallback hook,
 										   gpointer data,
@@ -536,6 +519,65 @@ GtkWidget *gsb_autofunc_combobox_new (GSList *list,
     return combobox;
 }
 
+/*
+ * creates a new Combobox from glade ui which will modify the value according to the index
+ * but made for values in grisbi structure :
+ * for each change, will call the corresponding given function : gsb_data_... (number, index)
+ * ie the target function must be :
+ * 	(default_func) (gint number_for_func,
+ * 			 gint index)
+ * ex : gsb_data_account_set_kind (account_number, account_kind)
+ *
+ * basically, that combobox is created with gsb_combo_box_new_with_index_from_list, so can use that functions to get the index
+ * 	if necessary
+ *
+ * \param list a g_slist to create the combobox (succession of text and number, see gsb_combo_box_new_with_index_from_list)
+ * \param index the index to place the combobox
+ * \param hook an optional function to execute as a handler if the
+ * 	combobox changed.
+ * 	hook should be :
+ * 		gboolean hook (GtkWidget *combobox,
+ * 				gpointer data)
+ *
+ * \param data An optional pointer to pass to hooks.
+ * \param default_func The function to call to change the value in memory (function must be func (number, number)) or NULL
+ * \param number_for_func a gint which we be used to call default_func (will be saved as g_object_set_data with "number_for_func")
+ * 				that number can be changed with gsb_autofunc_combobox_set_index
+ *
+ * \return
+ * */
+void gsb_autofunc_combobox_new_from_ui (GtkWidget *combo,
+										GSList *list,
+										gint index,
+										GCallback hook,
+										gpointer data,
+										GCallback default_func,
+										gint number_for_func)
+{
+    /* fill the combobox */
+    gsb_combo_box_new_with_index_from_list_from_ui (combo, list, NULL, NULL);
+    gsb_combo_box_set_index (combo, index);
+
+    /* set the default func :
+     * the func will be sent to gsb_autofunc_combo_changed by the data,
+     * the number_for_func will be set as data for object */
+    g_object_set_data (G_OBJECT (combo), "number_for_func", GINT_TO_POINTER (number_for_func));
+    if (default_func)
+		g_object_set_data (G_OBJECT (combo),
+						   "changed",
+						   GUINT_TO_POINTER (g_signal_connect_after (G_OBJECT(combo),
+																	 "changed",
+																	 G_CALLBACK (gsb_autofunc_combobox_changed),
+																	 default_func)));
+    if (hook)
+		g_object_set_data (G_OBJECT (combo),
+						   "changed-hook",
+						   GUINT_TO_POINTER (g_signal_connect_after (G_OBJECT(combo),
+																	 "changed",
+																	 G_CALLBACK (hook),
+																	 data)));
+}
+
 /**
  * set the value in a gsb_autofunc_combobox
  * a value is in 2 parts :
@@ -644,6 +686,70 @@ GtkWidget *gsb_autofunc_currency_new (gboolean set_name,
      return combobox;
 }
 
+/*
+ * This create a combobox of currencies from glade ui, this is basically the same as gsb_autofunc_combobox_new
+ * 	but work only with currencies
+ *
+ * for each change, will call the corresponding given function : gsb_data_... (number, currency_number)
+ * ie the target function must be :
+ * 	(default_func) (gint number_for_func,
+ * 			 gint currency_number)
+ * ex : gsb_data_account_set_currency (account_number, currency_number)
+ *
+ * basically, that combobox is created with gsb_currency_make_combobox, so can use that functions to get the index
+ * 	if necessary
+ *
+ * \param set_name TRUE to show the name of the currencies in the combobox
+ * \param currency_number the currency we want to show
+ * \param hook an optional function to execute as a handler if the
+ * 	combobox changed.
+ * 	hook should be :
+ * 		gboolean hook (GtkWidget *combobox,
+ * 				gpointer data)
+ *
+ * \param data An optional pointer to pass to hooks.
+ * \param default_func The function to call to change the value in memory (function must be func (number, currency_number)) or NULL
+ * \param number_for_func a gint which we be used to call default_func (will be saved as g_object_set_data with "number_for_func")
+ * 				that number can be changed with gsb_autofunc_currency_set_currency_number
+ *
+ * \return
+ **/
+void gsb_autofunc_currency_new_from_ui (GtkWidget *combo,
+										gboolean set_name,
+										gint currency_number,
+										GCallback hook,
+										gpointer data,
+										GCallback default_func,
+										gint number_for_func)
+{
+	/* init combo_account_currency */
+	gsb_currency_make_combobox_from_ui (combo, set_name);
+
+    /* fill the combobox */
+    if (currency_number)
+        gsb_currency_set_combobox_history (combo, currency_number);
+
+    /* set the default func :
+     * the func will be sent to gsb_autofunc_currency_changed by the data,
+     * the number_for_func will be set as data for object */
+    g_object_set_data (G_OBJECT (combo), "number_for_func", GINT_TO_POINTER (number_for_func));
+
+    if (default_func)
+		g_object_set_data (G_OBJECT (combo),
+						   "changed",
+						   GUINT_TO_POINTER (g_signal_connect_after (G_OBJECT(combo),
+																	 "changed",
+																	 G_CALLBACK (gsb_autofunc_currency_changed),
+																	 default_func)));
+    if (hook)
+		g_object_set_data (G_OBJECT (combo),
+						   "changed-hook",
+						   GUINT_TO_POINTER (g_signal_connect_after (G_OBJECT(combo),
+																	 "changed",
+																	 G_CALLBACK (hook),
+																	 data)));
+}
+
 /**
  * show the currency in a gsb_autofunc_currency
  * a value is in 2 parts :
@@ -846,16 +952,35 @@ GtkWidget *gsb_autofunc_entry_new (const gchar *value,
     return entry;
 }
 
+/*
+ * creates a new GtkEntry from glade ui which will modify the value according to the entry
+ * but made for values in grisbi structure :
+ * for each change, will call the corresponding given function : gsb_data_... (number, string content)
+ * ie the target function must be :
+ * 	(default_func) (gint number_for_func,
+ * 			 gchar *string)
+ * ex : gsb_data_account_set_name (account_number, name)
+ *
+ * \param value a string to fill the entry
+ * \param hook an optional function to execute as a handler if the
+ * 	entry's contents are modified.
+ * 	hook should be :
+ * 		gboolean hook (GtkWidget *entry,
+ * 				gpointer data)
+ *
+ * \param data An optional pointer to pass to hooks.
+ * \param default_func The function to call to change the value in memory (function must be func (number, string)) or NULL
+ * \param number_for_func a gint which we be used to call default_func (will be saved as g_object_set_data with "number_for_func")
+ * 				that number can be changed with gsb_autofunc_entry_set_value
+ *
+ * \return
+ **/
 void gsb_autofunc_entry_new_from_ui (GtkWidget *entry,
-									 const gchar *value,
 									 GCallback hook,
 									 gpointer data,
 									 GCallback default_func,
 									 gint number_for_func)
 {
-    if (value)
-		gtk_entry_set_text (GTK_ENTRY(entry), value);
-
     /* set the default func :
      * the func will be send to gsb_editable_set_text by the data,
      * the number_for_func will be set as data for object */
@@ -1185,6 +1310,55 @@ GtkWidget *gsb_autofunc_real_new (GsbReal real,
     return entry;
 }
 
+/*
+ * creates a new GtkEntry from ui to contain a GsbReal which will modify the value according to the entry
+ * but made for values in grisbi structure :
+ * for each change, will call the corresponding given function : gsb_data_... (number, gsb_real)
+ * ie the target function must be :
+ * 	(default_func) (gint number_for_func,
+ * 			 GsbReal real)
+ * ex : gsb_data_account_set_init_balance (account, real)
+ *
+ * \param real a GsbReal to fill the entry or NULL
+ * \param hook an optional function to execute as a handler if the
+ * 	entry's contents are modified.
+ * 	hook should be :
+ * 		gboolean hook (GtkWidget *entry,
+ * 				gpointer data)
+ *
+ * \param data An optional pointer to pass to hooks.
+ * \param default_func a function to call when something change (function must be func (number, real)) or null_real
+ * \param number_for_func a gint which we be used to call default_func (will be saved as g_object_set_data with "number_for_func")
+ * 				that number can be changed with gsb_autofunc_entry_set_value
+ *
+ * \return a new GtkEntry
+ * */
+void gsb_autofunc_real_new_from_ui (GtkWidget *entry,
+									GCallback hook,
+									gpointer data,
+									GCallback default_func,
+									gint number_for_func)
+{
+	/* set the default func :
+	* the func will be send to gsb_editable_set_text by the data,
+	* the number_for_func will be set as data for object */
+    g_object_set_data (G_OBJECT (entry), "number_for_func", GINT_TO_POINTER (number_for_func));
+    if (default_func)
+		g_object_set_data (G_OBJECT (entry),
+						   "changed",
+						   GUINT_TO_POINTER (g_signal_connect_after (G_OBJECT(entry),
+																	 "changed",
+																	 G_CALLBACK (gsb_autofunc_real_changed),
+																	 default_func)));
+    if (hook)
+		g_object_set_data (G_OBJECT (entry),
+						   "changed-hook",
+						   GUINT_TO_POINTER (g_signal_connect_after (G_OBJECT(entry),
+																	 "changed",
+																	 G_CALLBACK (hook),
+																	 data)));
+}
+
 /**
  * set the GsbReal in a gsb_editable_date
  * a value is in 2 parts :
@@ -1294,12 +1468,12 @@ GtkWidget *gsb_autofunc_spin_new (gint value,
     return spin_button;
 }
 
-GtkWidget *gsb_autofunc_spin_new_from_ui (GtkWidget *spin_button,
-										  gint value,
-										  GCallback hook,
-										  gpointer data,
-										  GCallback default_func,
-										  gint number_for_func)
+void gsb_autofunc_spin_new_from_ui (GtkWidget *spin_button,
+									gint value,
+									GCallback hook,
+									gpointer data,
+									GCallback default_func,
+									gint number_for_func)
 {
 
     /* set range and fill the spin button */
@@ -1324,7 +1498,6 @@ GtkWidget *gsb_autofunc_spin_new_from_ui (GtkWidget *spin_button,
 																	 "value-changed",
 																	 G_CALLBACK (hook),
 																	 data)));
-    return spin_button;
 }
 
 /**
@@ -1424,6 +1597,57 @@ GtkWidget *gsb_autofunc_textview_new (const gchar *value,
     return text_view;
 }
 
+/*
+ * creates a new GtkTextView from glade ui which will automatickly modify the value according to the text in memory
+ * in grisbi structure :
+ * for each change, will call the corresponding given function : gsb_data_... (number, string content)
+ * ie the target function must be :
+ * 	(default_func) (gint number_for_func,
+ * 			 gchar *string)
+ * ex : gsb_data_bank_set_bank_note (account_number, text)
+ * rem : do the same as gsb_autofunc_entry_new but for a text_view
+ *
+ * \param value a string to fill the text_view
+ * \param hook an optional function to execute as a handler if the
+ * 	text_view's contents are modified : !!! send the text_buffer, and not the text_view
+ * 	hook should be :
+ * 		gboolean hook (GtkTextBuffer *text_buffer,
+ * 				gpointer data)
+ *
+ * \param data An optional pointer to pass to hooks.
+ * \param default_func The function to call to change the value in memory (function must be func (number, string)) or NULL
+ * \param number_for_func a gint which we be used to call default_func (will be saved as g_object_set_data with "number_for_func")
+ *
+ * \return
+ **/
+void gsb_autofunc_textview_new_from_ui (GtkWidget *text_view,
+										GCallback hook,
+										gpointer data,
+										GCallback default_func,
+										gint number_for_func)
+{
+    GtkTextBuffer *buffer;
+
+    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (text_view));
+
+    /* set the default function and save the number_for_func */
+    g_object_set_data (G_OBJECT (buffer), "number_for_func", GINT_TO_POINTER (number_for_func));
+    if (default_func)
+		g_object_set_data (G_OBJECT (buffer),
+						   "changed",
+						   GUINT_TO_POINTER (g_signal_connect_after (G_OBJECT(buffer),
+																	 "changed",
+																	 ((GCallback) gsb_autofunc_textview_changed),
+																	 default_func)));
+    if (hook)
+		g_object_set_data (G_OBJECT (buffer),
+						   "changed-hook",
+						   GUINT_TO_POINTER (g_signal_connect_after  (G_OBJECT(buffer),
+																	  "changed",
+																	  ((GCallback) hook),
+																	  data)));
+}
+
 /**
  * set the value in a gsb_editable_text_area
  * a value is in 2 parts :
