@@ -15,7 +15,6 @@ GtkWidget *	gsb_autofunc_checkbutton_new 				(const gchar *label,
 														 GCallback default_func,
 														 gint number_for_func);
 void		gsb_autofunc_checkbutton_new_from_ui		(GtkWidget *button,
-														 const gchar *label,
 														 gboolean value,
 														 GCallback hook,
 														 gpointer data,
@@ -30,6 +29,13 @@ GtkWidget *	gsb_autofunc_combobox_new 					(GSList *list,
 													     gpointer data,
 													     GCallback default_func,
 													     gint number_for_func);
+void		gsb_autofunc_combobox_new_from_ui 			(GtkWidget *combobox,
+														 GSList *list,
+													     gint index,
+													     GCallback hook,
+													     gpointer data,
+													     GCallback default_func,
+													     gint number_for_func);
 void 		gsb_autofunc_combobox_set_index 			(GtkWidget *combobox,
 													     gint index,
 													     gint number_for_func);
@@ -39,6 +45,13 @@ GtkWidget *	gsb_autofunc_currency_new 					(gboolean set_name,
 													     gpointer data,
 													     GCallback default_func,
 													     gint number_for_func);
+void		gsb_autofunc_currency_new_from_ui			(GtkWidget *combo,
+														 gboolean set_name,
+													     gint currency_number,
+													     GCallback hook,
+													     gpointer data,
+													     GCallback default_func,
+													     gint number_for_func);
 void 		gsb_autofunc_currency_set_currency_number 	(GtkWidget *combobox,
 														 gint currency_number,
 														 gint number_for_func);
@@ -56,7 +69,6 @@ GtkWidget *	gsb_autofunc_entry_new 						(const gchar *value,
 														 GCallback default_func,
 														 gint number_for_func);
 void		gsb_autofunc_entry_new_from_ui				(GtkWidget *entry,
-					                                     const gchar *value,
 														 GCallback hook,
 														 gpointer data,
 														 GCallback default_func,
@@ -85,6 +97,11 @@ GtkWidget *	gsb_autofunc_real_new 						(GsbReal real,
 													     gpointer data,
 													     GCallback default_func,
 													     gint number_for_func);
+void 		gsb_autofunc_real_new_from_ui				(GtkWidget *entry,
+														 GCallback hook,
+														 gpointer data,
+														 GCallback default_func,
+														 gint number_for_func);
 void 		gsb_autofunc_real_set 						(GtkWidget *entry,
 														 GsbReal real,
 														 gint number_for_func);
@@ -93,7 +110,7 @@ GtkWidget *	gsb_autofunc_spin_new 						(gint value,
 														 gpointer data,
 														 GCallback default_func,
 														 gint number_for_func);
-GtkWidget *	gsb_autofunc_spin_new_from_ui 				(GtkWidget *spin_button,
+void		gsb_autofunc_spin_new_from_ui 				(GtkWidget *spin_button,
 					                                     gint value,
 														 GCallback hook,
 														 gpointer data,
@@ -107,6 +124,11 @@ GtkWidget *	gsb_autofunc_textview_new 					(const gchar *value,
 														 gpointer data,
 														 GCallback default_func,
 														 gint number_for_func);
+void		gsb_autofunc_textview_new_from_ui 			(GtkWidget *text_view,
+														 GCallback hook,
+														 gpointer data,
+														 GCallback default_func,
+														 gint number_for_func);
 void 		gsb_autofunc_textview_set_value 			(GtkWidget *text_view,
 														 const gchar *value,
 														 gint number_for_func);
