@@ -64,7 +64,11 @@ static void gsb_category_fill_sets ( GtkTreeView * view, GtkTreeModel * model, g
 /*START_EXTERN*/
 /*END_EXTERN*/
 
-
+enum BuiltinCategoryColumns {
+    BUILTIN_CATEGORY_MODEL_FILENAME,
+    BUILTIN_CATEGORY_MODEL_NAME,
+    BUILTIN_CATEGORY_MODEL_COLUMNS
+};
 
 /**
  * A handy GCompareFunc that compares two files depending on their
@@ -119,7 +123,7 @@ void gsb_category_fill_sets ( GtkTreeView * view, GtkTreeModel * model, gboolean
 	    while ( list )
 	    {
 		if ( ! g_slist_find_custom ( category_files, list -> data,
-					     (GCompareFunc) cherche_string_equivalente_dans_slist ) )
+					     (GCompareFunc) utils_str_search_str_in_string_list ) )
 		{
 		    category_files = g_slist_append ( category_files, list -> data );
 		}
@@ -352,6 +356,7 @@ GSList * gsb_category_assistant_scan_directory (const gchar *basename, GtkTreeMo
 		list = g_slist_append ( list, filename );
 	    }
 	}
+		g_dir_close(dir);
     }
 
     g_free ( dirname );
