@@ -54,8 +54,10 @@
 #include "utils_files.h"
 #include "utils_prefs.h"
 #include "utils_real.h"
-#include "erreur.h"
+#include "utils_widgets.h"
+#include "widget_account_property.h"
 #include "widget_currency_details.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
  /** This structure holds information needed for exchange rates cache. */
@@ -106,7 +108,6 @@ static GsbReal current_exchange;
 static GsbReal current_exchange_fees;
 
 /*START_EXTERN*/
-extern GtkWidget *detail_devise_compte;
 /*END_EXTERN*/
 
 /******************************************************************************/
@@ -655,6 +656,7 @@ gint gsb_currency_get_currency_from_combobox (GtkWidget *combo_box)
  */
 gboolean gsb_currency_update_combobox_currency_list (void)
 {
+	GtkWidget *detail_devise_compte;
 	GtkWidget *combo_devise_totaux_categ;
 	GtkWidget *combo_devise_totaux_ib;
 	GtkWidget *combo_devise_totaux_tiers;
@@ -662,6 +664,7 @@ gboolean gsb_currency_update_combobox_currency_list (void)
     gulong handler_id;
     gint old_currency_number = -1;
 	gchar* tmpstr;
+	GrisbiWinRun *w_run;
 
 	if (!combobox_currency_store || !gsb_data_currency_get_currency_list ())
 		return FALSE;
@@ -671,6 +674,7 @@ gboolean gsb_currency_update_combobox_currency_list (void)
 	combo_devise_totaux_tiers = prefs_page_metatree_get_currency_combobox ("combo_totaux_tiers");
 
 	/* XXX still buggy, very slow on the gtk_list_store_clear() call, try to find why. */
+	detail_devise_compte = widget_account_property_get_combo_account_currency ();
     if (detail_devise_compte && G_IS_OBJECT (detail_devise_compte))
     {
         handler_id = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (detail_devise_compte), "changed-hook"));
@@ -744,9 +748,10 @@ gboolean gsb_currency_update_combobox_currency_list (void)
         list_tmp = list_tmp->next;
     }
 
-    run.mise_a_jour_liste_comptes_accueil = TRUE;
-    run.mise_a_jour_liste_echeances_manuelles_accueil = TRUE;
-    run.mise_a_jour_liste_echeances_auto_accueil = TRUE;
+	w_run = (GrisbiWinRun *) grisbi_win_get_w_run ();
+    w_run->mise_a_jour_liste_comptes_accueil = TRUE;
+    w_run->mise_a_jour_liste_echeances_manuelles_accueil = TRUE;
+    w_run->mise_a_jour_liste_echeances_auto_accueil = TRUE;
 
     if (detail_devise_compte && G_IS_OBJECT (detail_devise_compte))
     {
@@ -899,6 +904,8 @@ void gsb_currency_exchange_dialog (gint account_currency_number,
 {
     GtkWidget *dialog, *label, *hbox, *paddingbox, *table, *widget;
     GtkWidget *entry, *amount_entry, *amount_1_entry, *amount_2_entry, *fees_entry;
+	GtkWidget *button_cancel;
+	GtkWidget *button_OK;
     GtkWidget *combobox_1;
     GtkWidget *combobox_2;
     CachedExchangeRate *cache;
@@ -922,13 +929,20 @@ void gsb_currency_exchange_dialog (gint account_currency_number,
     }
 
     dialog = gtk_dialog_new_with_buttons (_("Enter exchange rate"),
-                        GTK_WINDOW (grisbi_app_get_active_window (NULL)),
-                        GTK_DIALOG_MODAL,
-                        "gtk-cancel", GTK_RESPONSE_CANCEL,
-                        "gtk-ok", GTK_RESPONSE_OK,
-                        NULL);
+										  GTK_WINDOW (grisbi_app_get_active_window (NULL)),
+										  GTK_DIALOG_MODAL,
+										  NULL, NULL,
+										  NULL);
 
-    gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ON_PARENT);
+	button_cancel = gtk_button_new_with_label (_("Cancel"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_cancel, GTK_RESPONSE_CANCEL);
+	gtk_widget_set_can_default (button_cancel, TRUE);
+
+	button_OK = gtk_button_new_with_label (_("Validate"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_OK, GTK_RESPONSE_OK);
+	gtk_widget_set_can_default (button_OK, TRUE);
+
+	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ON_PARENT);
     gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 
     /* text for paddingbox */
@@ -1297,6 +1311,7 @@ gint gsb_currency_dialog_list_iso_4217_new (GtkWidget *page_currency,
 											gboolean no_callback)
 {
     GtkWidget *dialog;
+	GtkWidget *button_close;
     GtkWidget *content_area;
     GtkWidget *details;
     GtkWidget *popup;
@@ -1309,9 +1324,13 @@ gint gsb_currency_dialog_list_iso_4217_new (GtkWidget *page_currency,
 	dialog = gtk_dialog_new_with_buttons (_("Add a currency"),
 										  GTK_WINDOW (grisbi_app_get_active_window (NULL)),
 										  GTK_DIALOG_MODAL,
-										  "gtk-close", 1,
+										  NULL, NULL,
 										  NULL);
 
+	button_close = gtk_button_new_with_label (_("Close"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_close, GTK_RESPONSE_ACCEPT);
+	gtk_widget_set_can_default (button_close, TRUE);
+
     gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ON_PARENT);
     gtk_window_set_resizable (GTK_WINDOW (dialog), TRUE);
 	gtk_widget_set_size_request (dialog, 650, 500);
