@@ -3,7 +3,7 @@
 /*                                                                            */
 /*     Copyright (C)	2000-2008 Cédric Auger (cedric@grisbi.org)	          */
 /*			2003-2008 Benjamin Drieu (bdrieu@april.org)             	      */
-/* 			http://www.grisbi.org				                              */
+/* 			https://www.grisbi.org				                              */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -245,7 +245,7 @@ static void gsb_data_payee_reset_counters (void)
  *
  * \return FALSE
  **/
-gboolean gsb_data_payee_init_variables (void)
+gboolean gsb_data_payee_init_variables (gboolean cleanup)
 {
     /* free the memory used by the actual list */
     GSList *tmp_list;
@@ -259,18 +259,22 @@ gboolean gsb_data_payee_init_variables (void)
 		_gsb_data_payee_free (payee);
     }
     g_slist_free (payee_list);
-    payee_list = NULL;
-    payee_buffer = NULL;
+	if (cleanup)
+	{
+		payee_list = NULL;
+		payee_buffer = NULL;
 
-    /* create the blank payee */
-    if (empty_payee)
-    {
-        g_free (empty_payee->payee_name);
-		g_free (empty_payee);
-    }
-    empty_payee = g_malloc0 (sizeof (PayeeStruct));
-    empty_payee->payee_name = g_strdup(_("No payee"));
-    return FALSE;
+		/* create the blank payee */
+		if (empty_payee)
+		{
+			g_free (empty_payee->payee_name);
+			g_free (empty_payee);
+		}
+		empty_payee = g_malloc0 (sizeof (PayeeStruct));
+		empty_payee->payee_name = g_strdup(_("No payee"));
+	}
+
+	return FALSE;
 }
 
 /**
@@ -770,15 +774,24 @@ void gsb_data_payee_update_counters (void)
 void gsb_data_payee_add_transaction_to_payee (gint transaction_number)
 {
     PayeeStruct *payee;
+	gint contra_number;
 
-	/* if the transaction is a split transaction, don't take it */
+	/* if the transaction is a split transaction or a contra transaction don't take it */
 	if (gsb_data_transaction_get_mother_transaction_number (transaction_number))
 	{
 		return;
 	}
-    payee = gsb_data_payee_get_structure (gsb_data_transaction_get_party_number (transaction_number));
+	else if ((contra_number = gsb_data_transaction_get_contra_transaction_number (transaction_number)) > 0)
+	{
+		gint tmp_number;
 
-    /* if no payee in that transaction and it's neither a split transaction, we work with empty_payee */
+		tmp_number = gsb_data_transaction_get_contra_transaction_number (contra_number);
+		if (tmp_number > contra_number)
+			return;
+	}
+
+	/* if no payee in that transaction and it's neither a split transaction, we work with empty_payee */
+    payee = gsb_data_payee_get_structure (gsb_data_transaction_get_party_number (transaction_number));
 
     /* should not happen, this is if the transaction has a payee which doesn't exists
      * we show a debug warning and get without payee */
@@ -795,11 +808,10 @@ void gsb_data_payee_add_transaction_to_payee (gint transaction_number)
     }
 
     payee->payee_nb_transactions ++;
-    if (! gsb_data_transaction_get_split_of_transaction (transaction_number))
-        payee->payee_balance = gsb_real_add (payee->payee_balance,
-											 gsb_data_transaction_get_adjusted_amount_for_currency
-											 (transaction_number, payee_tree_currency (),
-											  -1));
+	payee->payee_balance = gsb_real_add (payee->payee_balance,
+										 gsb_data_transaction_get_adjusted_amount_for_currency
+										 (transaction_number, payee_tree_currency (),
+										  -1));
 }
 
 /**
