@@ -27,9 +27,9 @@
 #endif
 
 #include "include.h"
-#include <time.h>
-#include <limits.h>
-#include <stdlib.h>
+//~ #include <time.h>
+//~ #include <limits.h>
+//~ #include <stdlib.h>
 #include <glib/gstdio.h>
 #include <glib/gi18n.h>
 
@@ -43,7 +43,6 @@
 #include "dialog.h"
 #include "etats_gtktable.h"
 #include "grisbi_app.h"
-#include "gsb_account_property.h"
 #include "gsb_assistant_account.h"
 #include "gsb_data_account.h"
 #include "gsb_data_archive_store.h"
@@ -55,7 +54,6 @@
 #include "gsb_transactions_list.h"
 #include "menu.h"
 #include "navigation.h"
-#include "parametres.h"
 #include "structures.h"
 #include "traitement_variables.h"
 #include "transaction_list.h"
@@ -98,6 +96,7 @@ static void gsb_file_remove_old_backup (const gchar *filename,
     GSList *iterator;
 	gchar *basename;
 	gchar *name = NULL;
+	gchar *tmp_date;
 
 	devel_debug (filename);
 
@@ -130,7 +129,10 @@ static void gsb_file_remove_old_backup (const gchar *filename,
 										NULL,
 										NULL);
 	if (!direnum)
+	{
+		g_free(name);
 		return;
+	}
 
 	while (TRUE)
 	{
@@ -230,7 +232,9 @@ static void gsb_file_remove_old_backup (const gchar *filename,
 		return;
 	}
 
-	dialogue_message ("remove-backup-files", g_slist_length (filenames), gsb_format_gdate (first_old_date));
+	tmp_date = gsb_format_gdate (first_old_date);
+	dialogue_message ("remove-backup-files", g_slist_length (filenames), tmp_date);
+	g_free(tmp_date);
 
 	g_date_free (first_old_date);
 
@@ -303,19 +307,27 @@ static gboolean gsb_file_test_file (const gchar *filename)
  **/
 static gchar *gsb_file_dialog_ask_name (const gchar *filename)
 {
-    gchar *new_name;
     GtkWidget *dialog;
-    gint result;
+	GtkWidget *button_cancel;
+	GtkWidget *button_save;
+    gchar *new_name;
     gchar *tmp_last_directory;
+    gint result;
 
-    dialog = gtk_file_chooser_dialog_new (_("Name the accounts file"),
+	dialog = gtk_file_chooser_dialog_new (_("Name the accounts file"),
 										  GTK_WINDOW (grisbi_app_get_active_window (NULL)),
 										  GTK_FILE_CHOOSER_ACTION_SAVE,
-										  "gtk-cancel", GTK_RESPONSE_CANCEL,
-										  "gtk-save", GTK_RESPONSE_OK,
+										  NULL, NULL,
 										  NULL);
 
-    gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), gsb_file_get_last_path ());
+	button_cancel = gtk_button_new_with_label (_("Cancel"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_cancel, GTK_RESPONSE_CANCEL);
+
+	button_save = gtk_button_new_with_label (_("Save"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_save, GTK_RESPONSE_OK);
+	gtk_widget_set_can_default (button_save, TRUE);
+
+	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), gsb_file_get_last_path ());
     gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog), TRUE);
     gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ON_PARENT);
 
@@ -326,14 +338,16 @@ static gchar *gsb_file_dialog_ask_name (const gchar *filename)
 
 		w_etat = (GrisbiWinEtat *) grisbi_win_get_w_etat ();
 
-        tmp_str = g_strconcat (w_etat->accounting_entity, ".gsb", NULL);
-        gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog), tmp_str);
-        g_free (tmp_str);
-    }
-    else
+		tmp_str = g_strconcat (w_etat->accounting_entity, ".gsb", NULL);
+		gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog), tmp_str);
+		g_free (tmp_str);
+	}
+	else
         gtk_file_chooser_select_filename (GTK_FILE_CHOOSER (dialog), filename);
 
-    result = gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_show_all (dialog);
+
+	result = gtk_dialog_run (GTK_DIALOG (dialog));
 
     switch (result)
     {
@@ -374,15 +388,23 @@ static gint gsb_file_dialog_save (const gchar *filename,
 								  gint origine)
 {
     GtkWidget *dialog;
+    GtkWidget *button_cancel;
+    GtkWidget *button_close;
+    GtkWidget *button_save;
     gchar *hint = NULL;
     gchar *message = NULL;
     gint result;
+	gchar *basename = NULL;
 
-    dialog = gtk_message_dialog_new (GTK_WINDOW (grisbi_app_get_active_window (NULL)),
+	dialog = gtk_message_dialog_new (GTK_WINDOW (grisbi_app_get_active_window (NULL)),
 									 GTK_DIALOG_DESTROY_WITH_PARENT,
 									 GTK_MESSAGE_WARNING,
 									 GTK_BUTTONS_NONE,
 									 " ");
+
+	if (filename)
+		basename = g_path_get_basename(filename);
+
 	switch (origine)
 	{
 		case -1:
@@ -390,18 +412,23 @@ static gint gsb_file_dialog_save (const gchar *filename,
 			gchar *time_elapsed;
 			time_t now;
 			gint difference;
+			GrisbiWinRun *w_run;
 
+			w_run = (GrisbiWinRun *) grisbi_win_get_w_run ();
 			now = time (NULL);
-			difference = (int) (difftime (now, run.file_modification));
+			difference = (int) (difftime (now, w_run->file_modification));
 			hint = g_strdup_printf (_("Save changes to document '%s' before closing?"),
-									(filename ? g_path_get_basename(filename) : _("unnamed")));
+									(basename ? basename : _("unnamed")));
 
+			button_close = gtk_button_new_with_label (_("Close without saving"));
+			gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_close, GTK_RESPONSE_NO);
+
+			button_cancel = gtk_button_new_with_label (_("Cancel"));
+			gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_cancel, GTK_RESPONSE_REJECT);
+
+			button_save = gtk_button_new_with_label (_("Save"));
+			gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_save, GTK_RESPONSE_OK);
 
-			gtk_dialog_add_buttons (GTK_DIALOG(dialog),
-									_("Close without saving"), GTK_RESPONSE_NO,
-									"gtk-cancel", GTK_RESPONSE_REJECT,
-									"gtk-save", GTK_RESPONSE_OK,
-									NULL);
 			if (difference >= 120)
 			{
 				time_elapsed = g_strdup_printf (_("%d minutes and %d seconds"), difference / 60, difference % 60);
@@ -425,23 +452,29 @@ static gint gsb_file_dialog_save (const gchar *filename,
 		default:
 		{
 			hint = g_strdup_printf (_("Save changes in '%s' file?"),
-									(filename ? g_path_get_basename(filename) : _("unnamed")));
+									(basename ? basename : _("unnamed")));
+
+			button_cancel = gtk_button_new_with_label (_("Cancel"));
+			gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_cancel, GTK_RESPONSE_NO);
+
+			button_save = gtk_button_new_with_label (_("Save"));
+			gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_save, GTK_RESPONSE_OK);
 
-			gtk_dialog_add_buttons (GTK_DIALOG(dialog),
-									"gtk-cancel", GTK_RESPONSE_NO,
-									"gtk-save", GTK_RESPONSE_OK,
-									NULL);
 			message = g_strdup("");
 		}
 	}
 	gtk_dialog_set_default_response (GTK_DIALOG(dialog), GTK_RESPONSE_OK);
 	g_object_set (G_OBJECT (dialog), "text", hint, "secondary-text", message, NULL);
 
+	gtk_widget_show_all (dialog);
+
     g_free (message);
     g_free (hint);
+    g_free(basename);
 
     gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
 
+
     result = gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (dialog);
 
@@ -559,25 +592,27 @@ static gboolean gsb_file_save_file (gint origine)
     gchar *nouveau_nom_enregistrement;
 	gchar *filename;
 	GrisbiAppConf *a_conf;
+	GrisbiWinEtat *w_etat;
 
     devel_debug_int (origine);
 
 	/* on regarde si il y a quelque chose à sauvegarder sauf pour "sauvegarder sous" */
 	if ((!gsb_file_get_modified () && origine != -2)
         ||
-        !gsb_data_account_get_accounts_amount ())
+        !gsb_data_account_get_number_of_accounts ())
     {
         notice_debug ("nothing done in gsb_file_save_file");
         return (TRUE);
     }
 
 	a_conf = grisbi_app_get_a_conf ();
+	w_etat = grisbi_win_get_w_etat ();
 
 	/* on récupère le nom du fichier */
 	filename = g_strdup (grisbi_win_get_filename (NULL));
 
 	/* on vérifie que le fichier n'est pas locké si il l'est on sort */
-    if (etat.fichier_deja_ouvert && !a_conf->force_enregistrement && origine != -2)
+    if (w_etat->fichier_deja_ouvert && !a_conf->force_enregistrement && origine != -2)
     {
         gchar* tmp_str1;
         gchar* tmp_str2;
@@ -644,7 +679,7 @@ static gboolean gsb_file_save_file (gint origine)
         gsb_file_util_modify_lock (nouveau_nom_enregistrement, TRUE);
 
         /* update variables */
-        etat.fichier_deja_ouvert = 0;
+        w_etat->fichier_deja_ouvert = 0;
         gsb_file_set_modified (FALSE);
         grisbi_win_set_window_title (gsb_gui_navigation_get_current_account ());
 
@@ -718,6 +753,8 @@ gboolean gsb_file_new_finish (void)
 gboolean gsb_file_open_menu (void)
 {
     GtkWidget *selection_fichier;
+	GtkWidget *button_cancel;
+	GtkWidget *button_open;
     GtkFileFilter * filter;
     gboolean result = FALSE;
     gchar *tmp_last_directory;
@@ -726,9 +763,16 @@ gboolean gsb_file_open_menu (void)
     selection_fichier = gtk_file_chooser_dialog_new (_("Open an accounts file"),
 												     GTK_WINDOW (grisbi_app_get_active_window (NULL)),
 												     GTK_FILE_CHOOSER_ACTION_OPEN,
-												     "gtk-cancel", GTK_RESPONSE_CANCEL,
-												     "gtk-open", GTK_RESPONSE_OK,
-												     NULL);
+												     NULL, NULL,
+													 NULL);
+
+	button_cancel = gtk_button_new_with_label (_("Cancel"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (selection_fichier), button_cancel, GTK_RESPONSE_CANCEL);
+
+	button_open = gtk_button_new_with_label (_("Open"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (selection_fichier), button_open, GTK_RESPONSE_OK);
+	gtk_widget_set_can_default (button_open, TRUE);
+	gtk_dialog_set_default_response (GTK_DIALOG (selection_fichier), GTK_RESPONSE_OK);
 
     gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (selection_fichier), gsb_file_get_last_path ());
     gtk_window_set_position (GTK_WINDOW (selection_fichier), GTK_WIN_POS_CENTER_ON_PARENT);
@@ -744,6 +788,8 @@ gboolean gsb_file_open_menu (void)
     gtk_file_filter_add_pattern (filter, "*");
     gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (selection_fichier), filter);
 
+	gtk_widget_show_all (selection_fichier);
+
     switch (gtk_dialog_run (GTK_DIALOG (selection_fichier)))
     {
 		case GTK_RESPONSE_OK:
@@ -853,7 +899,7 @@ void gsb_file_set_backup_path (const gchar *path)
     else
         backup_path = my_strdup (path);
 
-    if (!g_file_test (path, G_FILE_TEST_EXISTS))
+    if (path && !g_file_test (path, G_FILE_TEST_EXISTS))
     {
         utils_files_create_XDG_dir ();
     }
@@ -925,6 +971,7 @@ gboolean gsb_file_open_file (const gchar *filename)
                                    "This file can not be imported by Grisbi."),
                                  _("Version of Grisbi file too old :"));
             grisbi_win_status_bar_stop_wait (TRUE);
+			w_run->file_modification = 0;
 
             return FALSE;
         }
@@ -960,9 +1007,11 @@ gboolean gsb_file_open_file (const gchar *filename)
 		dialogue_error_hint (tmp_str2, tmp_str1);
 		g_free (tmp_str1);
 		g_free (tmp_str2);
+		w_run->file_modification = 0;
 #endif
 		grisbi_win_status_bar_stop_wait (TRUE);
 		grisbi_win_stack_box_show (NULL, "accueil_page");
+
 		return FALSE;
     }
 
@@ -1121,12 +1170,13 @@ gboolean gsb_file_close (void)
 
     if (!gsb_file_get_modified ())
     {
-	     /* remove the lock */
-	    if (!etat.fichier_deja_ouvert
-			&&
-			gsb_data_account_get_accounts_amount ()
-			&&
-			filename)
+		GrisbiWinEtat *w_etat;
+
+		/* remove the lock */
+		w_etat = grisbi_win_get_w_etat ();
+	    if (!w_etat->fichier_deja_ouvert
+			&& gsb_data_account_get_number_of_accounts ()
+			&& filename)
 		{
 			gsb_file_util_modify_lock (filename, FALSE);
 		}
@@ -1135,7 +1185,6 @@ gboolean gsb_file_close (void)
 		etats_gtktable_free_table_etat (); /* set table_etat = NULL: fix crash loading a multiple accounts files */
  	    init_variables ();
         grisbi_win_free_general_vbox ();
-        gsb_account_property_clear_config ();
 		grisbi_win_set_filename (NULL, NULL);
 
         grisbi_win_set_window_title (-1);
@@ -1161,21 +1210,24 @@ gboolean gsb_file_close (void)
  */
 void gsb_file_set_modified (gboolean modified)
 {
-/*     devel_debug_int (modified);  */
+	GrisbiWinRun *w_run;
+
+	/*     devel_debug_int (modified);  */
 
     /* If no file is loaded, do not change menu items. */
-	if (!gsb_data_account_get_accounts_amount ())
+	if (!gsb_data_account_get_number_of_accounts ())
 		return;
 
+	w_run = (GrisbiWinRun *) grisbi_win_get_w_run ();
 	if (modified)
     {
 		/* modification pour gerer la non modification par la recherche dans la liste des operations */
-		run.file_modification = time (NULL);
+		w_run->file_modification = time (NULL);
         gsb_menu_gui_sensitive_win_menu_item ("save", TRUE);
     }
     else
     {
-        run.file_modification = 0;
+        w_run->file_modification = 0;
         gsb_menu_gui_sensitive_win_menu_item ("save", FALSE);
     }
 }
@@ -1187,7 +1239,10 @@ void gsb_file_set_modified (gboolean modified)
  */
 gboolean gsb_file_get_modified (void)
 {
-    if (run.file_modification == 0)
+	GrisbiWinRun *w_run;
+
+	w_run = (GrisbiWinRun *) grisbi_win_get_w_run ();
+	if (w_run->file_modification == 0)
         return FALSE;
     else
         return TRUE;
@@ -1311,10 +1366,13 @@ gboolean gsb_file_quit (void)
 
     if (!gsb_file_get_modified ())
     {
-	     /* remove the lock */
-	    if (!etat.fichier_deja_ouvert
+		GrisbiWinEtat *w_etat;
+
+		/* remove the lock */
+		w_etat = grisbi_win_get_w_etat ();
+	    if (!w_etat->fichier_deja_ouvert
 			&&
-			gsb_data_account_get_accounts_amount ()
+			gsb_data_account_get_number_of_accounts ()
 			&&
 			filename)
 		{
@@ -1324,7 +1382,6 @@ gboolean gsb_file_quit (void)
 	    /* free all the variables */
 		etats_gtktable_free_table_etat (); /* set table_etat = NULL: fix crash loading a multiple accounts files */
         grisbi_win_free_general_vbox ();
-        gsb_account_property_clear_config ();
 		grisbi_win_set_filename (NULL, NULL);
 
         grisbi_win_set_window_title (-1);
@@ -1337,6 +1394,33 @@ gboolean gsb_file_quit (void)
     return FALSE;
 }
 
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ **/
+void gsb_file_remove_account_file (const gchar *filename)
+{
+	gchar *tmp_str;
+	gint result;
+
+	devel_debug (filename);
+
+	tmp_str = g_strdup_printf (_("Are you sure you want to remove this accounts file \"%s\"?\n"),
+							   filename);
+	result = dialogue_yes_no (tmp_str, _("Confirmation of accounts file removal"), GTK_RESPONSE_NO);
+
+	if (result)
+	{
+		utils_files_remove_name_to_recent_array (filename);
+		g_remove (filename);
+	}
+
+	g_free (tmp_str);
+}
+
 /**
  *
  *
