@@ -127,7 +127,7 @@ gboolean gsb_file_others_save_category ( gchar *filename )
     iterator = gsb_file_save_append_part ( iterator,
 					   &length_calculated,
 					   &file_content,
-					   my_strdup ("<?xml version=\"1.0\"?>\n<Grisbi_categ>\n"));
+					   "<?xml version=\"1.0\"?>\n<Grisbi_categ>\n");
 
     iterator = gsb_file_others_save_general_part ( iterator,
 						   &length_calculated,
@@ -143,7 +143,7 @@ gboolean gsb_file_others_save_category ( gchar *filename )
     iterator = gsb_file_save_append_part ( iterator,
 					   &length_calculated,
 					   &file_content,
-					   my_strdup ("</Grisbi_categ>"));
+					   "</Grisbi_categ>");
 
     /* the file is in memory, we can save it */
 
@@ -220,7 +220,7 @@ gboolean gsb_file_others_save_budget ( gchar *filename )
     iterator = gsb_file_save_append_part ( iterator,
 					   &length_calculated,
 					   &file_content,
-					   my_strdup ("<?xml version=\"1.0\"?>\n<Grisbi_budget>\n"));
+					   "<?xml version=\"1.0\"?>\n<Grisbi_budget>\n");
 
     iterator = gsb_file_others_save_general_part ( iterator,
 						   &length_calculated,
@@ -236,7 +236,7 @@ gboolean gsb_file_others_save_budget ( gchar *filename )
     iterator = gsb_file_save_append_part ( iterator,
 					   &length_calculated,
 					   &file_content,
-					   my_strdup ("</Grisbi_budget>"));
+					   "</Grisbi_budget>");
 
     /* the file is in memory, we can save it */
 
@@ -310,7 +310,7 @@ gboolean gsb_file_others_save_report ( gchar *filename )
     iterator = gsb_file_save_append_part ( iterator,
 					   &length_calculated,
 					   &file_content,
-					   my_strdup ("<?xml version=\"1.0\"?>\n<Grisbi_report>\n"));
+					   "<?xml version=\"1.0\"?>\n<Grisbi_report>\n");
 
     iterator = gsb_file_others_save_general_part ( iterator,
 						   &length_calculated,
@@ -327,7 +327,7 @@ gboolean gsb_file_others_save_report ( gchar *filename )
     iterator = gsb_file_save_append_part ( iterator,
 					   &length_calculated,
 					   &file_content,
-					   my_strdup ("</Grisbi_report>"));
+					   "</Grisbi_report>");
 
     /* the file is in memory, we can save it */
 
@@ -392,6 +392,7 @@ gulong gsb_file_others_save_general_part ( gulong iterator,
 						length_calculated,
 						file_content,
 						new_string );
+	g_free(new_string);
     return result;
 }
 
@@ -725,7 +726,7 @@ void gsb_file_others_start_element ( GMarkupParseContext *context,
     if ( !strcmp ( element_name,
 		   "Category" ))
     {
-	gsb_file_load_category ( attribute_names,
+	gsb_file_load_category_part ( attribute_names,
 				 attribute_values );
 	return;
     }
@@ -733,7 +734,7 @@ void gsb_file_others_start_element ( GMarkupParseContext *context,
     if ( !strcmp ( element_name,
 		   "Sub_category" ))
     {
-	gsb_file_load_sub_category ( attribute_names,
+	gsb_file_load_sub_category_part ( attribute_names,
 				     attribute_values );
 	return;
     }
@@ -741,7 +742,7 @@ void gsb_file_others_start_element ( GMarkupParseContext *context,
     if ( !strcmp ( element_name,
 		   "Budgetary" ))
     {
-	gsb_file_load_budgetary ( attribute_names,
+	gsb_file_load_budgetary_part ( attribute_names,
 				  attribute_values );
 	return;
     }
@@ -749,7 +750,7 @@ void gsb_file_others_start_element ( GMarkupParseContext *context,
     if ( !strcmp ( element_name,
 		   "Sub_budgetary" ))
     {
-	gsb_file_load_sub_budgetary ( attribute_names,
+	gsb_file_load_sub_budgetary_part ( attribute_names,
 				      attribute_values );
 	return;
     }
@@ -757,7 +758,7 @@ void gsb_file_others_start_element ( GMarkupParseContext *context,
     if ( !strcmp ( element_name,
 		   "Report" ))
     {
-	gsb_file_load_report ( attribute_names,
+	gsb_file_load_report_part ( attribute_names,
 			       attribute_values );
 	return;
     }
@@ -765,7 +766,7 @@ void gsb_file_others_start_element ( GMarkupParseContext *context,
     if ( !strcmp ( element_name,
 		   "Text_comparison" ))
     {
-	gsb_file_load_text_comparison ( attribute_names,
+	gsb_file_load_text_comparison_part ( attribute_names,
 					attribute_values );
 	return;
     }
@@ -773,7 +774,7 @@ void gsb_file_others_start_element ( GMarkupParseContext *context,
     if ( !strcmp ( element_name,
 		   "Amount_comparison" ))
     {
-	gsb_file_load_amount_comparison ( attribute_names,
+	gsb_file_load_amount_comparison_part ( attribute_names,
 					  attribute_values );
 	return;
     }
@@ -872,13 +873,13 @@ void gsb_file_others_start_budget_from_category ( GMarkupParseContext *context,
 {
     if ( !strcmp ( element_name, "Category" ) )
     {
-	    gsb_file_load_budgetary ( attribute_names, attribute_values );
+	    gsb_file_load_budgetary_part ( attribute_names, attribute_values );
 	    return;
     }
 
     if ( !strcmp ( element_name, "Sub_category" ))
     {
-	    gsb_file_load_sub_budgetary ( attribute_names, attribute_values );
+	    gsb_file_load_sub_budgetary_part ( attribute_names, attribute_values );
 	    return;
     }
 }
