@@ -58,7 +58,7 @@
 /*END_INCLUDE*/
 
 /*START_STATIC*/
-static GSList *		form_list_widgets = NULL; /* contains a list of struct_element according to the current form */
+static GSList *		form_list_widgets = NULL; /* contains a list of FormElement according to the current form */
 static gchar *		old_debit = NULL;
 static gchar *		old_credit = NULL;
 static gint			old_credit_payment_number = 0;
@@ -202,7 +202,7 @@ gboolean gsb_form_widget_free_list (void)
     tmp_list = form_list_widgets;
     while (tmp_list)
     {
-        struct_element *element;
+        FormElement *element;
 
         element = tmp_list->data;
         if (!element)
@@ -303,7 +303,9 @@ GtkWidget *gsb_form_widget_create (gint element_number,
 {
     GtkWidget *widget;
     GSList *tmp_list;
+	GrisbiWinEtat *w_etat;
 
+	w_etat = grisbi_win_get_w_etat ();
 	if (!element_number)
 		return NULL;
 
@@ -350,8 +352,8 @@ GtkWidget *gsb_form_widget_create (gint element_number,
 		case TRANSACTION_FORM_PARTY:
 			tmp_list = gsb_data_payee_get_name_and_report_list ();
 			widget = gtk_combofix_new_with_properties (tmp_list,
-													   etat.combofix_force_payee,
-													   etat.combofix_case_sensitive,
+													   w_etat->combofix_force_payee,
+													   w_etat->combofix_case_sensitive,
 													   FALSE,
 													   METATREE_PAYEE);
 			gsb_data_payee_free_name_and_report_list (tmp_list);
@@ -360,9 +362,9 @@ GtkWidget *gsb_form_widget_create (gint element_number,
 		case TRANSACTION_FORM_CATEGORY:
         	tmp_list = gsb_data_category_get_name_list (TRUE, TRUE, TRUE, TRUE);
 			widget = gtk_combofix_new_with_properties (tmp_list,
-													   etat.combofix_force_category,
-													   etat.combofix_case_sensitive,
-													   etat.combofix_mixed_sort,
+													   w_etat->combofix_force_category,
+													   w_etat->combofix_case_sensitive,
+													   w_etat->combofix_mixed_sort,
 													   METATREE_CATEGORY);
 			gsb_data_categorie_free_name_list (tmp_list);
 	    	break;
@@ -374,9 +376,9 @@ GtkWidget *gsb_form_widget_create (gint element_number,
 		case TRANSACTION_FORM_BUDGET:
 			tmp_list = gsb_data_budget_get_name_list (TRUE, TRUE);
 			widget = gtk_combofix_new_with_properties (tmp_list,
-													   etat.combofix_force_category,
-													   etat.combofix_case_sensitive,
-													   etat.combofix_mixed_sort,
+													   w_etat->combofix_force_category,
+													   w_etat->combofix_case_sensitive,
+													   w_etat->combofix_mixed_sort,
 													   METATREE_BUDGET);
 			gsb_data_categorie_free_name_list (tmp_list);
 			break;
@@ -438,9 +440,9 @@ GtkWidget *gsb_form_widget_create (gint element_number,
 		gtk_widget_set_size_request (widget, FORM_COURT_WIDTH, -1);
 
 		/* first, append the widget to the list */
-		struct_element *element;
+		FormElement *element;
 
-		element = g_malloc0 (sizeof (struct_element));
+		element = g_malloc0 (sizeof (FormElement));
 		element->element_number = element_number;
 		element->element_widget = widget;
 		form_list_widgets = g_slist_append (form_list_widgets, element);
@@ -1308,7 +1310,7 @@ gboolean gsb_form_widget_free_list_without_widgets (void)
     tmp_list = form_list_widgets;
     while (tmp_list)
     {
-        struct_element *element;
+        FormElement *element;
 
         element = tmp_list->data;
         g_free (element);
