@@ -3,7 +3,7 @@
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2003-2009 Benjamin Drieu (bdrieu@april.org)                       */
 /*          2008-2011 Pierre Biava (grisbi@pierre.biava.name)                 */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -85,7 +85,7 @@ GRegex *gsb_regex_insert ( const gchar *key,
     GRegex *regex;
     GError *error = NULL;
 
-    devel_debug (pattern);
+    //~ devel_debug (pattern);
     if ( ! regex_store )
         return NULL;
 
