@@ -2,8 +2,8 @@
 /*                                                                            */
 /*     Copyright (C)    2001-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2003-2008 Benjamin Drieu (bdrieu@april.org)                       */
-/*          2009-2019 Pierre Biava (grisbi@pierre.biava.name)                 */
-/*          https://www.grisbi.org/                                            */
+/*          2009-2021 Pierre Biava (grisbi@pierre.biava.name)                 */
+/*          https://www.grisbi.org/                                           */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -108,6 +108,27 @@ enum CombofixKeyDirection
 /******************************************************************************/
 /* Private functions                                                          */
 /******************************************************************************/
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ **/
+static void gtk_combofix_completion_no_match_selected (GtkEntryCompletion *completion,
+													   GtkComboFixPrivate *priv)
+{
+	devel_debug (NULL);
+	if (priv->force)
+	{
+		gint end_pos;
+
+		end_pos = gtk_editable_get_position (GTK_EDITABLE (priv->entry));
+		gtk_editable_delete_text (GTK_EDITABLE (priv->entry), end_pos-1, end_pos);
+
+	}
+}
+
 /**
  * positionne le bouton "Change" du formulaire si le compte destinataire
  * du transfert a une devise différente du compte de départ.
@@ -254,6 +275,10 @@ static void gtk_combofix_completion_insert_new_item (GtkComboFix *combofix,
 			g_free (tmp_str);
 		}
 		while (gtk_tree_model_iter_next (store, &iter));
+
+		/* si on est là c'est qu'on est à la fin de la liste on ajoute le texte */
+		gtk_list_store_append (GTK_LIST_STORE (store), &new_iter);
+		gtk_list_store_set (GTK_LIST_STORE (store), &new_iter, 0, text, -1);
 	}
 	else
 	{
@@ -604,14 +629,19 @@ static gboolean gtk_combofix_fill_store (GtkComboFix *combofix,
 
             if (string[0] == '\t')
             {
-                /* it's a child */
-                tmp_str = g_strconcat (last_parent, " : ", string + 1, NULL);
-                gtk_combofix_fill_iter_child (priv->store, &iter_parent, string + 1, tmp_str, list_number);
+				if (last_parent)
+				{
+					/* it's a child */
+					tmp_str = g_strconcat (last_parent, " : ", string + 1, NULL);
+					gtk_combofix_fill_iter_child (priv->store, &iter_parent, string + 1, tmp_str, list_number);
 
-				/* append a row in the completion */
-				gtk_list_store_append (GTK_LIST_STORE (completion_store), &new_iter);
-				gtk_list_store_set (GTK_LIST_STORE (completion_store), &new_iter, 0, tmp_str, -1);
-                g_free (tmp_str);
+					/* append a row in the completion */
+					gtk_list_store_append (GTK_LIST_STORE (completion_store), &new_iter);
+					gtk_list_store_set (GTK_LIST_STORE (completion_store), &new_iter, 0, tmp_str, -1);
+					g_free (tmp_str);
+				}
+				else
+					alert_debug("Wrong format\n");
             }
             else
             {
@@ -760,7 +790,6 @@ static gboolean gtk_combofix_set_all_visible_rows (GtkComboFix *combofix)
 static gint gtk_combofix_get_screen_height (GtkComboFix *combofix,
 											gint y)
 {
-#if GTK_CHECK_VERSION (3,22,0)
 	GdkWindow *window;
 	GdkDisplay *display;
 	GdkMonitor *monitor;
@@ -771,10 +800,7 @@ static gint gtk_combofix_get_screen_height (GtkComboFix *combofix,
 	monitor = gdk_display_get_monitor_at_point (display, 0, y);
 	gdk_monitor_get_geometry (monitor, &rectangle);
 
-		return rectangle.height;
-#else
-		return gdk_screen_height ();
-#endif
+	return rectangle.height;
 }
 
 /**
@@ -938,8 +964,8 @@ static gboolean gtk_combofix_focus_out (GtkWidget *entry,
 {
 	gtk_combofix_hide_popup (combofix);
 
-    /* hide the selection */
-    gtk_editable_select_region (GTK_EDITABLE (entry), 0, 0);
+    /* fix bug 2208 */
+    //~ gtk_editable_select_region (GTK_EDITABLE (entry), 0, 0);
 
     return (FALSE);
 }
@@ -1489,15 +1515,18 @@ static gboolean gtk_combofix_select_item (GtkComboFix *combofix,
     g_free (tmp_item);
 
     if (result == 0)
-        gtk_tree_model_get_iter_first (model, &iter);
-
-    gtk_tree_selection_select_iter (priv->selection, &iter);
-    path = gtk_tree_model_get_path (model, &iter);
-    if (path)
-    {
-        gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (priv->tree_view), path, NULL, FALSE, 0, 0);
-        gtk_tree_path_free (path);
-    }
+	{
+        if (gtk_tree_model_get_iter_first (model, &iter))
+		{
+			gtk_tree_selection_select_iter (priv->selection, &iter);
+			path = gtk_tree_model_get_path (model, &iter);
+			if (path)
+			{
+				gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (priv->tree_view), path, NULL, FALSE, 0, 0);
+				gtk_tree_path_free (path);
+			}
+		}
+	}
 
     return FALSE;
 }
@@ -1637,10 +1666,12 @@ static void gtk_combofix_create_entry (GtkComboFix *combofix)
 	GtkEntryCompletion *completion;
 	GtkListStore *completion_store;
 	GrisbiAppConf *a_conf;
-    GtkComboFixPrivate *priv;
+	GrisbiWinEtat *w_etat;
+	GtkComboFixPrivate *priv;
 
     priv = gtk_combofix_get_instance_private (combofix);
 	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
+	w_etat = grisbi_win_get_w_etat ();
 
 	/* create entry */
     priv->entry = gtk_entry_new ();
@@ -1648,7 +1679,7 @@ static void gtk_combofix_create_entry (GtkComboFix *combofix)
 	/* set completion */
 	completion = gtk_entry_completion_new ();
 	gtk_entry_completion_set_inline_selection (completion, TRUE);
-	if (etat.combofix_case_sensitive)
+	if (w_etat->combofix_case_sensitive)
 		gtk_entry_completion_set_match_func (completion,
 											 (GtkEntryCompletionMatchFunc) gtk_combofix_completion_match_func,
 											 NULL,
@@ -1660,11 +1691,9 @@ static void gtk_combofix_create_entry (GtkComboFix *combofix)
 	/* set store */
 	completion_store = gtk_list_store_new (1, G_TYPE_STRING);
 	gtk_entry_completion_set_model (completion, GTK_TREE_MODEL (completion_store));
-	g_object_unref (completion_store);
 
 	/* set entry completion */
 	gtk_entry_set_completion (GTK_ENTRY (priv->entry), completion);
-	g_object_unref (completion);
 
 	/* set entry signals */
     g_signal_connect (G_OBJECT (priv->entry),
@@ -1895,9 +1924,7 @@ static void gtk_combofix_class_init (GtkComboFixClass *klass)
     object_class->dispose = gtk_combofix_dispose;
     object_class->finalize = gtk_combofix_finalize;
 
-#if GTK_CHECK_VERSION (3,20,0)
 	gtk_widget_class_set_css_name (GTK_WIDGET_CLASS (klass), "combofix");
-#endif
 }
 
 /******************************************************************************/
@@ -1961,6 +1988,18 @@ GtkWidget *gtk_combofix_new_with_properties (GSList *list,
 	gtk_combofix_set_list (combofix, list);
 	gtk_widget_set_size_request (GTK_WIDGET (combofix), COMBOFIX_MIN_WIDTH, -1);
 
+	/* fix_bug 2154 */
+	if (priv->type == METATREE_PAYEE && priv->force)
+	{
+		GtkEntryCompletion *completion;
+
+		completion = gtk_entry_get_completion (GTK_ENTRY (priv->entry));
+	   g_signal_connect (G_OBJECT (completion),
+						 "no-matches",
+						 G_CALLBACK (gtk_combofix_completion_no_match_selected),
+						 priv);
+	}
+
 	return (GTK_WIDGET (combofix));
 }
 
@@ -2042,26 +2081,28 @@ void gtk_combofix_set_text (GtkComboFix *combofix,
 void gtk_combofix_set_properties (GtkWidget *combofix)
 {
 	gint old_case_sensitive = 0;
-    GtkComboFixPrivate *priv;
+	GrisbiWinEtat *w_etat;
+	GtkComboFixPrivate *priv;
 
     g_return_if_fail (combofix);
     g_return_if_fail (GTK_IS_COMBOFIX (combofix));
 
-    priv = gtk_combofix_get_instance_private (GTK_COMBOFIX (combofix));
+	priv = gtk_combofix_get_instance_private (GTK_COMBOFIX (combofix));
+	w_etat = grisbi_win_get_w_etat ();
 	old_case_sensitive = priv->case_sensitive;
 
 	if (priv->type)
 	{
-		priv->force = etat.combofix_force_category;
-		priv->mixed_sort = etat.combofix_mixed_sort;
+		priv->force = w_etat->combofix_force_category;
+		priv->mixed_sort = w_etat->combofix_mixed_sort;
 	}
 	else
 	{
-		priv->force = etat.combofix_force_payee;
+		priv->force = w_etat->combofix_force_payee;
 		priv->mixed_sort = FALSE;
 	}
-    priv->case_sensitive = etat.combofix_case_sensitive;
-	if (old_case_sensitive - etat.combofix_case_sensitive)
+    priv->case_sensitive = w_etat->combofix_case_sensitive;
+	if (old_case_sensitive - w_etat->combofix_case_sensitive)
 	{
 		GtkEntryCompletion *completion;
 
@@ -2478,6 +2519,7 @@ void gtk_combofix_remove_report (GtkComboFix *combofix,
     gchar *tmp_str;
     gchar *tmp_str2;
     gboolean valid;
+	GrisbiWinEtat *w_etat;
     GtkComboFixPrivate *priv;
 
     /* on récupère le nom de l'état */
@@ -2546,13 +2588,14 @@ void gtk_combofix_remove_report (GtkComboFix *combofix,
 	/* update completion */
 	completion = gtk_entry_get_completion (GTK_ENTRY (priv->entry));
 	completion_model = gtk_entry_completion_get_model (completion);
-    valid = gtk_tree_model_get_iter_first (completion_model, &iter);
+	valid = gtk_tree_model_get_iter_first (completion_model, &iter);
+	w_etat = grisbi_win_get_w_etat ();
 
     while (valid)
     {
         gtk_tree_model_get (completion_model, &iter, 0, &tmp_str, -1);
 
-        if (etat.combofix_case_sensitive && !strcmp (tmp_str2, tmp_str))
+        if (w_etat->combofix_case_sensitive && !strcmp (tmp_str2, tmp_str))
         {
             g_free (tmp_str);
             break;
