@@ -438,23 +438,34 @@ gboolean gsb_budget_update_combofix ( gboolean force )
 void budgetary_lines_exporter_list ( void )
 {
     GtkWidget *dialog;
+	GtkWidget *button_cancel;
+	GtkWidget *button_save;
     gint resultat;
     gchar *nom_ib;
     gchar *tmp_last_directory;
 
-    dialog = gtk_file_chooser_dialog_new ( _("Export the budgetary lines"),
-					   GTK_WINDOW ( grisbi_app_get_active_window (NULL) ),
-					   GTK_FILE_CHOOSER_ACTION_SAVE,
-					   "gtk-cancel", GTK_RESPONSE_CANCEL,
-					   "gtk-save", GTK_RESPONSE_OK,
-					   NULL);
+    dialog = gtk_file_chooser_dialog_new (_("Export the budgetary lines"),
+										  GTK_WINDOW ( grisbi_app_get_active_window (NULL)),
+										  GTK_FILE_CHOOSER_ACTION_SAVE,
+										  NULL, NULL,
+										  NULL);
+
+	button_cancel = gtk_button_new_with_label (_("Cancel"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_cancel, GTK_RESPONSE_CANCEL);
+
+	button_save = gtk_button_new_with_label (_("Save"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_save, GTK_RESPONSE_OK);
+	gtk_widget_set_can_default (button_save, TRUE);
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
     gtk_file_chooser_set_current_name ( GTK_FILE_CHOOSER ( dialog ),  _("Budgetary-lines.igsb"));
     gtk_file_chooser_set_current_folder ( GTK_FILE_CHOOSER ( dialog ), gsb_file_get_last_path () );
     gtk_file_chooser_set_do_overwrite_confirmation ( GTK_FILE_CHOOSER ( dialog ), TRUE);
     gtk_window_set_position ( GTK_WINDOW ( dialog ), GTK_WIN_POS_CENTER_ON_PARENT );
 
-    resultat = gtk_dialog_run ( GTK_DIALOG ( dialog ));
+	gtk_widget_show_all (dialog);
+
+	resultat = gtk_dialog_run ( GTK_DIALOG ( dialog ));
 
     switch ( resultat )
     {
@@ -487,21 +498,31 @@ void budgetary_lines_exporter_list ( void )
 /* **************************************************************************************************** */
 void budgetary_lines_importer_list ( void )
 {
-    GtkWidget *dialog;
-    gint resultat;
+	GtkWidget *dialog;
+	GtkWidget *button_cancel;
+	GtkWidget *button_open;
+	GtkWidget *button_replace;
+	gint resultat;
     gchar *budget_name;
     gint last_transaction_number;
     GtkFileFilter * filter;
     gchar *tmp_last_directory;
 
-    dialog = gtk_file_chooser_dialog_new ( _("Import budgetary lines"),
-					   GTK_WINDOW ( grisbi_app_get_active_window (NULL) ),
-					   GTK_FILE_CHOOSER_ACTION_OPEN,
-					   "gtk-cancel", GTK_RESPONSE_CANCEL,
-					   "gtk-open", GTK_RESPONSE_OK,
-					   NULL);
+    dialog = gtk_file_chooser_dialog_new (_("Import budgetary lines"),
+										  GTK_WINDOW (grisbi_app_get_active_window (NULL)),
+										  GTK_FILE_CHOOSER_ACTION_OPEN,
+										  NULL, NULL,
+										  NULL);
 
-    gtk_file_chooser_set_current_folder ( GTK_FILE_CHOOSER ( dialog ), gsb_file_get_last_path () );
+	button_cancel = gtk_button_new_with_label (_("Cancel"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_cancel, GTK_RESPONSE_CANCEL);
+
+	button_open = gtk_button_new_with_label (_("Open"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_open, GTK_RESPONSE_OK);
+	gtk_widget_set_can_default (button_open, TRUE);
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
+
+	gtk_file_chooser_set_current_folder ( GTK_FILE_CHOOSER ( dialog ), gsb_file_get_last_path () );
     gtk_window_set_position ( GTK_WINDOW ( dialog ), GTK_WIN_POS_CENTER_ON_PARENT );
 
     filter = gtk_file_filter_new ();
@@ -520,6 +541,8 @@ void budgetary_lines_importer_list ( void )
     gtk_file_filter_add_pattern ( filter, "*" );
     gtk_file_chooser_add_filter ( GTK_FILE_CHOOSER ( dialog ), filter );
 
+	gtk_widget_show_all (dialog);
+
     resultat = gtk_dialog_run ( GTK_DIALOG ( dialog ));
 
     if ( resultat != GTK_RESPONSE_OK  )
@@ -547,15 +570,19 @@ void budgetary_lines_importer_list ( void )
 				           "You may also decide to replace existing budgetary lines with imported ones." ) ),
 				       _("Merge imported budgetary lines with existing?") );
 
-    if ( !last_transaction_number)
-	gtk_dialog_add_buttons ( GTK_DIALOG(dialog),
-				 _("Replace existing"), 2,
-				 NULL );
+    if (!last_transaction_number)
+	{
+		button_replace = gtk_button_new_with_label (_("Replace existing"));
+		gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_replace, 2);
+	}
 
-    gtk_dialog_add_buttons ( GTK_DIALOG(dialog),
-			     "gtk-cancel", 0,
-			     "gtk-ok", 1,
-			     NULL );
+	button_cancel = gtk_button_new_with_label (_("Cancel"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_cancel, 0);
+
+	button_open = gtk_button_new_with_label (_("Open"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_open, 1);
+	gtk_widget_set_can_default (button_open, TRUE);
+	gtk_widget_show_all (dialog);
 
     resultat = gtk_dialog_run ( GTK_DIALOG ( dialog ));
     gtk_widget_destroy ( GTK_WIDGET ( dialog ));
@@ -622,7 +649,7 @@ GtkWidget *creation_barre_outils_ib ( void )
     gtk_toolbar_insert ( GTK_TOOLBAR ( toolbar ), item, -1 );
 
     /* Import button */
-    item = utils_buttons_tool_button_new_from_image_label ("gsb-import-24.png", _("Import"));
+    item = utils_buttons_tool_button_new_from_image_resource ("gsb-import-24.png", _("Import"));
     gtk_widget_set_tooltip_text ( GTK_WIDGET ( item ),
                         _("Import a Grisbi budgetary line file (.igsb)"
                         " or create from a list of categories (.cgsb)" ) );
@@ -727,12 +754,7 @@ gboolean popup_budgetary_line_view_mode_menu ( GtkWidget * button )
 
     gtk_widget_show_all ( menu );
 
-#if GTK_CHECK_VERSION (3,22,0)
 	gtk_menu_popup_at_pointer (GTK_MENU (menu), NULL);
-#else
-    gtk_menu_popup ( GTK_MENU(menu), NULL, button, set_popup_position, button, 1,
-		     gtk_get_current_event_time());
-#endif
     return FALSE;
 }
 
@@ -745,6 +767,8 @@ gboolean popup_budgetary_line_view_mode_menu ( GtkWidget * button )
 gboolean edit_budgetary_line ( GtkTreeView * view )
 {
     GtkWidget * dialog, *paddingbox, *table, *label, *entry, *hbox, *radiogroup;
+	GtkWidget *button_cancel;
+	GtkWidget *button_apply;
     GtkTreeSelection * selection;
     GtkTreeModel * model = NULL;
     GtkTreeIter iter;
@@ -775,14 +799,21 @@ gboolean edit_budgetary_line ( GtkTreeView * view )
 							     0,
 							     _("No budget defined") ));
 
-    dialog = gtk_dialog_new_with_buttons ( title ,
-					   GTK_WINDOW ( grisbi_app_get_active_window (NULL) ),
-					   GTK_DIALOG_MODAL,
-					   "gtk-cancel", GTK_RESPONSE_NO,
-					   "gtk-apply", GTK_RESPONSE_OK,
-					   NULL );
+    dialog = gtk_dialog_new_with_buttons (title,
+										  GTK_WINDOW (grisbi_app_get_active_window (NULL)),
+										  GTK_DIALOG_MODAL,
+										  NULL, NULL,
+										  NULL);
 
-    gtk_window_set_position ( GTK_WINDOW ( dialog ), GTK_WIN_POS_CENTER_ON_PARENT );
+	button_cancel = gtk_button_new_with_label (_("Cancel"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_cancel, GTK_RESPONSE_CANCEL);
+	gtk_widget_set_can_default (button_cancel, TRUE);
+
+	button_apply = gtk_button_new_with_label (_("Apply"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_apply, GTK_RESPONSE_APPLY);
+	gtk_widget_set_can_default (button_apply, TRUE);
+
+	gtk_window_set_position ( GTK_WINDOW ( dialog ), GTK_WIN_POS_CENTER_ON_PARENT );
     gtk_window_set_resizable ( GTK_WINDOW ( dialog ), FALSE );
 
     /* Ugly dance to avoid side effects on dialog's vbox. */
@@ -838,7 +869,7 @@ gboolean edit_budgetary_line ( GtkTreeView * view )
 
     while ( 1 )
     {
-	if ( gtk_dialog_run ( GTK_DIALOG(dialog) ) != GTK_RESPONSE_OK )
+	if ( gtk_dialog_run ( GTK_DIALOG(dialog) ) != GTK_RESPONSE_APPLY)
 	{
         sortie_edit_budgetary_line = TRUE;
 	    gtk_widget_destroy ( GTK_WIDGET ( dialog ) );
@@ -1191,11 +1222,7 @@ void budgetary_line_list_popup_context_menu ( void )
     /* Finish all. */
     gtk_widget_show_all ( menu );
 
-#if GTK_CHECK_VERSION (3,22,0)
 	gtk_menu_popup_at_pointer (GTK_MENU (menu), NULL);
-#else
-    gtk_menu_popup ( GTK_MENU ( menu ), NULL, NULL, NULL, NULL, 3, gtk_get_current_event_time ( ) );
-#endif
 }
 
 
