@@ -40,7 +40,6 @@
 #include "prefs_page_archives.h"
 #include "dialog.h"
 #include "grisbi_app.h"
-#include "gsb_account_property.h"
 #include "gsb_autofunc.h"
 #include "gsb_data_account.h"
 #include "gsb_data_archive.h"
@@ -57,6 +56,7 @@
 #include "utils_dates.h"
 #include "utils_prefs.h"
 #include "utils_str.h"
+#include "widget_account_property.h"
 #include "erreur.h"
 
 /*END_INCLUDE*/
@@ -284,7 +284,7 @@ static gboolean prefs_page_archives_destroy_archive (GtkWidget *button,
 		if (account_number >= 0)
 		{
 			/* we are on an account */
-			gsb_account_property_fill_page ();
+			widget_account_property_fill ();
 			transaction_list_set_balances ();
 		}
 
@@ -553,7 +553,6 @@ static void prefs_page_archives_setup_treeview_archives (PrefsPageArchives *page
 static void prefs_page_archives_setup_page (PrefsPageArchives *page)
 {
 	GtkWidget *head_page;
-	gchar* tmp_str;
 	gboolean is_loading;
 	GrisbiAppConf *a_conf;
 	PrefsPageArchivesPrivate *priv;
@@ -571,7 +570,6 @@ static void prefs_page_archives_setup_page (PrefsPageArchives *page)
 
 	/* set the entry widget entry_archives_name */
 	gsb_autofunc_entry_new_from_ui (priv->entry_archives_name,
-	                                NULL,
 								    G_CALLBACK (prefs_page_archives_name_changed),
 								    priv->treeview_archives,
 								    G_CALLBACK (gsb_data_archive_set_name),
@@ -607,20 +605,12 @@ static void prefs_page_archives_setup_page (PrefsPageArchives *page)
 							priv->treeview_archives);
 
     /* button to delete an archive and free the transactions */
-    tmp_str = g_build_filename (gsb_dirs_get_pixmaps_dir (), "gsb-import-24.png", NULL);
-    gtk_button_set_image (GTK_BUTTON (priv->button_archives_delete),
-						  gtk_image_new_from_file (tmp_str));
-    g_free (tmp_str);
     g_signal_connect (G_OBJECT (priv->button_archives_delete),
                       "clicked",
                       G_CALLBACK (prefs_page_archives_delete_archive),
                       priv->treeview_archives);
 
 	/* button to delete an archive and delete the transactions */
-    tmp_str = g_build_filename (gsb_dirs_get_pixmaps_dir (), "gsb-import-24.png", NULL);
-    gtk_button_set_image (GTK_BUTTON (priv->button_archives_destroy),
-						  gtk_image_new_from_file (tmp_str));
-    g_free (tmp_str);
     g_signal_connect (G_OBJECT (priv->button_archives_destroy),
                       "clicked",
                       G_CALLBACK (prefs_page_archives_destroy_archive),
@@ -629,6 +619,7 @@ static void prefs_page_archives_setup_page (PrefsPageArchives *page)
 	/* set the checkbutton for the automatic check */
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_archives_check_auto),
 								  a_conf->archives_check_auto);
+	g_object_set_data (G_OBJECT (priv->checkbutton_archives_check_auto), "widget", priv->spinbutton_archives_check_auto);
 
 	/* Connect signal */
     g_signal_connect (priv->checkbutton_archives_check_auto,
@@ -675,7 +666,7 @@ static void prefs_page_archives_class_init (PrefsPageArchivesClass *klass)
 	G_OBJECT_CLASS (klass)->dispose = prefs_page_archives_dispose;
 
 	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass),
-												 "/org/gtk/grisbi/ui/prefs_page_archives.ui");
+												 "/org/gtk/grisbi/prefs/prefs_page_archives.ui");
 
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageArchives, vbox_archives);
 
