@@ -369,7 +369,7 @@ static void prefs_page_currency_link_setup_treeview (PrefsPageCurrencyLink *page
 		{
 			column = gtk_tree_view_column_new_with_attributes (gettext (title[i]),
 															   gtk_cell_renderer_pixbuf_new (),
-															   "stock-id", i,
+															   "icon-name", i,
 															   "cell-background-rgba", LINK_BACKGROUND_COLOR,
 															   NULL);
 		}
@@ -477,7 +477,7 @@ static void prefs_page_currency_link_class_init (PrefsPageCurrencyLinkClass *kla
 	G_OBJECT_CLASS (klass)->dispose = prefs_page_currency_link_dispose;
 
 	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass),
-												 "/org/gtk/grisbi/ui/prefs_page_currency_link.ui");
+												 "/org/gtk/grisbi/prefs/prefs_page_currency_link.ui");
 
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageCurrencyLink, vbox_currency_link);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageCurrencyLink, button_currency_link_add);
