@@ -63,7 +63,6 @@ struct _PrefsPageDisplayGuiPrivate
 	GtkWidget *			checkbutton_low_definition_screen;
 
     GtkWidget *			radiobutton_display_both;
-    GtkWidget *			radiobutton_display_both_horiz;
     GtkWidget *			radiobutton_display_icon;
     GtkWidget *			radiobutton_display_text;
 
@@ -88,13 +87,13 @@ static gboolean prefs_page_display_gui_active_scrolling_left_pane (GtkWidget *to
 																   GrisbiAppConf *a_conf)
 {
 	if (a_conf->active_scrolling_left_pane)
-        g_signal_handlers_unblock_by_func (gsb_gui_navigation_get_tree_view (),
-										   G_CALLBACK (gsb_gui_navigation_check_scroll),
-										   NULL);
-    else
-        g_signal_handlers_block_by_func (gsb_gui_navigation_get_tree_view (),
-										 G_CALLBACK (gsb_gui_navigation_check_scroll),
-										 NULL);
+		g_signal_handlers_unblock_by_func (gsb_gui_navigation_get_tree_view (),
+				G_CALLBACK (gsb_gui_navigation_check_scroll),
+				NULL);
+	else
+		g_signal_handlers_block_by_func (gsb_gui_navigation_get_tree_view (),
+				G_CALLBACK (gsb_gui_navigation_check_scroll),
+				NULL);
 
 	return FALSE;
 }
@@ -166,7 +165,7 @@ static gboolean prefs_page_display_gui_definition_screen_toggled (GtkWidget *tog
 	grisbi_prefs_update_prefs_hpaned (prefs);
 
 	/* init status bar */
-	grisbi_win_init_statusbar (NULL);
+	grisbi_win_status_bar_init (NULL);
 
 	/* update navigation pane */
 	if (grisbi_win_file_is_loading ())
@@ -270,39 +269,29 @@ static void prefs_page_display_gui_setup_page (PrefsPageDisplayGui *page,
     /* set the variables for display toolbar */
 	switch (a_conf->display_toolbar)
 	{
-		case GSB_BUTTON_BOTH:
+		case GTK_TOOLBAR_BOTH:
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->radiobutton_display_both), TRUE);
 			break;
 
-		case GSB_BUTTON_BOTH_HORIZ:
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->radiobutton_display_both_horiz), TRUE);
-			break;
-
-		case GSB_BUTTON_ICON:
+		case GTK_TOOLBAR_ICONS:
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->radiobutton_display_icon), TRUE);
 			break;
 
-		case GSB_BUTTON_TEXT:
+		case GTK_TOOLBAR_TEXT:
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->radiobutton_display_text), TRUE);
 			break;
 	}
 
-	/* choix non disponible */
-	gtk_widget_set_sensitive (priv->radiobutton_display_both_horiz, FALSE);
-
 	/* set data for each widget */
 	g_object_set_data (G_OBJECT (priv->radiobutton_display_both),
 					   "display",
-					   GINT_TO_POINTER (GSB_BUTTON_BOTH));
-	g_object_set_data (G_OBJECT (priv->radiobutton_display_both_horiz),
-					   "display",
-					   GINT_TO_POINTER (GSB_BUTTON_BOTH_HORIZ));
+					   GINT_TO_POINTER (GTK_TOOLBAR_BOTH));
 	g_object_set_data (G_OBJECT (priv->radiobutton_display_icon),
 					   "display",
-					   GINT_TO_POINTER (GSB_BUTTON_ICON));
+					   GINT_TO_POINTER (GTK_TOOLBAR_ICONS));
 	g_object_set_data (G_OBJECT (priv->radiobutton_display_text),
 					   "display",
-					   GINT_TO_POINTER (GSB_BUTTON_TEXT));
+					   GINT_TO_POINTER (GTK_TOOLBAR_TEXT));
 
 	/* Connect signal */
 	g_signal_connect (G_OBJECT (priv->radiobutton_display_both),
@@ -310,11 +299,6 @@ static void prefs_page_display_gui_setup_page (PrefsPageDisplayGui *page,
 					  G_CALLBACK (prefs_page_display_gui_change_toolbar_display_mode),
 					  a_conf);
 
-	g_signal_connect (G_OBJECT (priv->radiobutton_display_both_horiz),
-					  "toggled",
-					  G_CALLBACK (prefs_page_display_gui_change_toolbar_display_mode),
-					  a_conf);
-
 	g_signal_connect (G_OBJECT (priv->radiobutton_display_icon),
 					  "toggled",
 					  G_CALLBACK (prefs_page_display_gui_change_toolbar_display_mode),
@@ -356,14 +340,13 @@ static void prefs_page_display_gui_class_init (PrefsPageDisplayGuiClass *klass)
 	G_OBJECT_CLASS (klass)->dispose = prefs_page_display_gui_dispose;
 
 	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass),
-												 "/org/gtk/grisbi/ui/prefs_page_display_gui.ui");
+												 "/org/gtk/grisbi/prefs/prefs_page_display_gui.ui");
 
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayGui, vbox_display_gui);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayGui, checkbutton_show_headings_bar);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayGui, checkbutton_active_scrolling_left_pane);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayGui, checkbutton_low_definition_screen);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayGui, radiobutton_display_both);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayGui, radiobutton_display_both_horiz);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayGui, radiobutton_display_icon);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayGui, radiobutton_display_text);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayGui, text_view_display_shorcuts);
