@@ -69,8 +69,11 @@ struct _PrefsPageDiversPrivate
     GtkWidget *			grid_generalities;
 	GtkWidget *			button_reset_prefs_window;
 	GtkWidget *			entry_web_browser;
+	GtkWidget *			hbox_display_pdf;
 	GtkWidget *			label_prefs_settings;
 	GtkWidget *			notebook_divers;
+	GtkWidget *			radiobutton_display_html;
+	GtkWidget *			radiobutton_display_pdf;
 
 	/* scheduler */
 	GtkWidget *         vbox_launch_scheduler;
@@ -104,6 +107,29 @@ G_DEFINE_TYPE_WITH_PRIVATE (PrefsPageDivers, prefs_page_divers, GTK_TYPE_BOX)
 /******************************************************************************/
 /* Private functions                                                          */
 /******************************************************************************/
+/**
+ *
+ *
+ * \param
+ * \param
+ * \param
+ *
+ * \return
+ **/
+static gboolean prefs_page_divers_radiobutton_help_press_event (GtkWidget *button,
+																GdkEvent  *event,
+																GrisbiAppConf *a_conf)
+{
+	gint button_number;
+
+	button_number = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (button), "pointer"));
+	if (button_number == 1)
+		a_conf->display_help = 0;
+	else
+		a_conf->display_help = 1;
+
+	return FALSE;
+}
 /**
  *
  *
@@ -120,10 +146,18 @@ static void prefs_page_divers_button_reset_prefs_window_clicked (GtkButton *butt
 	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
 	paned_prefs = grisbi_prefs_get_prefs_hpaned (GRISBI_PREFS (prefs));
 	a_conf->prefs_height = PREFS_WIN_MIN_HEIGHT;
-	a_conf->prefs_width = PREFS_WIN_MIN_WIDTH;
 	a_conf->prefs_panel_width = PREFS_PANED_MIN_WIDTH;
 
-	gtk_widget_set_size_request(GTK_WIDGET (prefs), PREFS_WIN_MIN_WIDTH, PREFS_WIN_MIN_HEIGHT);
+	if (a_conf->low_definition_screen)
+	{
+		a_conf->prefs_width = PREFS_WIN_MIN_WIDTH_LOW;
+		gtk_widget_set_size_request(GTK_WIDGET (prefs), PREFS_WIN_MIN_WIDTH_LOW, PREFS_WIN_MIN_HEIGHT);
+	}
+	else
+	{
+		a_conf->prefs_width = PREFS_WIN_MIN_WIDTH_HIGH;
+		gtk_widget_set_size_request(GTK_WIDGET (prefs), PREFS_WIN_MIN_WIDTH_HIGH, PREFS_WIN_MIN_HEIGHT);
+	}
 	gtk_paned_set_position (GTK_PANED (paned_prefs), PREFS_PANED_MIN_WIDTH);
 }
 
@@ -141,6 +175,9 @@ static void prefs_page_divers_choose_thousands_sep_changed (GtkComboBoxText *wid
     GtkWidget *entry;
     gchar *str_capital;
     const gchar *text;
+	GrisbiWinEtat *w_etat;
+
+	w_etat = (GrisbiWinEtat *) grisbi_win_get_w_etat ();
 
     text = gtk_combo_box_text_get_active_text (widget);
     combo_box = g_object_get_data (G_OBJECT (widget), "separator");
@@ -175,8 +212,8 @@ static void prefs_page_divers_choose_thousands_sep_changed (GtkComboBoxText *wid
     /* reset capital */
     entry = bet_finance_ui_get_capital_entry ();
     str_capital = utils_real_get_string_with_currency (gsb_real_double_to_real (
-                    etat.bet_capital),
-                    etat.bet_currency,
+                    w_etat->bet_capital),
+                    w_etat->bet_currency,
                     FALSE);
 
     gtk_entry_set_text (GTK_ENTRY (entry), str_capital);
@@ -192,8 +229,11 @@ static void prefs_page_divers_choose_decimal_point_changed (GtkComboBoxText *wid
     GtkWidget *entry;
     gchar *str_capital;
     const gchar *text;
+	GrisbiWinEtat *w_etat;
 
-    text = gtk_combo_box_text_get_active_text (widget);
+	w_etat = (GrisbiWinEtat *) grisbi_win_get_w_etat ();
+
+	text = gtk_combo_box_text_get_active_text (widget);
     combo_box = g_object_get_data (G_OBJECT (widget), "separator");
 
     if (g_strcmp0 (text, ",") == 0)
@@ -219,8 +259,8 @@ static void prefs_page_divers_choose_decimal_point_changed (GtkComboBoxText *wid
     /* reset capital */
     entry = bet_finance_ui_get_capital_entry ();
     str_capital = utils_real_get_string_with_currency (gsb_real_double_to_real (
-                    etat.bet_capital),
-                    etat.bet_currency,
+                    w_etat->bet_capital),
+                    w_etat->bet_currency,
                     FALSE);
 
     gtk_entry_set_text (GTK_ENTRY (entry), str_capital);
@@ -414,7 +454,11 @@ static gboolean prefs_page_divers_scheduler_set_fixed_day_changed (GtkWidget *ch
  * */
 static gboolean prefs_page_divers_scheduler_change_account (GtkWidget *combo)
 {
-	etat.scheduler_default_account_number = gsb_account_get_combo_account_number (combo);
+	GrisbiWinEtat *w_etat;
+
+	w_etat = (GrisbiWinEtat *) grisbi_win_get_w_etat ();
+
+	w_etat->scheduler_default_account_number = gsb_account_get_combo_account_number (combo);
 
     return FALSE;
 }
@@ -574,20 +618,21 @@ static void prefs_page_divers_setup_divers_page (PrefsPageDivers *page,
 												 GrisbiPrefs *win)
 {
 	GtkWidget *head_page;
+	GtkWidget *image;
     GtkWidget *vbox_button;
     GtkWidget *combo;
-#ifdef USE_CONFIG_FILE
 	gchar *config_file;
-#endif
 	gint combo_index;
 	gboolean is_loading;
 	GrisbiAppConf *a_conf;
+	GrisbiWinEtat *w_etat;
 	PrefsPageDiversPrivate *priv;
 
 	devel_debug (NULL);
 
 	priv = prefs_page_divers_get_instance_private (page);
 	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
+	w_etat = (GrisbiWinEtat *) grisbi_win_get_w_etat ();
 	is_loading = grisbi_win_file_is_loading ();
 
 	/* On récupère le nom de la page */
@@ -599,14 +644,21 @@ static void prefs_page_divers_setup_divers_page (PrefsPageDivers *page,
     /* set the variables for programs */
 	gsb_automem_entry_new_from_ui (priv->entry_web_browser, &a_conf->browser_command, NULL, NULL);
 
-	/* set preferences settings : gsettings or config file */
-#ifdef USE_CONFIG_FILE
-		config_file = g_strconcat (_("File: "), gsb_dirs_get_grisbirc_filename (), NULL);
-		gtk_label_set_text	(GTK_LABEL (priv->label_prefs_settings), config_file);
-		g_free (config_file);
-#else
-		gtk_label_set_text	(GTK_LABEL (priv->label_prefs_settings), "Gsettings");
-#endif
+	/* set help display */
+	image = gtk_image_new_from_resource ("/org/gtk/grisbi/images/gsb-pdf.svg");
+	gtk_image_set_pixel_size (GTK_IMAGE (image), 16);
+	gtk_container_add (GTK_CONTAINER (priv->hbox_display_pdf), image);
+	gtk_box_reorder_child (GTK_BOX (priv->hbox_display_pdf), image, 0);
+
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->radiobutton_display_pdf), a_conf->display_help);
+	g_object_set_data (G_OBJECT (priv->radiobutton_display_html), "pointer", GINT_TO_POINTER (1));
+	g_object_set_data (G_OBJECT (priv->radiobutton_display_pdf), "pointer", GINT_TO_POINTER (2));
+
+	/* set config file */
+	config_file = g_strconcat (_("File: "), gsb_dirs_get_grisbirc_filename (), NULL);
+	gtk_label_set_text	(GTK_LABEL (priv->label_prefs_settings), config_file);
+	g_free (config_file);
+
 	/* set signal button_reset_prefs_window */
 	g_signal_connect (priv->button_reset_prefs_window,
 					  "clicked",
@@ -639,12 +691,12 @@ static void prefs_page_divers_setup_divers_page (PrefsPageDivers *page,
 
 	/* Init checkbutton set fixed date */
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_scheduler_set_fixed_date),
-								  etat.scheduler_set_fixed_date);
+								  w_etat->scheduler_set_fixed_date);
 	gtk_widget_set_sensitive (priv->checkbutton_scheduler_set_fixed_date, is_loading);
 
 	/* Adding and init widgets select defaut compte */
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_scheduler_set_default_account),
-								  etat.scheduler_set_default_account);
+								  w_etat->scheduler_set_default_account);
 
 	if (is_loading)
 		combo = gsb_account_create_combo_list (G_CALLBACK (prefs_page_divers_scheduler_change_account), NULL, FALSE);
@@ -655,8 +707,8 @@ static void prefs_page_divers_setup_divers_page (PrefsPageDivers *page,
 	gtk_box_pack_start (GTK_BOX (priv->hbox_launch_scheduler_set_default_account), combo, FALSE, FALSE, 0);
 	g_object_set_data (G_OBJECT (priv->checkbutton_scheduler_set_default_account), "widget", combo);
 
-	if (etat.scheduler_set_default_account)
-		gsb_account_set_combo_account_number (combo, etat.scheduler_default_account_number);
+	if (w_etat->scheduler_set_default_account)
+		gsb_account_set_combo_account_number (combo, w_etat->scheduler_default_account_number);
 	else
 		gtk_widget_set_sensitive (GTK_WIDGET (combo), FALSE);
 
@@ -684,6 +736,16 @@ static void prefs_page_divers_setup_divers_page (PrefsPageDivers *page,
 
 
 	/* Connect signal */
+	/* callback select help display */
+	g_signal_connect (G_OBJECT (priv->radiobutton_display_html),
+					  "button-press-event",
+					  G_CALLBACK (prefs_page_divers_radiobutton_help_press_event),
+					  a_conf);
+	g_signal_connect (G_OBJECT (priv->radiobutton_display_pdf),
+					  "button-press-event",
+					  G_CALLBACK (prefs_page_divers_radiobutton_help_press_event),
+					  a_conf);
+
     /* callback for spinbutton_nb_days_before_scheduled */
     g_signal_connect (priv->spinbutton_nb_days_before_scheduled,
 					  "value-changed",
@@ -711,13 +773,13 @@ static void prefs_page_divers_setup_divers_page (PrefsPageDivers *page,
 	g_signal_connect (priv->checkbutton_scheduler_set_fixed_date,
 					  "toggled",
 					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
-					  &etat.scheduler_set_fixed_date);
+					  &w_etat->scheduler_set_fixed_date);
 
     /* callback for checkbutton_scheduler_set_default_account */
     g_signal_connect (priv->checkbutton_scheduler_set_default_account,
 					  "toggled",
 					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
-					  &etat.scheduler_set_default_account);
+					  &w_etat->scheduler_set_default_account);
 
 	/* set the localization parameters */
 	/* set the language */
@@ -785,7 +847,7 @@ static void prefs_page_divers_class_init (PrefsPageDiversClass *klass)
 	G_OBJECT_CLASS (klass)->dispose = prefs_page_divers_dispose;
 
 	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass),
-												 "/org/gtk/grisbi/ui/prefs_page_divers.ui");
+												 "/org/gtk/grisbi/prefs/prefs_page_divers.ui");
 
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDivers, vbox_divers);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDivers, grid_generalities);
@@ -795,6 +857,10 @@ static void prefs_page_divers_class_init (PrefsPageDiversClass *klass)
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDivers, entry_web_browser);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDivers, label_prefs_settings);
 
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDivers, hbox_display_pdf);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDivers, radiobutton_display_html);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDivers, radiobutton_display_pdf);
+
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDivers, vbox_launch_scheduler);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDivers, hbox_launch_scheduler_set_default_account);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDivers, checkbutton_scheduler_set_default_account);
