@@ -38,14 +38,16 @@
 
 /*START_INCLUDE*/
 #include "prefs_page_files.h"
+#include "dialog.h"
 #include "grisbi_app.h"
 #include "gsb_account.h"
+#include "gsb_data_account.h"
+#include "gsb_dirs.h"
 #include "gsb_file.h"
-#include "parametres.h"
+#include "gsb_select_icon.h"
 #include "structures.h"
 #include "utils_prefs.h"
 #include "erreur.h"
-
 /*END_INCLUDE*/
 
 /*START_EXTERN*/
@@ -61,7 +63,9 @@ struct _PrefsPageFilesPrivate
     GtkWidget *         checkbutton_sauvegarde_auto;
     GtkWidget *         checkbutton_force_enregistrement;
     GtkWidget *         checkbutton_compress_file;
+	GtkWidget *			checkbutton_use_icons_file_dir;
     GtkWidget *         checkbutton_crypt_file;
+	GtkWidget *			label_use_icons_file_dir;
 	GtkWidget *			label_nb_max_derniers_fichiers;
 	GtkWidget *         spinbutton_nb_max_derniers_fichiers;
 
@@ -84,6 +88,108 @@ G_DEFINE_TYPE_WITH_PRIVATE (PrefsPageFiles, prefs_page_files, GTK_TYPE_BOX)
 /******************************************************************************/
 /* Private functions                                                          */
 /******************************************************************************/
+/**
+ *
+ *
+ * \param
+ * \param
+ *
+ * \return
+ **/
+static void prefs_page_files_use_icons_file_dir_toggled (GtkToggleButton *checkbutton,
+														 PrefsPageFilesPrivate *priv)
+{
+	if (gtk_toggle_button_get_active (checkbutton))
+	{
+		GSList *icons_name_list = NULL;
+		GSList *tmp_list;
+		gchar *msg;
+		gchar *str_to_free = NULL;
+		gchar *tmp_str = NULL;
+		gint nbre_account = 0;
+		gint nbre_errors = 0;
+		gint i = 0;
+
+		devel_debug (NULL);
+		tmp_list = gsb_data_account_get_list_accounts ();
+		while (tmp_list)
+		{
+			const gchar *account_icon_name;
+			gint tmp_account;
+
+			tmp_account = gsb_data_account_get_no_account (tmp_list->data);
+			account_icon_name = gsb_data_account_get_name_icon (tmp_account);
+			if (account_icon_name && strlen (account_icon_name))
+			{
+				gchar *icon_basename;
+				gchar *new_icon_name;
+
+				icon_basename = g_path_get_basename (account_icon_name);
+
+				/* on ignore les doublons */
+				if (!g_slist_find_custom (icons_name_list, account_icon_name, (GCompareFunc) g_strcmp0))
+				{
+					icons_name_list = g_slist_insert_sorted (icons_name_list,
+															 g_strdup (account_icon_name),
+															 (GCompareFunc) g_strcmp0);
+				}
+
+				new_icon_name = gsb_select_icon_set_icon_in_user_icons_dir (account_icon_name);
+				gsb_data_account_set_name_icon (tmp_account, new_icon_name);
+				if (new_icon_name == NULL)
+					nbre_errors++;
+				else
+					g_free (new_icon_name);
+				g_free (icon_basename);
+				nbre_account++;
+			}
+			tmp_list = tmp_list->next;
+		}
+
+		/* set list icons for msg */
+		tmp_list = icons_name_list;
+		while (tmp_list)
+		{
+			if (tmp_str == NULL)
+			{
+				tmp_str =  g_strdup_printf ("%s\n", (gchar *) g_slist_nth_data (icons_name_list, i));
+			}
+			else
+			{
+				tmp_str =  g_strconcat (tmp_str, "\t- ", (gchar *) g_slist_nth_data (icons_name_list, i), "\n", NULL);
+				g_free (str_to_free);
+			}
+			str_to_free = tmp_str;
+			i++;
+			tmp_list = tmp_list->next;
+		}
+		if (nbre_errors)
+			msg = g_strdup_printf (_("%d accounts have a specific icon among the following %d icons:\n"
+									 "\t- %s"
+									 "\n"
+									 "Une ou plusieurs erreurs de copie ont eu lieu probablement "
+									 "pour des raisons de droits d'écriture dans le répertoire de "
+									 "destination.\n"),
+								   nbre_account,
+								   g_slist_length (icons_name_list),
+								   tmp_str);
+		else
+			msg = g_strdup_printf (_("%d accounts have a specific icon among the following %d icons:\n"
+									 "\t- %s"
+									 "\n"
+									 "These icons have been copied into the directory:\n%s\n"),
+								   nbre_account,
+								   g_slist_length (icons_name_list),
+								   tmp_str,
+								   gsb_dirs_get_user_icons_dir ());
+
+		dialogue_warning_hint (msg,_("Move account icons in the accounts file directory"));
+
+		g_free (tmp_str);
+		g_slist_free_full (icons_name_list, (GDestroyNotify) g_free);
+	}
+}
+
 /**
  * Création de la page de gestion des fichiers
  *
@@ -94,13 +200,14 @@ G_DEFINE_TYPE_WITH_PRIVATE (PrefsPageFiles, prefs_page_files, GTK_TYPE_BOX)
 static void prefs_page_files_setup_files_page (PrefsPageFiles *page)
 {
 	GtkWidget *head_page;
+	const gchar *icons_dir;
+	gchar *tmp_str;
 	gboolean is_loading;
 	GrisbiAppConf *a_conf;
 	GrisbiWinEtat *w_etat;
 	PrefsPageFilesPrivate *priv;
 
 	devel_debug (NULL);
-
 	priv = prefs_page_files_get_instance_private (page);
 	is_loading = grisbi_win_file_is_loading ();
 	a_conf = grisbi_app_get_a_conf ();
@@ -128,6 +235,37 @@ static void prefs_page_files_setup_files_page (PrefsPageFiles *page)
     gtk_spin_button_set_value (GTK_SPIN_BUTTON (priv->spinbutton_nb_max_derniers_fichiers),
 							   a_conf->nb_max_derniers_fichiers_ouverts);
 
+	/* set the label for accounts icons */
+	icons_dir = gsb_dirs_get_user_icons_dir ();
+	tmp_str = g_strconcat (_("Put the specific icons of the accounts in the directory:\n"
+							 "\t"), icons_dir,
+						   NULL);
+	gtk_label_set_text (GTK_LABEL (priv->label_use_icons_file_dir), tmp_str);
+	g_free (tmp_str);
+
+	/* test and set value */
+	if (w_etat->use_icons_file_dir)
+	{
+		const gchar *icon_dir;
+
+		icon_dir = gsb_dirs_get_user_icons_dir ();
+		if (!g_file_test (icon_dir, G_FILE_TEST_IS_DIR))
+		{
+			gchar *msg;
+
+			msg = g_strdup (_("You selected the option \"put the specific icons of the accounts "
+							  "in the directory of the accounts file\" but you did not use this "
+							  "possibility.\n"
+							  "If you need it, do so otherwise uncheck the option" ));
+
+			dialogue_warning_hint (msg,_("Put the icons of the accounts in the directory of the accounts file"));
+			g_free (msg);
+
+		}
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_use_icons_file_dir),
+									  w_etat->use_icons_file_dir);
+	}
+
     /* Connect signal */
     g_signal_connect (priv->checkbutton_load_last_file,
 					  "toggled",
@@ -161,6 +299,16 @@ static void prefs_page_files_setup_files_page (PrefsPageFiles *page)
 							NULL);
 #endif
 
+	g_signal_connect (priv->checkbutton_use_icons_file_dir,
+					  "toggled",
+					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
+					  &w_etat->use_icons_file_dir);
+
+	g_signal_connect_after (priv->checkbutton_use_icons_file_dir,
+							"toggled",
+							G_CALLBACK (prefs_page_files_use_icons_file_dir_toggled),
+							NULL);
+
 	/* callback for spinbutton_nb_max_derniers_fichiers_ouverts */
     g_signal_connect (priv->spinbutton_nb_max_derniers_fichiers,
                         "value-changed",
@@ -305,7 +453,7 @@ static void prefs_page_files_class_init (PrefsPageFilesClass *klass)
 	G_OBJECT_CLASS (klass)->dispose = prefs_page_files_dispose;
 
 	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass),
-												 "/org/gtk/grisbi/ui/prefs_page_files.ui");
+												 "/org/gtk/grisbi/prefs/prefs_page_files.ui");
 
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, vbox_files);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, checkbutton_load_last_file);
@@ -313,6 +461,8 @@ static void prefs_page_files_class_init (PrefsPageFilesClass *klass)
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, checkbutton_force_enregistrement);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, checkbutton_compress_file);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, checkbutton_crypt_file);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, checkbutton_use_icons_file_dir);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, label_use_icons_file_dir);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, label_nb_max_derniers_fichiers);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, spinbutton_nb_max_derniers_fichiers);
 
