@@ -43,7 +43,6 @@
 #include "gsb_file.h"
 #include "imputation_budgetaire.h"
 #include "navigation.h"
-#include "parametres.h"
 #include "structures.h"
 #include "tiers_onglet.h"
 #include "utils_prefs.h"
@@ -338,7 +337,7 @@ static void prefs_page_metatree_setup_metatree_page (PrefsPageMetatree *page)
 									  w_etat->metatree_assoc_mode);
 
 		/* set for metatree_unarchived_payees */
-		if (etat.combofix_force_payee)
+		if (w_etat->combofix_force_payee)
 		{
 			gtk_widget_set_sensitive (priv->checkbutton_metatree_unarchived_payees, FALSE);
 			w_etat->metatree_unarchived_payees = FALSE;
@@ -425,7 +424,7 @@ static void prefs_page_metatree_class_init (PrefsPageMetatreeClass *klass)
 	G_OBJECT_CLASS (klass)->dispose = prefs_page_metatree_dispose;
 
 	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass),
-												 "/org/gtk/grisbi/ui/prefs_page_metatree.ui");
+												 "/org/gtk/grisbi/prefs/prefs_page_metatree.ui");
 
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageMetatree, vbox_metatree);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageMetatree, grid_metatree_currencies);
