@@ -100,27 +100,6 @@ enum ReconciliationColumns
 /******************************************************************************/
 /* Private functions                                                          */
 /******************************************************************************/
-/**
- *
- *
- * \param
- *
- * \return
- **/
-static void prefs_page_reconcile_setup_button_collapse_row (GtkWidget *button)
-{
-	GtkWidget *image;
-    gchar *filename;
-
-    filename = g_build_filename (gsb_dirs_get_pixmaps_dir (), "gsb-up-16.png", NULL);
-	image = gtk_image_new_from_file (filename);
-	g_free (filename);
-
-	gtk_button_set_image (GTK_BUTTON (button), image);
-	gtk_button_set_always_show_image (GTK_BUTTON (button), TRUE);
-	gtk_widget_set_sensitive (button, FALSE);
-}
-
 /**
  * sensitive unsensitive details of reconcile
  *
@@ -640,7 +619,7 @@ static void prefs_page_reconcile_setup_page (PrefsPageReconcile *page)
 													     priv->treeview_reconcile,
 													     G_CALLBACK (gsb_data_reconcile_set_name),
 													     0);
-    gtk_widget_set_size_request (priv->entry_reconcile_name, ENTRY_MIN_WIDTH_1, -1);
+    gtk_widget_set_size_request (priv->entry_reconcile_name, ENTRY_MIN_WIDTH, -1);
 	gtk_grid_attach (GTK_GRID (priv->grid_reconcile), priv->entry_reconcile_name, 2, 6, 1, 1);
 
 	priv->entry_reconcile_init_date = gsb_autofunc_date_new (NULL,
@@ -648,7 +627,7 @@ static void prefs_page_reconcile_setup_page (PrefsPageReconcile *page)
 															 priv->treeview_reconcile,
 															 G_CALLBACK (gsb_data_reconcile_set_init_date),
 															 0);
-    gtk_widget_set_size_request (priv->entry_reconcile_init_date, ENTRY_MIN_WIDTH_1, -1);
+    gtk_widget_set_size_request (priv->entry_reconcile_init_date, ENTRY_MIN_WIDTH, -1);
 	gtk_grid_attach (GTK_GRID (priv->grid_reconcile), priv->entry_reconcile_init_date, 2, 7, 1, 1);
 
 	priv->entry_reconcile_final_date = gsb_autofunc_date_new (NULL,
@@ -656,7 +635,7 @@ static void prefs_page_reconcile_setup_page (PrefsPageReconcile *page)
 															  priv->treeview_reconcile,
 															  G_CALLBACK (gsb_data_reconcile_set_final_date),
 															  0);
-    gtk_widget_set_size_request (priv->entry_reconcile_final_date, ENTRY_MIN_WIDTH_1, -1);
+    gtk_widget_set_size_request (priv->entry_reconcile_final_date, ENTRY_MIN_WIDTH, -1);
 	gtk_grid_attach (GTK_GRID (priv->grid_reconcile), priv->entry_reconcile_final_date, 2, 8, 1, 1);
 
 	priv->entry_reconcile_init_balance = gsb_autofunc_real_new (null_real,
@@ -664,7 +643,7 @@ static void prefs_page_reconcile_setup_page (PrefsPageReconcile *page)
 																priv->treeview_reconcile,
 																G_CALLBACK (gsb_data_reconcile_set_init_balance),
 																0);
-    gtk_widget_set_size_request (priv->entry_reconcile_init_balance, ENTRY_MIN_WIDTH_1, -1);
+    gtk_widget_set_size_request (priv->entry_reconcile_init_balance, ENTRY_MIN_WIDTH, -1);
 	gtk_grid_attach (GTK_GRID (priv->grid_reconcile), priv->entry_reconcile_init_balance, 4, 7, 1, 1);
 
 	priv->entry_reconcile_final_balance = gsb_autofunc_real_new (null_real,
@@ -672,7 +651,7 @@ static void prefs_page_reconcile_setup_page (PrefsPageReconcile *page)
 																 priv->treeview_reconcile,
 																 G_CALLBACK (gsb_data_reconcile_set_final_balance),
 																 0);
-    gtk_widget_set_size_request (priv->entry_reconcile_final_balance, ENTRY_MIN_WIDTH_1, -1);
+    gtk_widget_set_size_request (priv->entry_reconcile_final_balance, ENTRY_MIN_WIDTH, -1);
     gtk_grid_attach (GTK_GRID (priv->grid_reconcile), priv->entry_reconcile_final_balance, 4, 8, 1, 1);
 
 	/* set the checkbutton_reconcile_sort */
@@ -681,7 +660,7 @@ static void prefs_page_reconcile_setup_page (PrefsPageReconcile *page)
 
 	/* set unsensitive details */
 	prefs_page_reconcile_sensitive_details (page, FALSE);
-	prefs_page_reconcile_setup_button_collapse_row (priv->button_collapse_row);
+	gtk_widget_set_sensitive (priv->button_collapse_row, FALSE);
 
     /* Connect signal */
     g_signal_connect (G_OBJECT (priv->radiobutton_end_date_2),
@@ -735,7 +714,7 @@ static void prefs_page_reconcile_class_init (PrefsPageReconcileClass *klass)
 	G_OBJECT_CLASS (klass)->dispose = prefs_page_reconcile_dispose;
 
 	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass),
-												 "/org/gtk/grisbi/ui/prefs_page_reconcile.ui");
+												 "/org/gtk/grisbi/prefs/prefs_page_reconcile.ui");
 
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageReconcile, vbox_reconcile);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageReconcile, button_collapse_row);
