@@ -1,8 +1,8 @@
 /* ************************************************************************** */
 /*                                                                            */
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
-/*         2008-2017 Pierre Biava (grisbi@pierre.biava.name)                  */
-/*         https://www.grisbi.org/                                             */
+/*         2008-2021 Pierre Biava (grisbi@pierre.biava.name)                  */
+/*         https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -37,6 +37,7 @@
 /*START_INCLUDE*/
 #include "print_report.h"
 #include "dialog.h"
+#include "etats_gtktable.h"
 #include "grisbi_app.h"
 #include "gsb_data_print_config.h"
 #include "gsb_file.h"
@@ -48,10 +49,10 @@
 
 
 /*START_STATIC*/
+static GtkWidget *	table_etat = NULL;
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern GtkWidget *	table_etat;
 extern gint 		nb_colonnes;
 extern gint 		nb_lignes;
 /*END_EXTERN*/
@@ -539,6 +540,8 @@ static gboolean print_config_show_config_apply (GtkPrintOperation *operation,
 gboolean print_report (GtkWidget *button,
                        gpointer null)
 {
+	table_etat = etats_gtktable_get_table_etat ();
+
     if (!table_etat)
     {
 		dialogue_error_hint (_("Please select a report before trying to print it."),
@@ -564,6 +567,7 @@ void print_report_export_pdf (const gchar *pdf_name)
     g_value_init (&value, G_TYPE_STRING);
     g_value_set_string (&value, pdf_name);
 
+	table_etat = etats_gtktable_get_table_etat ();
 	print = gtk_print_operation_new ();
 
 	if (print_settings != NULL)
