@@ -1,7 +1,7 @@
 /* ************************************************************************** */
 /*                                                                            */
-/*     Copyright (C)	2000-2008 Cédric Auger (cedric@grisbi.org)	      */
-/* 			http://www.grisbi.org				      */
+/*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
+/*          https://www.grisbi.org                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -40,6 +40,7 @@
 #include "gsb_data_print_config.h"
 #include "gsb_data_transaction.h"
 #include "gsb_rgba.h"
+#include "gsb_transactions_list.h"
 #include "utils.h"
 #include "print_dialog_config.h"
 #include "transaction_model.h"
@@ -78,8 +79,6 @@ static GtkWidget * print_transactions_list_layout_config ( GtkPrintOperation * o
 
 
 /*START_EXTERN*/
-extern gchar *titres_colonnes_liste_operations[CUSTOM_MODEL_VISIBLE_COLUMNS];
-extern gint transaction_col_width[CUSTOM_MODEL_VISIBLE_COLUMNS];
 /*END_EXTERN*/
 
 
@@ -685,24 +684,31 @@ gboolean print_transactions_list_get_visibles_lines ( gint *number_of_archives,
  *
  * \return
  * */
-static void print_transactions_list_calculate_columns ( gdouble page_width )
+static void print_transactions_list_calculate_columns ( gdouble width_page)
 {
     gint total_text_width = 0;
     gint column;
+	gint *width_pointer;
+;
 
     /* set the positions of the columns */
+	width_pointer = gsb_transactions_list_get_tab_width_col_treeview ();
     columns_position[0] = 0.0;
     for ( column=1 ; column<CUSTOM_MODEL_VISIBLE_COLUMNS ; column++)
-	columns_position[column] = (gdouble) (transaction_col_width[column - 1]*page_width/100) + columns_position[column - 1];
+	{
+		columns_position[column] = (gdouble) (*(width_pointer+(column-1))*width_page/100) + columns_position[column - 1];
+	}
 
-    /* set the page_width of the columns */
+    /* set the width_page of the columns */
     for (column = 0 ; column < (CUSTOM_MODEL_VISIBLE_COLUMNS  - 1); column++ )
     {
-	columns_width[column] = (columns_position[column + 1] - columns_position[column] - 3*gsb_data_print_config_get_draw_column ()) * PANGO_SCALE;
-	total_text_width = total_text_width + columns_width[column];
+		columns_width[column] = (columns_position[column + 1] - columns_position[column]
+								 - 3*gsb_data_print_config_get_draw_column ()) * PANGO_SCALE;
+		total_text_width = total_text_width + columns_width[column];
     }
     /* last column is the rest of the line */
-    columns_width[CUSTOM_MODEL_VISIBLE_COLUMNS - 1] = (page_width -3*gsb_data_print_config_get_draw_column ()*(CUSTOM_MODEL_VISIBLE_COLUMNS)) * PANGO_SCALE - total_text_width;
+    columns_width[CUSTOM_MODEL_VISIBLE_COLUMNS - 1] = (width_page -3*gsb_data_print_config_get_draw_column ()
+													   *(CUSTOM_MODEL_VISIBLE_COLUMNS)) * PANGO_SCALE - total_text_width;
 }
 
 /**
@@ -763,7 +769,7 @@ static gint print_transactions_list_draw_columns_title ( GtkPrintContext *contex
 	column_position = columns_position[column];
 
 	/* get the text */
-	text = _(titres_colonnes_liste_operations[column]);
+	text = gsb_transactions_list_get_column_title (0, column);
 	if (!text)
 	    continue;
 
@@ -810,10 +816,7 @@ static void print_transactions_list_draw_background ( CustomRecord *record,
 
         color = gsb_rgba_get_couleur ( "background_archive" );
         cairo_rectangle ( cr, 0, line_position, page_width, size_row + 2*gsb_data_print_config_get_draw_lines ( ) );
-        cairo_set_source_rgb ( cr,
-                        (gdouble) color -> red/65535,
-                        (gdouble) color -> green/65535,
-                        (gdouble) color -> blue/65535 );
+        cairo_set_source_rgb (cr, (gdouble) color->red, (gdouble) color->green, (gdouble) color->blue);
     }
     else
     {
@@ -827,10 +830,7 @@ static void print_transactions_list_draw_background ( CustomRecord *record,
 
         cairo_rectangle (cr, 0, line_position, page_width,
                         custom_list -> nb_rows_by_transaction * size_row + 2*gsb_data_print_config_get_draw_lines ( ) );
-        cairo_set_source_rgb (cr,
-                        (gdouble) color -> red/65535,
-                        (gdouble) color -> green/65535,
-                        (gdouble) color -> blue/65535 );
+        cairo_set_source_rgb (cr, (gdouble) color->red, (gdouble) color->green, (gdouble) color->blue);
     }
     cairo_fill ( cr );
     cairo_set_source_rgb ( cr, 0.0, 0.0, 0.0 );
