@@ -248,6 +248,7 @@ static void transaction_list_append_child (gint transaction_number)
              * before the mother */
             orphan_child_transactions = g_slist_append (orphan_child_transactions,
 														GINT_TO_POINTER (transaction_number));
+			g_free(newrecord);
             return;
         }
     }
@@ -267,16 +268,10 @@ static void transaction_list_append_child (gint transaction_number)
      * so if no child, better to stop here */
     if (!pos)
     {
-		gchar *tmp_str;
-
-		tmp_str = g_strdup_printf (_("Trying to append the child number %d to the mother %d "
-									"in the model, but no white line was created before... "
-									"Better to stop here, please contact the Grisbi team to "
-									"fix that issue."),
-									transaction_number,
-								  gsb_data_transaction_get_mother_transaction_number (transaction_number));
-		dialogue_error (tmp_str);
-		g_free (tmp_str);
+		/* fix bug 2202 */
+		/* Trying to append the child transaction to a mother in the model, but no white line was created before */
+		orphan_child_transactions = g_slist_append (orphan_child_transactions,
+													GINT_TO_POINTER (transaction_number));
 		g_free (newrecord);
 
 		return;
@@ -933,7 +928,7 @@ gboolean transaction_list_remove_archive (gint archive_number)
  *
  * \return
  * */
-void transaction_list_filter (gint account_number)
+gboolean transaction_list_filter (gint account_number)
 {
     gint current_pos_general_list;
     gint current_pos_filtered_list = 0;
@@ -942,6 +937,7 @@ void transaction_list_filter (gint account_number)
     GtkTreeIter iter;
     gint i;
     gint *neworder;
+	gboolean re_filter = FALSE;
     CustomList *custom_list;
 	GrisbiAppConf *a_conf;
 
@@ -950,8 +946,8 @@ void transaction_list_filter (gint account_number)
 
     devel_debug (NULL);
 
-    g_return_if_fail (custom_list != NULL);
-    g_return_if_fail (custom_list->num_rows != 0);
+    g_return_val_if_fail (custom_list != NULL, FALSE);
+    g_return_val_if_fail (custom_list->num_rows != 0, FALSE);
 
     /* there is a bug, i think in gtk, which when we re-filter the list with opened split, and when
      * there is less lines in the list that the window, gtk close the split opened without
@@ -962,7 +958,7 @@ void transaction_list_filter (gint account_number)
 
     /* we erase the selection */
     if (custom_list->selected_row)
-	transaction_list_select_unselect ();
+		transaction_list_select_unselect ();
 
     custom_list->nb_rows_by_transaction = gsb_data_account_get_nb_rows (account_number);
 
@@ -1098,6 +1094,12 @@ void transaction_list_filter (gint account_number)
         gtk_tree_path_next (path);
     }
 
+	/* fix bug 2172 */
+	if (previous_visible_rows > 0 && current_pos_filtered_list != previous_visible_rows)
+	{
+		re_filter = TRUE;
+	}
+
     /* if the previous list was bigger than now, we need to delete some rows */
     if (previous_visible_rows > current_pos_filtered_list)
 	{
@@ -1136,6 +1138,8 @@ void transaction_list_filter (gint account_number)
 
     gtk_tree_path_free(path);
     g_free(neworder);
+
+	return re_filter;
 }
 
 
@@ -1186,24 +1190,24 @@ void transaction_list_colorize (void)
                 white_record = record->children_rows[record->number_of_children -1];
                 transaction_list_update_white_child (white_record);
             }
-            else
-            {
-                /* set the color of the mother */
+				else
+				{
+					/* set the color of the mother */
                 for (j=0 ; j<TRANSACTION_LIST_ROWS_NB ; j++)
                     record->transaction_records[j]->text_color = gsb_rgba_get_couleur ("text_unfinished_split");
             }
 
         }
 	    /* if we changed of transaction, change the color */
-	    if (record->transaction_pointer != current_transaction_pointer)
-	    {
-		current_color = !current_color;
-		current_transaction_pointer = record->transaction_pointer;
-	    }
+			if (record->transaction_pointer != current_transaction_pointer)
+			{
+				current_color = !current_color;
+				current_transaction_pointer = record->transaction_pointer;
+			}
 
-	    /* set the color of the row */
-	    record->row_bg = gsb_rgba_get_couleur_with_indice ("couleur_fond", current_color);
-	}
+			/* set the color of the row */
+			record->row_bg = gsb_rgba_get_couleur_with_indice ("couleur_fond", current_color);
+		}
     }
 }
 
@@ -2384,6 +2388,41 @@ gboolean transaction_list_check_line_is_visible (gint line_in_transaction,
     return FALSE;
 }
 
+/**
+ * reset the color of transation
+ *
+ * \param gint		number of transaction
+ *
+ * \return
+ **/
+void transaction_list_reset_transaction_color (gint transaction_number)
+{
+	GdkRGBA *text_color;
+	GtkTreeIter iter;
+	gint i;
+	CustomList *custom_list;
+	CustomRecord *record;
+
+	custom_list = transaction_model_get_model ();
+
+	if (custom_list == NULL)
+		return;
+
+	/* get the record */
+	if (!transaction_model_get_transaction_iter (&iter, transaction_number, 0))
+		return;
+
+	record = iter.user_data;
+	if (!record)
+		return;
+
+	/* reset the color of the transaction */
+	text_color = gsb_rgba_get_couleur_with_indice ("text_color", 0);
+
+	for (i=0 ; i<TRANSACTION_LIST_ROWS_NB ; i++)
+		record->transaction_records[i]->text_color = text_color;
+}
+
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
