@@ -37,7 +37,6 @@
 #include "gsb_data_account.h"
 #include "gsb_dirs.h"
 #include "gsb_rgba.h"
-#include "parametres.h"
 #include "structures.h"
 #include "erreur.h"
 /*END_INCLUDE*/
@@ -50,49 +49,11 @@
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern GtkWidget *fenetre_preferences;
 /*END_EXTERN*/
 
-/*START_GLOBAL*/
-struct CsvSeparators csv_separators[] =			/* Contains all pre-defined CSV separators. */
-{
-    { N_("Comma"),		"," },
-    { N_("Semi-colon"),	";" },
-    { N_("Colon"),		":" },
-    { N_("Tabulation"),	"\t" },
-    { N_("Other"),		NULL },
-};
-/*END_GLOBAL*/
-
 /******************************************************************************/
 /* Private functions                                                          */
 /******************************************************************************/
-/**
- * Callback triggered when user changed the pre-defined csv separators
- * combobox.  Update the text entry and thus the preview.
- *
- * \param combo		GtkComboBox that triggered event.
- * \param entry		Associated entry to change.
- *
- * \return			FALSE
- **/
-static gboolean utils_widget_csv_separators_combo_changed (GtkComboBox *combo,
-														   GtkWidget *entry)
-{
-    gint active = gtk_combo_box_get_active (combo);
-
-    if (csv_separators [active].value)
-    {
-		gtk_entry_set_text (GTK_ENTRY (entry), csv_separators [active].value);
-    }
-    else
-    {
-		gtk_entry_set_text (GTK_ENTRY (entry), "");
-    }
-
-    return FALSE;
-}
-
 /******************************************************************************/
 /* Public functions                                                           */
 /******************************************************************************/
@@ -224,7 +185,6 @@ gboolean lance_navigateur_web (const gchar *url)
             tmp_str = g_strconcat (" \"", url, "\" ", NULL);
             chaine = g_strjoinv (tmp_str, split);
             g_free(tmp_str);
-            g_strfreev (split);
 
             /* add the & character at the end */
             tmp_str = g_strconcat (chaine, "&", NULL);
@@ -233,6 +193,7 @@ gboolean lance_navigateur_web (const gchar *url)
         }
         else
             chaine = g_strconcat (a_conf->browser_command, " \"", url, "\"&", NULL);
+		g_strfreev (split);
 
         if (system (chaine) == -1)
         {
@@ -386,7 +347,7 @@ GtkWidget *new_vbox_with_title_and_icon (const gchar *title,
  */
 gboolean assert_account_loaded (void)
 {
-  return gsb_data_account_get_accounts_amount () != 0;
+  return gsb_data_account_get_number_of_accounts () != 0;
 }
 
 
@@ -464,15 +425,10 @@ gchar *get_gtk_run_version (void)
 void lance_mailer (const gchar *uri)
 {
     GError *error = NULL;
-
-#if GTK_CHECK_VERSION (3,22,0)
 	GtkWindow *window;
 
 	window = GTK_WINDOW (grisbi_app_get_active_window (NULL));
     if (gtk_show_uri_on_window (window, uri, GDK_CURRENT_TIME, &error) == FALSE)
-#else
-	if (gtk_show_uri (NULL, uri, GDK_CURRENT_TIME, &error) == FALSE)
-#endif
     {
         gchar *tmp_str;
 
@@ -867,32 +823,6 @@ void utils_labels_set_alignment (GtkLabel *label,
     gtk_label_set_yalign (label, yalign);
 }
 
-/**
- * set xalign and yalign to label
- *
- * \param
- * \param
- * \param
- *
- * \return
- * */
-void utils_widget_set_padding (GtkWidget *widget,
-							   gint xpad,
-							   gint ypad)
-{
-    if (xpad)
-    {
-        gtk_widget_set_margin_start (widget, xpad);
-        gtk_widget_set_margin_end (widget, xpad);
-    }
-
-    if (ypad)
-    {
-        gtk_widget_set_margin_top (widget, ypad);
-        gtk_widget_set_margin_bottom (widget, ypad);
-    }
-}
-
 /**
  * Création d'un GtkToolButton à partir d'une image et d'un label
  *
@@ -932,122 +862,36 @@ GtkWidget *utils_menu_item_new_from_image_label (const gchar *image_name,
 }
 
 /**
+ * Création d'un GtkToolButton à partir d'une image et d'un label
  *
+ * \param image_name    filename
+ * \param label_name    label for button
  *
- * \param
- * \param
- * \param
- *
- * \return
- **/
-guint utils_widget_csv_separators_combo_block_unblock (gpointer instance,
-													   gpointer entry,
-													   gboolean block)
+ * \return a GtkToolItem or NULL
+ * */
+GtkWidget *utils_menu_item_new_from_resource_label (const gchar *image_name,
+													const gchar *label_name)
 {
-	guint hid;
+	GtkWidget *menu_item = NULL;
+	GtkWidget *box;
+	GtkWidget *image;
+	GtkWidget *label;
+	gchar *resource;
 
-	if (block)
-		hid = g_signal_handlers_block_by_func (instance,
-											   utils_widget_csv_separators_combo_changed,
-											   entry);
-	else
-		hid = g_signal_handlers_unblock_by_func (instance,
-												 utils_widget_csv_separators_combo_changed,
-												 entry);
+	resource = g_strconcat ("/org/gtk/grisbi/images/", image_name, NULL);
 
-	return hid;
-}
+	image = gtk_image_new_from_resource (resource);
+	g_free (resource);
 
-/**
- *
- *
- * \param
- * \param
- * \param
- *
- * \return
- **/
-GtkWidget *utils_widget_csv_separators_new (GtkSizeGroup *size_group,
-											GCallback hook_entry,
-											gpointer assistant)
-{
-	GtkWidget *hbox;
-	GtkWidget *combobox;
-	GtkWidget *entry;
-    gint i = 0;
+	label = gtk_label_new (label_name);
+	box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX);
+	gtk_container_add (GTK_CONTAINER (box), image);
+	gtk_container_add (GTK_CONTAINER (box), label);
 
-	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX);
+	menu_item = gtk_menu_item_new ();
+	gtk_container_add (GTK_CONTAINER (menu_item), box);
 
-    combobox = gtk_combo_box_text_new ();
-    do
-    {
-		gchar *complete_name;
-
-		complete_name = g_strdup_printf ("%s : \"%s\"",
-										 _(csv_separators [i].name),
-										 (csv_separators [i].value ?
-										 csv_separators [i].value : ""));
-		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combobox), complete_name);
-		g_free (complete_name);
-
-    }
-    while (csv_separators [i ++].value);
-
-	entry = gsb_automem_entry_new (NULL,
-								   G_CALLBACK (hook_entry),
-								   assistant);
-    g_object_set_data (G_OBJECT(entry), "combobox", combobox);
-    g_object_set_data (G_OBJECT(entry), "assistant", assistant);
-	g_object_set_data (G_OBJECT(assistant), "entry", entry);
-
-	/* set size of widgets */
-	if (size_group)
-	{
-		gtk_size_group_add_widget (size_group, combobox);
-		gtk_size_group_add_widget (size_group, entry);
-		gtk_box_pack_start (GTK_BOX (hbox), combobox, FALSE, FALSE, MARGIN_BOX);
-		gtk_box_pack_start (GTK_BOX (hbox), entry, FALSE, FALSE, MARGIN_BOX);
-	}
-	else
-	{
-		gtk_box_pack_start (GTK_BOX (hbox), combobox, TRUE, TRUE, MARGIN_BOX);
-		gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, TRUE, MARGIN_BOX);
-	}
-
-	/* set signals */
-    g_signal_connect (G_OBJECT (combobox),
-					  "changed",
-					  G_CALLBACK (utils_widget_csv_separators_combo_changed),
-					  entry);
-
-	gtk_combo_box_set_active(GTK_COMBO_BOX (combobox), 0);
-
-	gtk_widget_show_all (hbox);
-
-	return hbox;
-}
-
-/**
- *
- *
- * \param
- *
- * \return
- **/
-gint utils_widget_csv_separators_combo_update (const gchar *separator)
-{
-	gint i = 0;
-
-    while (csv_separators [i].value)
-    {
-        if (strcmp (csv_separators [i].value, separator) == 0)
-        {
-            break;
-        }
-        i ++ ;
-    }
-
-	return i;
+    return menu_item;
 }
 
 /**
