@@ -5,7 +5,7 @@
 /*          2003-2007 Benjamin Drieu(bdrieu@april.org)                        */
 /*          2003-2004 Alain Portal(aportal@univ-montp2.fr)                    */
 /*          2008-2017 Pierre Biava (grisbi@pierre.biava.name)                 */
-/*          https://www.grisbi.org/                                            */
+/*          https://www.grisbi.org/                                           */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -256,15 +256,15 @@ static GSList *utils_files_check_UTF8_validity (const gchar *contents,
         if (ptr_tmp)
         {
             gchar *ptr_r;
+			gchar *tmp_str;
 
             string = g_strndup (ptr, ((ptr_tmp) - ptr));
             if ((ptr_r = g_strrstr (string, "\r")))
                 ptr_r[0] = '\0';
 
-            if (g_convert (string, -1, "UTF-8", coding_system, NULL, NULL, NULL) == NULL)
+			tmp_str = g_convert (string, -1, "UTF-8", coding_system, NULL, NULL, NULL);
+            if (tmp_str == NULL)
             {
-                gchar *tmp_str;
-
                 long_str = strlen (string);
                 result = g_malloc0 (sizeof (struct CheckEncoding));
                 result->charset = "";
@@ -286,6 +286,8 @@ static GSList *utils_files_check_UTF8_validity (const gchar *contents,
 
                 return list;
             }
+			else
+				g_free(tmp_str);
             g_free (string);
             ptr = ptr_tmp + 1;
         }
@@ -373,94 +375,129 @@ static void utils_files_go_charmap_sel_changed (GtkWidget *go_charmap_sel,
 void utils_files_append_name_to_recent_array (const gchar *filename)
 {
 	gchar **recent_array;
-    gchar *dernier;
-    gint position;
-    gint i;
+	gchar **new_recent_array;
+	gint position = 0;
+	gint i;
 	GrisbiAppConf *a_conf;
 
 	if (!filename)
 		return;
 
 	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
-    if (a_conf->nb_max_derniers_fichiers_ouverts == 0)
-        return;
+	if (a_conf->nb_max_derniers_fichiers_ouverts == 0)
+		return;
 
-    if (a_conf->nb_derniers_fichiers_ouverts < 0)
+	if (a_conf->nb_derniers_fichiers_ouverts < 0)
 	{
-        a_conf->nb_derniers_fichiers_ouverts = 0;
+		a_conf->nb_derniers_fichiers_ouverts = 0;
 	}
 
 	recent_array = grisbi_app_get_recent_files_array ();
-
-    /* on commence par vérifier si ce fichier n'est pas dans les nb_derniers_fichiers_ouverts  */
-    position = 0;
-
-    if (a_conf->nb_derniers_fichiers_ouverts)
-    {
-        for (i = 0; i < a_conf->nb_derniers_fichiers_ouverts; i++)
-        {
-            if (!strcmp (filename, recent_array[i]))
-            {
-                /* 	si ce fichier est déjà le dernier ouvert, on laisse tomber */
-                if (i == 0)
-                {
-                    return;
-                }
-                position = i;
-            }
-        }
-
-		if (position)
-        {
-            /* le fichier a été trouvé, on fait juste une rotation */
-            for (i = position; i > 0 ; i--)
-			{
-                recent_array[i] = recent_array[i-1];
-			}
-
-			recent_array[0] = my_strdup (filename);
-
-			grisbi_app_set_recent_files_array (recent_array);
-			grisbi_app_update_recent_files_menu ();
-
-            return;
-        }
-        /* le fichier est nouveau, on décale tout d'un cran et on met le nouveau à 0 */
-
-        /* si on est déjà au max, c'est juste un décalage avec perte du dernier */
-        /* on garde le ptit dernier dans le cas contraire */
-        dernier = recent_array[a_conf->nb_derniers_fichiers_ouverts-1];
-        for (i = a_conf->nb_derniers_fichiers_ouverts - 1 ; i > 0 ; i--)
-		{
-            recent_array[i] = recent_array[i-1];
-		}
-    }
-    else
-	{
-        dernier = NULL;
-	}
-
-	/* on ajoute 1 nom de fichier */
-
-	if (a_conf->nb_derniers_fichiers_ouverts == 0)
+	if (recent_array == NULL)	/* a_conf->nb_derniers_fichiers_ouverts = 0 */
 	{
 		recent_array = g_malloc0 ((++a_conf->nb_derniers_fichiers_ouverts +1) * sizeof (gchar*));
+		recent_array[0] = my_strdup (filename);
+		grisbi_app_set_recent_files_array (recent_array);
+		grisbi_app_update_recent_files_menu ();
+
+		return;
 	}
-	else
+	/* on commence par vérifier si ce fichier n'est pas dans les nb_derniers_fichiers_ouverts  */
+	position = 0;
+	for (i = 0; i < a_conf->nb_derniers_fichiers_ouverts; i++)
 	{
-		recent_array = g_realloc (recent_array, (++a_conf->nb_derniers_fichiers_ouverts +1) * sizeof (gchar*));
+		if (!strcmp (filename, recent_array[i]))
+		{
+			/* 	si ce fichier est déjà le dernier ouvert, on laisse tomber */
+			if (i == 0)
+			{
+				return;
+			}
+			position = i;
+		}
 	}
 
-	if (a_conf->nb_derniers_fichiers_ouverts <= a_conf->nb_max_derniers_fichiers_ouverts)
-		recent_array[a_conf->nb_derniers_fichiers_ouverts-1] = dernier;
+	if (position)
+	{
+		/* le fichier a été trouvé, on fait juste une rotation */
+		for (i = position; i > 0 ; i--)
+		{
+			recent_array[i] = recent_array[i-1];
+		}
 
-	recent_array[a_conf->nb_derniers_fichiers_ouverts] = NULL;
+		recent_array[0] = my_strdup (filename);
+		grisbi_app_set_recent_files_array (recent_array);
+		grisbi_app_update_recent_files_menu ();
 
-    recent_array[0] = my_strdup (filename);
-	grisbi_app_set_recent_files_array (recent_array);
+		return;
+	}
+
+	/* le fichier est nouveau, on met le nouveau au debut et on ajoute les autres */
+	new_recent_array = g_malloc0 ((++a_conf->nb_derniers_fichiers_ouverts +1) * sizeof (gchar*));
+	new_recent_array[0] = my_strdup (filename);
+	for (i = 1; i < a_conf->nb_derniers_fichiers_ouverts ; i++)
+	{
+		if (i == a_conf->nb_max_derniers_fichiers_ouverts)
+			break;
+
+		new_recent_array[i] = recent_array[i-1];
+	}
+	grisbi_app_set_recent_files_array (new_recent_array);
 	grisbi_app_update_recent_files_menu ();
 }
 
+/**
+ * remove a name in recent_array tab
+ *
+ * \param
+ *
+ * \return
+ **/
+void utils_files_remove_name_to_recent_array (const gchar *filename)
+{
+	gchar **recent_array;
+	gchar **new_recent_array;
+	gint i = 0;
+	gint j = 0;
+	GrisbiAppConf *a_conf;
+
+	devel_debug (filename);
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
+	recent_array = grisbi_app_get_recent_files_array ();
+
+	if (a_conf->nb_derniers_fichiers_ouverts == 1)
+	{
+		g_free (recent_array[0]);
+		g_free (recent_array);
+		grisbi_app_set_recent_files_array (NULL);
+		a_conf->nb_derniers_fichiers_ouverts = 0;
+		grisbi_app_update_recent_files_menu ();
+		grisbi_win_no_file_page_update (grisbi_app_get_active_window (NULL));
+
+		return;
+	}
+
+	/* on cree un nouveau tableau sans le fichier a supprimer */
+	new_recent_array = g_malloc0 ((a_conf->nb_derniers_fichiers_ouverts) * sizeof (gchar*));
+	for (i = 0; i < a_conf->nb_derniers_fichiers_ouverts; i++)
+	{
+		if (!strcmp (filename, recent_array[i]))
+		{
+			g_free (recent_array[i]);
+		}
+		else
+		{
+			new_recent_array[j] = recent_array[i];
+			j++;
+		}
+	}
+	new_recent_array[j] = NULL;
+	a_conf->nb_derniers_fichiers_ouverts = g_strv_length (new_recent_array);
+	grisbi_app_set_recent_files_array (new_recent_array);
+	grisbi_app_update_recent_files_menu ();
+	grisbi_win_no_file_page_update (grisbi_app_get_active_window (NULL));
+}
+
 /*
  * get the line af the file,
  * convert it in UTF8 and fill string with that line
@@ -481,6 +518,9 @@ gint utils_files_get_utf8_line_from_file (FILE *fichier,
     gchar *pointeur_char = NULL;
     gchar *tmp_string;
 
+	/* start with a known value */
+	*string = NULL;
+
     if (!fichier)
 	return 0;
 
@@ -631,30 +671,34 @@ GtkWidget *utils_files_create_file_chooser (GtkWidget *parent,
 											gchar *titre)
 {
     GtkWidget *chooser;
-    GtkWidget *bouton_cancel, *bouton_OK;
+    GtkWidget *bouton_cancel;
+    GtkWidget *bouton_open;
 
-    chooser = gtk_file_chooser_dialog_new (titre,
-                        GTK_WINDOW (parent),
-                        GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
-                        NULL, NULL, NULL);
+	chooser = gtk_file_chooser_dialog_new (titre,
+										   GTK_WINDOW (parent),
+										   GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
+										   NULL, NULL,
+										   NULL);
 
-    bouton_cancel = gtk_dialog_add_button (GTK_DIALOG (chooser),
-                                "gtk-cancel",
-                                GTK_RESPONSE_CANCEL);
+	bouton_cancel = gtk_button_new_with_label (_("Cancel"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (chooser), bouton_cancel, GTK_RESPONSE_CANCEL);
     g_signal_connect (G_OBJECT (bouton_cancel),
 		       "clicked",
 		       G_CALLBACK (utils_files_file_chooser_cancel),
 		       chooser);
 
-    bouton_OK = gtk_dialog_add_button (GTK_DIALOG (chooser),
-                                "gtk-open",
-                                GTK_RESPONSE_ACCEPT);
-	(void)bouton_OK; /* unused value: fix warning -Wunused-but-set-variable */
+    bouton_open = gtk_button_new_with_label (_("Open"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (chooser), bouton_open, GTK_RESPONSE_ACCEPT);
 
 	gtk_window_set_position (GTK_WINDOW (chooser), GTK_WIN_POS_CENTER_ON_PARENT);
     gtk_window_set_transient_for (GTK_WINDOW (chooser), GTK_WINDOW (parent));
     gtk_widget_set_size_request (chooser, 600, 750);
 
+	gtk_widget_set_can_default (bouton_open, TRUE);
+	gtk_dialog_set_default_response (GTK_DIALOG (chooser), GTK_RESPONSE_ACCEPT);
+
+	gtk_widget_show_all (chooser);
+
     return  chooser;
 }
 
@@ -698,6 +742,8 @@ gchar *utils_files_create_sel_charset (GtkWidget *assistant,
 {
     GtkWidget *dialog, *vbox, *sw, *tree_view;
     GtkWidget *hbox, *warn, *label;
+	GtkWidget *button_cancel;
+	GtkWidget *button_OK;
     GtkTreeViewColumn *column;
     GtkCellRenderer *renderer;
     GtkTreeModel *model;
@@ -708,11 +754,19 @@ gchar *utils_files_create_sel_charset (GtkWidget *assistant,
     gint result;
 
     dialog = gtk_dialog_new_with_buttons (_("Select a charmap"),
-                            GTK_WINDOW (assistant),
-                            GTK_DIALOG_MODAL,
-                            "gtk-cancel", 0,
-                            "gtk-ok", GTK_RESPONSE_OK,
-                            NULL);
+										  GTK_WINDOW (assistant),
+										  GTK_DIALOG_MODAL,
+										  NULL, NULL,
+										  NULL);
+
+	button_cancel = gtk_button_new_with_label (_("Cancel"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_cancel, GTK_RESPONSE_CANCEL);
+	gtk_widget_set_can_default (button_cancel, TRUE);
+
+	button_OK = gtk_button_new_with_label (_("Validate"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_OK, GTK_RESPONSE_OK);
+	gtk_widget_set_can_default (button_OK, TRUE);
+
     gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ON_PARENT);
     gtk_widget_set_size_request (dialog, 600, -1);
     gtk_dialog_set_response_sensitive   (GTK_DIALOG (dialog), GTK_RESPONSE_OK, FALSE);
