@@ -37,7 +37,6 @@
 #include "grisbi_prefs.h"
 #include "gsb_file.h"
 #include "gsb_dirs.h"
-#include "parametres.h"
 #include "structures.h"
 #include "utils.h"
 #include "utils_str.h"
@@ -756,6 +755,8 @@ gboolean utils_prefs_encryption_toggled (GtkWidget *checkbox,
     }
 	else
 		w_run->new_crypted_file = FALSE;
+
+	gsb_file_set_modified(TRUE);
 #else
 	gchar *text = _("This build of Grisbi does not support encryption.\n"
 					"Please recompile Grisbi with OpenSSL encryption enabled.");
