@@ -939,15 +939,9 @@ gchar *utils_str_dtostr (gdouble number,
 {
     gchar buffer[G_ASCII_DTOSTR_BUF_SIZE];
     gchar *str_number;
-    gchar *decimal;
-    gchar *format;
     gint nbre_char;
 
-    decimal = utils_str_itoa (nbre_decimal);
-    format = g_strconcat ("%.", decimal, "f", NULL);
-    nbre_char = g_sprintf (buffer, format, number);
-    g_free (decimal);
-    g_free (format);
+    nbre_char = g_sprintf (buffer, "%.*f", nbre_decimal, number);
 
     if (nbre_char > G_ASCII_DTOSTR_BUF_SIZE)
         return NULL;
@@ -1070,9 +1064,12 @@ gchar *utils_str_incremente_number_from_str (const gchar *str_number,
 
     new_str_number = utils_str_itoa (number);
 
-    if (prefix && strlen (prefix) > 0)
+    if (prefix)
     {
-        new_str_number = g_strconcat (prefix, new_str_number, NULL);
+		gchar *tmp_str;
+		tmp_str = g_strconcat (prefix, new_str_number, NULL);
+		g_free(new_str_number);
+		new_str_number = tmp_str;
         g_free (prefix);
     }
 
@@ -1328,6 +1325,7 @@ gchar *utils_str_break_form_name_field (const gchar *text,
 
 			tab= g_strsplit (text, ":", 2);
 			tmp_str = g_strconcat (tab[0], ":\n", tab[1]+1, NULL);
+			g_strfreev (tab);
 		}
 		else if (g_utf8_strchr (text, -1, '|'))
 		{
@@ -1461,6 +1459,26 @@ gchar *utils_str_break_form_name_field (const gchar *text,
 	return tmp_str;
 }
 
+/**
+ * compare deux chaines avec la fonction strcmp () Quid de l'UTF8 ?
+ *
+ * \param
+ * \param
+ *
+ * \return
+ **/
+gint utils_str_search_str_in_string_list (gchar *string_list,
+										  gchar *string_cmp)
+{
+    if (!string_list || strlen (string_list) == 0)
+        return -1;
+
+    if (!string_cmp || strlen (string_cmp) == 0)
+        return 1;
+
+    return (strcmp (string_list, string_cmp));
+}
+
 /**
  *
  *
